import 'package:flutter/material.dart';
import 'package:material_design_icons_flutter/material_design_icons_flutter.dart';

void main() {
  runApp(new MdiGalleryApp());
}

class MdiGalleryApp extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return new MaterialApp(
      title: 'Material Design Icons Flutter Gallery',
      theme: new ThemeData(
        iconTheme: new IconThemeData(size: 36.0, color: Colors.black87),
        primarySwatch: Colors.blue,
        textTheme: new TextTheme(
          body1: new TextStyle(fontSize: 16.0, color: Colors.black87),
        ),
      ),
      home: new MdiGalleryHome(),
    );
  }
}

class MdiGalleryHome extends StatefulWidget {
  @override
  State<StatefulWidget> createState() => new MdiGalleryHomeState();
}

class MdiGalleryHomeState extends State<MdiGalleryHome> {
  var _searchTerm = "";
  var _isSearching = false;

  @override
  Widget build(BuildContext context) {
    final filteredIcons = icons
        .where((icon) =>
            _searchTerm.isEmpty ||
            icon.title.toLowerCase().contains(_searchTerm.toLowerCase()))
        .toList();
    final orientation = MediaQuery.of(context).orientation;

    return new Scaffold(
      appBar: _isSearching ? _searchBar(context) : _titleBar(),
      body: new GridView.builder(
          itemCount: filteredIcons.length,
          gridDelegate: new SliverGridDelegateWithFixedCrossAxisCount(
            crossAxisCount: orientation == Orientation.portrait ? 2 : 3,
          ),
          itemBuilder: (context, index) {
            final icon = filteredIcons[index];

            return new InkWell(
              onTap: () {
                Navigator.push(
                  context,
                  new MaterialPageRoute<Null>(
                    builder: (BuildContext context) {
                      return new GestureDetector(
                        onTap: () {
                          Navigator.of(context).pop();
                        },
                        child: new Container(
                          color: Colors.white,
                          child: new SizedBox.expand(
                            child: new Hero(
                              tag: icon,
                              child: new Icon(
                                icon.iconData,
                                size: 100.0,
                              ),
                            ),
                          ),
                        ),
                      );
                    },
                  ),
                );
              },
              child: new Column(
                mainAxisAlignment: MainAxisAlignment.center,
                children: <Widget>[
                  new Hero(tag: icon, child: new Icon(icon.iconData)),
                  new Container(
                    padding: new EdgeInsets.only(top: 16.0),
                    child: new Text(icon.title),
                  )
                ],
              ),
            );
          }),
    );
  }

  AppBar _titleBar() {
    return new AppBar(
      title: new Text("Material Design Icons Gallery"),
      actions: [
        new IconButton(
            icon: new Icon(MdiIcons.magnify),
            onPressed: () {
              ModalRoute.of(context).addLocalHistoryEntry(
                new LocalHistoryEntry(
                  onRemove: () {
                    setState(() {
                      _searchTerm = "";
                      _isSearching = false;
                    });
                  },
                ),
              );

              setState(() {
                _isSearching = true;
              });
            })
      ],
    );
  }

  AppBar _searchBar(BuildContext context) {
    return new AppBar(
      leading: new IconButton(
        icon: new Icon(MdiIcons.magnify),
        onPressed: () {
          setState(
            () {
              Navigator.pop(context);
              _isSearching = false;
              _searchTerm = "";
            },
          );
        },
      ),
      title: new TextField(
        onChanged: (text) => setState(() => _searchTerm = text),
        autofocus: true,
        style: new TextStyle(fontSize: 18.0),
        decoration: new InputDecoration(),
      ),
    );
  }
}

class IconDefinition implements Comparable {
  final IconData iconData;
  final String title;

  IconDefinition(this.iconData, this.title);

  @override
  String toString() => 'IconDefinition{iconData: $iconData, title: $title}';

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
      other is IconDefinition &&
          runtimeType == other.runtimeType &&
          iconData == other.iconData &&
          title == other.title;

  @override
  int get hashCode => iconData.hashCode ^ title.hashCode;

  @override
  int compareTo(other) => title.compareTo(other.title);
}

MdiIcons iconLib = new MdiIcons();

final icons = <IconDefinition>[
  new IconDefinition(iconLib['accessPoint'], 'access-point'),
  new IconDefinition(iconLib['accessPointNetwork'], 'access-point-network'),
  new IconDefinition(iconLib['accessPointNetworkOff'], 'access-point-network-off'),
  new IconDefinition(iconLib['account'], 'account'),
  new IconDefinition(iconLib['accountAlert'], 'account-alert'),
  new IconDefinition(iconLib['accountAlertOutline'], 'account-alert-outline'),
  new IconDefinition(iconLib['accountArrowLeft'], 'account-arrow-left'),
  new IconDefinition(iconLib['accountArrowLeftOutline'], 'account-arrow-left-outline'),
  new IconDefinition(iconLib['accountArrowRight'], 'account-arrow-right'),
  new IconDefinition(iconLib['accountArrowRightOutline'], 'account-arrow-right-outline'),
  new IconDefinition(iconLib['accountBadge'], 'account-badge'),
  new IconDefinition(iconLib['accountBadgeAlert'], 'account-badge-alert'),
  new IconDefinition(iconLib['accountBadgeAlertOutline'], 'account-badge-alert-outline'),
  new IconDefinition(iconLib['accountBadgeHorizontal'], 'account-badge-horizontal'),
  new IconDefinition(iconLib['accountBadgeHorizontalOutline'], 'account-badge-horizontal-outline'),
  new IconDefinition(iconLib['accountBadgeOutline'], 'account-badge-outline'),
  new IconDefinition(iconLib['accountBox'], 'account-box'),
  new IconDefinition(iconLib['accountBoxMultiple'], 'account-box-multiple'),
  new IconDefinition(iconLib['accountBoxOutline'], 'account-box-outline'),
  new IconDefinition(iconLib['accountCardDetails'], 'account-card-details'),
  new IconDefinition(iconLib['accountCardDetailsOutline'], 'account-card-details-outline'),
  new IconDefinition(iconLib['accountCheck'], 'account-check'),
  new IconDefinition(iconLib['accountCheckOutline'], 'account-check-outline'),
  new IconDefinition(iconLib['accountChild'], 'account-child'),
  new IconDefinition(iconLib['accountChildCircle'], 'account-child-circle'),
  new IconDefinition(iconLib['accountCircle'], 'account-circle'),
  new IconDefinition(iconLib['accountCircleOutline'], 'account-circle-outline'),
  new IconDefinition(iconLib['accountClock'], 'account-clock'),
  new IconDefinition(iconLib['accountClockOutline'], 'account-clock-outline'),
  new IconDefinition(iconLib['accountConvert'], 'account-convert'),
  new IconDefinition(iconLib['accountDetails'], 'account-details'),
  new IconDefinition(iconLib['accountEdit'], 'account-edit'),
  new IconDefinition(iconLib['accountGroup'], 'account-group'),
  new IconDefinition(iconLib['accountGroupOutline'], 'account-group-outline'),
  new IconDefinition(iconLib['accountHeart'], 'account-heart'),
  new IconDefinition(iconLib['accountHeartOutline'], 'account-heart-outline'),
  new IconDefinition(iconLib['accountKey'], 'account-key'),
  new IconDefinition(iconLib['accountKeyOutline'], 'account-key-outline'),
  new IconDefinition(iconLib['accountMinus'], 'account-minus'),
  new IconDefinition(iconLib['accountMinusOutline'], 'account-minus-outline'),
  new IconDefinition(iconLib['accountMultiple'], 'account-multiple'),
  new IconDefinition(iconLib['accountMultipleCheck'], 'account-multiple-check'),
  new IconDefinition(iconLib['accountMultipleMinus'], 'account-multiple-minus'),
  new IconDefinition(iconLib['accountMultipleMinusOutline'], 'account-multiple-minus-outline'),
  new IconDefinition(iconLib['accountMultipleOutline'], 'account-multiple-outline'),
  new IconDefinition(iconLib['accountMultiplePlus'], 'account-multiple-plus'),
  new IconDefinition(iconLib['accountMultiplePlusOutline'], 'account-multiple-plus-outline'),
  new IconDefinition(iconLib['accountNetwork'], 'account-network'),
  new IconDefinition(iconLib['accountNetworkOutline'], 'account-network-outline'),
  new IconDefinition(iconLib['accountOff'], 'account-off'),
  new IconDefinition(iconLib['accountOffOutline'], 'account-off-outline'),
  new IconDefinition(iconLib['accountOutline'], 'account-outline'),
  new IconDefinition(iconLib['accountPlus'], 'account-plus'),
  new IconDefinition(iconLib['accountPlusOutline'], 'account-plus-outline'),
  new IconDefinition(iconLib['accountQuestion'], 'account-question'),
  new IconDefinition(iconLib['accountQuestionOutline'], 'account-question-outline'),
  new IconDefinition(iconLib['accountRemove'], 'account-remove'),
  new IconDefinition(iconLib['accountRemoveOutline'], 'account-remove-outline'),
  new IconDefinition(iconLib['accountSearch'], 'account-search'),
  new IconDefinition(iconLib['accountSearchOutline'], 'account-search-outline'),
  new IconDefinition(iconLib['accountSettings'], 'account-settings'),
  new IconDefinition(iconLib['accountStar'], 'account-star'),
  new IconDefinition(iconLib['accountStarOutline'], 'account-star-outline'),
  new IconDefinition(iconLib['accountSupervisor'], 'account-supervisor'),
  new IconDefinition(iconLib['accountSupervisorCircle'], 'account-supervisor-circle'),
  new IconDefinition(iconLib['accountSwitch'], 'account-switch'),
  new IconDefinition(iconLib['accountTie'], 'account-tie'),
  new IconDefinition(iconLib['accusoft'], 'accusoft'),
  new IconDefinition(iconLib['adchoices'], 'adchoices'),
  new IconDefinition(iconLib['adjust'], 'adjust'),
  new IconDefinition(iconLib['adobe'], 'adobe'),
  new IconDefinition(iconLib['airConditioner'], 'air-conditioner'),
  new IconDefinition(iconLib['airFilter'], 'air-filter'),
  new IconDefinition(iconLib['airHorn'], 'air-horn'),
  new IconDefinition(iconLib['airPurifier'], 'air-purifier'),
  new IconDefinition(iconLib['airbag'], 'airbag'),
  new IconDefinition(iconLib['airballoon'], 'airballoon'),
  new IconDefinition(iconLib['airplane'], 'airplane'),
  new IconDefinition(iconLib['airplaneLanding'], 'airplane-landing'),
  new IconDefinition(iconLib['airplaneOff'], 'airplane-off'),
  new IconDefinition(iconLib['airplaneTakeoff'], 'airplane-takeoff'),
  new IconDefinition(iconLib['airplay'], 'airplay'),
  new IconDefinition(iconLib['airport'], 'airport'),
  new IconDefinition(iconLib['alarm'], 'alarm'),
  new IconDefinition(iconLib['alarmBell'], 'alarm-bell'),
  new IconDefinition(iconLib['alarmCheck'], 'alarm-check'),
  new IconDefinition(iconLib['alarmLight'], 'alarm-light'),
  new IconDefinition(iconLib['alarmLightOutline'], 'alarm-light-outline'),
  new IconDefinition(iconLib['alarmMultiple'], 'alarm-multiple'),
  new IconDefinition(iconLib['alarmNote'], 'alarm-note'),
  new IconDefinition(iconLib['alarmNoteOff'], 'alarm-note-off'),
  new IconDefinition(iconLib['alarmOff'], 'alarm-off'),
  new IconDefinition(iconLib['alarmPlus'], 'alarm-plus'),
  new IconDefinition(iconLib['alarmSnooze'], 'alarm-snooze'),
  new IconDefinition(iconLib['album'], 'album'),
  new IconDefinition(iconLib['alert'], 'alert'),
  new IconDefinition(iconLib['alertBox'], 'alert-box'),
  new IconDefinition(iconLib['alertBoxOutline'], 'alert-box-outline'),
  new IconDefinition(iconLib['alertCircle'], 'alert-circle'),
  new IconDefinition(iconLib['alertCircleOutline'], 'alert-circle-outline'),
  new IconDefinition(iconLib['alertDecagram'], 'alert-decagram'),
  new IconDefinition(iconLib['alertDecagramOutline'], 'alert-decagram-outline'),
  new IconDefinition(iconLib['alertOctagon'], 'alert-octagon'),
  new IconDefinition(iconLib['alertOctagonOutline'], 'alert-octagon-outline'),
  new IconDefinition(iconLib['alertOctagram'], 'alert-octagram'),
  new IconDefinition(iconLib['alertOctagramOutline'], 'alert-octagram-outline'),
  new IconDefinition(iconLib['alertOutline'], 'alert-outline'),
  new IconDefinition(iconLib['alien'], 'alien'),
  new IconDefinition(iconLib['allInclusive'], 'all-inclusive'),
  new IconDefinition(iconLib['alpha'], 'alpha'),
  new IconDefinition(iconLib['alphaA'], 'alpha-a'),
  new IconDefinition(iconLib['alphaABox'], 'alpha-a-box'),
  new IconDefinition(iconLib['alphaABoxOutline'], 'alpha-a-box-outline'),
  new IconDefinition(iconLib['alphaACircle'], 'alpha-a-circle'),
  new IconDefinition(iconLib['alphaACircleOutline'], 'alpha-a-circle-outline'),
  new IconDefinition(iconLib['alphaB'], 'alpha-b'),
  new IconDefinition(iconLib['alphaBBox'], 'alpha-b-box'),
  new IconDefinition(iconLib['alphaBBoxOutline'], 'alpha-b-box-outline'),
  new IconDefinition(iconLib['alphaBCircle'], 'alpha-b-circle'),
  new IconDefinition(iconLib['alphaBCircleOutline'], 'alpha-b-circle-outline'),
  new IconDefinition(iconLib['alphaC'], 'alpha-c'),
  new IconDefinition(iconLib['alphaCBox'], 'alpha-c-box'),
  new IconDefinition(iconLib['alphaCBoxOutline'], 'alpha-c-box-outline'),
  new IconDefinition(iconLib['alphaCCircle'], 'alpha-c-circle'),
  new IconDefinition(iconLib['alphaCCircleOutline'], 'alpha-c-circle-outline'),
  new IconDefinition(iconLib['alphaD'], 'alpha-d'),
  new IconDefinition(iconLib['alphaDBox'], 'alpha-d-box'),
  new IconDefinition(iconLib['alphaDBoxOutline'], 'alpha-d-box-outline'),
  new IconDefinition(iconLib['alphaDCircle'], 'alpha-d-circle'),
  new IconDefinition(iconLib['alphaDCircleOutline'], 'alpha-d-circle-outline'),
  new IconDefinition(iconLib['alphaE'], 'alpha-e'),
  new IconDefinition(iconLib['alphaEBox'], 'alpha-e-box'),
  new IconDefinition(iconLib['alphaEBoxOutline'], 'alpha-e-box-outline'),
  new IconDefinition(iconLib['alphaECircle'], 'alpha-e-circle'),
  new IconDefinition(iconLib['alphaECircleOutline'], 'alpha-e-circle-outline'),
  new IconDefinition(iconLib['alphaF'], 'alpha-f'),
  new IconDefinition(iconLib['alphaFBox'], 'alpha-f-box'),
  new IconDefinition(iconLib['alphaFBoxOutline'], 'alpha-f-box-outline'),
  new IconDefinition(iconLib['alphaFCircle'], 'alpha-f-circle'),
  new IconDefinition(iconLib['alphaFCircleOutline'], 'alpha-f-circle-outline'),
  new IconDefinition(iconLib['alphaG'], 'alpha-g'),
  new IconDefinition(iconLib['alphaGBox'], 'alpha-g-box'),
  new IconDefinition(iconLib['alphaGBoxOutline'], 'alpha-g-box-outline'),
  new IconDefinition(iconLib['alphaGCircle'], 'alpha-g-circle'),
  new IconDefinition(iconLib['alphaGCircleOutline'], 'alpha-g-circle-outline'),
  new IconDefinition(iconLib['alphaH'], 'alpha-h'),
  new IconDefinition(iconLib['alphaHBox'], 'alpha-h-box'),
  new IconDefinition(iconLib['alphaHBoxOutline'], 'alpha-h-box-outline'),
  new IconDefinition(iconLib['alphaHCircle'], 'alpha-h-circle'),
  new IconDefinition(iconLib['alphaHCircleOutline'], 'alpha-h-circle-outline'),
  new IconDefinition(iconLib['alphaI'], 'alpha-i'),
  new IconDefinition(iconLib['alphaIBox'], 'alpha-i-box'),
  new IconDefinition(iconLib['alphaIBoxOutline'], 'alpha-i-box-outline'),
  new IconDefinition(iconLib['alphaICircle'], 'alpha-i-circle'),
  new IconDefinition(iconLib['alphaICircleOutline'], 'alpha-i-circle-outline'),
  new IconDefinition(iconLib['alphaJ'], 'alpha-j'),
  new IconDefinition(iconLib['alphaJBox'], 'alpha-j-box'),
  new IconDefinition(iconLib['alphaJBoxOutline'], 'alpha-j-box-outline'),
  new IconDefinition(iconLib['alphaJCircle'], 'alpha-j-circle'),
  new IconDefinition(iconLib['alphaJCircleOutline'], 'alpha-j-circle-outline'),
  new IconDefinition(iconLib['alphaK'], 'alpha-k'),
  new IconDefinition(iconLib['alphaKBox'], 'alpha-k-box'),
  new IconDefinition(iconLib['alphaKBoxOutline'], 'alpha-k-box-outline'),
  new IconDefinition(iconLib['alphaKCircle'], 'alpha-k-circle'),
  new IconDefinition(iconLib['alphaKCircleOutline'], 'alpha-k-circle-outline'),
  new IconDefinition(iconLib['alphaL'], 'alpha-l'),
  new IconDefinition(iconLib['alphaLBox'], 'alpha-l-box'),
  new IconDefinition(iconLib['alphaLBoxOutline'], 'alpha-l-box-outline'),
  new IconDefinition(iconLib['alphaLCircle'], 'alpha-l-circle'),
  new IconDefinition(iconLib['alphaLCircleOutline'], 'alpha-l-circle-outline'),
  new IconDefinition(iconLib['alphaM'], 'alpha-m'),
  new IconDefinition(iconLib['alphaMBox'], 'alpha-m-box'),
  new IconDefinition(iconLib['alphaMBoxOutline'], 'alpha-m-box-outline'),
  new IconDefinition(iconLib['alphaMCircle'], 'alpha-m-circle'),
  new IconDefinition(iconLib['alphaMCircleOutline'], 'alpha-m-circle-outline'),
  new IconDefinition(iconLib['alphaN'], 'alpha-n'),
  new IconDefinition(iconLib['alphaNBox'], 'alpha-n-box'),
  new IconDefinition(iconLib['alphaNBoxOutline'], 'alpha-n-box-outline'),
  new IconDefinition(iconLib['alphaNCircle'], 'alpha-n-circle'),
  new IconDefinition(iconLib['alphaNCircleOutline'], 'alpha-n-circle-outline'),
  new IconDefinition(iconLib['alphaO'], 'alpha-o'),
  new IconDefinition(iconLib['alphaOBox'], 'alpha-o-box'),
  new IconDefinition(iconLib['alphaOBoxOutline'], 'alpha-o-box-outline'),
  new IconDefinition(iconLib['alphaOCircle'], 'alpha-o-circle'),
  new IconDefinition(iconLib['alphaOCircleOutline'], 'alpha-o-circle-outline'),
  new IconDefinition(iconLib['alphaP'], 'alpha-p'),
  new IconDefinition(iconLib['alphaPBox'], 'alpha-p-box'),
  new IconDefinition(iconLib['alphaPBoxOutline'], 'alpha-p-box-outline'),
  new IconDefinition(iconLib['alphaPCircle'], 'alpha-p-circle'),
  new IconDefinition(iconLib['alphaPCircleOutline'], 'alpha-p-circle-outline'),
  new IconDefinition(iconLib['alphaQ'], 'alpha-q'),
  new IconDefinition(iconLib['alphaQBox'], 'alpha-q-box'),
  new IconDefinition(iconLib['alphaQBoxOutline'], 'alpha-q-box-outline'),
  new IconDefinition(iconLib['alphaQCircle'], 'alpha-q-circle'),
  new IconDefinition(iconLib['alphaQCircleOutline'], 'alpha-q-circle-outline'),
  new IconDefinition(iconLib['alphaR'], 'alpha-r'),
  new IconDefinition(iconLib['alphaRBox'], 'alpha-r-box'),
  new IconDefinition(iconLib['alphaRBoxOutline'], 'alpha-r-box-outline'),
  new IconDefinition(iconLib['alphaRCircle'], 'alpha-r-circle'),
  new IconDefinition(iconLib['alphaRCircleOutline'], 'alpha-r-circle-outline'),
  new IconDefinition(iconLib['alphaS'], 'alpha-s'),
  new IconDefinition(iconLib['alphaSBox'], 'alpha-s-box'),
  new IconDefinition(iconLib['alphaSBoxOutline'], 'alpha-s-box-outline'),
  new IconDefinition(iconLib['alphaSCircle'], 'alpha-s-circle'),
  new IconDefinition(iconLib['alphaSCircleOutline'], 'alpha-s-circle-outline'),
  new IconDefinition(iconLib['alphaT'], 'alpha-t'),
  new IconDefinition(iconLib['alphaTBox'], 'alpha-t-box'),
  new IconDefinition(iconLib['alphaTBoxOutline'], 'alpha-t-box-outline'),
  new IconDefinition(iconLib['alphaTCircle'], 'alpha-t-circle'),
  new IconDefinition(iconLib['alphaTCircleOutline'], 'alpha-t-circle-outline'),
  new IconDefinition(iconLib['alphaU'], 'alpha-u'),
  new IconDefinition(iconLib['alphaUBox'], 'alpha-u-box'),
  new IconDefinition(iconLib['alphaUBoxOutline'], 'alpha-u-box-outline'),
  new IconDefinition(iconLib['alphaUCircle'], 'alpha-u-circle'),
  new IconDefinition(iconLib['alphaUCircleOutline'], 'alpha-u-circle-outline'),
  new IconDefinition(iconLib['alphaV'], 'alpha-v'),
  new IconDefinition(iconLib['alphaVBox'], 'alpha-v-box'),
  new IconDefinition(iconLib['alphaVBoxOutline'], 'alpha-v-box-outline'),
  new IconDefinition(iconLib['alphaVCircle'], 'alpha-v-circle'),
  new IconDefinition(iconLib['alphaVCircleOutline'], 'alpha-v-circle-outline'),
  new IconDefinition(iconLib['alphaW'], 'alpha-w'),
  new IconDefinition(iconLib['alphaWBox'], 'alpha-w-box'),
  new IconDefinition(iconLib['alphaWBoxOutline'], 'alpha-w-box-outline'),
  new IconDefinition(iconLib['alphaWCircle'], 'alpha-w-circle'),
  new IconDefinition(iconLib['alphaWCircleOutline'], 'alpha-w-circle-outline'),
  new IconDefinition(iconLib['alphaX'], 'alpha-x'),
  new IconDefinition(iconLib['alphaXBox'], 'alpha-x-box'),
  new IconDefinition(iconLib['alphaXBoxOutline'], 'alpha-x-box-outline'),
  new IconDefinition(iconLib['alphaXCircle'], 'alpha-x-circle'),
  new IconDefinition(iconLib['alphaXCircleOutline'], 'alpha-x-circle-outline'),
  new IconDefinition(iconLib['alphaY'], 'alpha-y'),
  new IconDefinition(iconLib['alphaYBox'], 'alpha-y-box'),
  new IconDefinition(iconLib['alphaYBoxOutline'], 'alpha-y-box-outline'),
  new IconDefinition(iconLib['alphaYCircle'], 'alpha-y-circle'),
  new IconDefinition(iconLib['alphaYCircleOutline'], 'alpha-y-circle-outline'),
  new IconDefinition(iconLib['alphaZ'], 'alpha-z'),
  new IconDefinition(iconLib['alphaZBox'], 'alpha-z-box'),
  new IconDefinition(iconLib['alphaZBoxOutline'], 'alpha-z-box-outline'),
  new IconDefinition(iconLib['alphaZCircle'], 'alpha-z-circle'),
  new IconDefinition(iconLib['alphaZCircleOutline'], 'alpha-z-circle-outline'),
  new IconDefinition(iconLib['alphabetical'], 'alphabetical'),
  new IconDefinition(iconLib['altimeter'], 'altimeter'),
  new IconDefinition(iconLib['amazon'], 'amazon'),
  new IconDefinition(iconLib['amazonAlexa'], 'amazon-alexa'),
  new IconDefinition(iconLib['amazonDrive'], 'amazon-drive'),
  new IconDefinition(iconLib['ambulance'], 'ambulance'),
  new IconDefinition(iconLib['ammunition'], 'ammunition'),
  new IconDefinition(iconLib['ampersand'], 'ampersand'),
  new IconDefinition(iconLib['amplifier'], 'amplifier'),
  new IconDefinition(iconLib['anchor'], 'anchor'),
  new IconDefinition(iconLib['android'], 'android'),
  new IconDefinition(iconLib['androidAuto'], 'android-auto'),
  new IconDefinition(iconLib['androidDebugBridge'], 'android-debug-bridge'),
  new IconDefinition(iconLib['androidHead'], 'android-head'),
  new IconDefinition(iconLib['androidMessages'], 'android-messages'),
  new IconDefinition(iconLib['androidStudio'], 'android-studio'),
  new IconDefinition(iconLib['angleAcute'], 'angle-acute'),
  new IconDefinition(iconLib['angleObtuse'], 'angle-obtuse'),
  new IconDefinition(iconLib['angleRight'], 'angle-right'),
  new IconDefinition(iconLib['angular'], 'angular'),
  new IconDefinition(iconLib['angularjs'], 'angularjs'),
  new IconDefinition(iconLib['animation'], 'animation'),
  new IconDefinition(iconLib['animationOutline'], 'animation-outline'),
  new IconDefinition(iconLib['animationPlay'], 'animation-play'),
  new IconDefinition(iconLib['animationPlayOutline'], 'animation-play-outline'),
  new IconDefinition(iconLib['anvil'], 'anvil'),
  new IconDefinition(iconLib['apple'], 'apple'),
  new IconDefinition(iconLib['appleFinder'], 'apple-finder'),
  new IconDefinition(iconLib['appleIcloud'], 'apple-icloud'),
  new IconDefinition(iconLib['appleIos'], 'apple-ios'),
  new IconDefinition(iconLib['appleKeyboardCaps'], 'apple-keyboard-caps'),
  new IconDefinition(iconLib['appleKeyboardCommand'], 'apple-keyboard-command'),
  new IconDefinition(iconLib['appleKeyboardControl'], 'apple-keyboard-control'),
  new IconDefinition(iconLib['appleKeyboardOption'], 'apple-keyboard-option'),
  new IconDefinition(iconLib['appleKeyboardShift'], 'apple-keyboard-shift'),
  new IconDefinition(iconLib['appleSafari'], 'apple-safari'),
  new IconDefinition(iconLib['application'], 'application'),
  new IconDefinition(iconLib['applicationExport'], 'application-export'),
  new IconDefinition(iconLib['applicationImport'], 'application-import'),
  new IconDefinition(iconLib['apps'], 'apps'),
  new IconDefinition(iconLib['appsBox'], 'apps-box'),
  new IconDefinition(iconLib['arch'], 'arch'),
  new IconDefinition(iconLib['archive'], 'archive'),
  new IconDefinition(iconLib['arrangeBringForward'], 'arrange-bring-forward'),
  new IconDefinition(iconLib['arrangeBringToFront'], 'arrange-bring-to-front'),
  new IconDefinition(iconLib['arrangeSendBackward'], 'arrange-send-backward'),
  new IconDefinition(iconLib['arrangeSendToBack'], 'arrange-send-to-back'),
  new IconDefinition(iconLib['arrowAll'], 'arrow-all'),
  new IconDefinition(iconLib['arrowBottomLeft'], 'arrow-bottom-left'),
  new IconDefinition(iconLib['arrowBottomLeftBoldOutline'], 'arrow-bottom-left-bold-outline'),
  new IconDefinition(iconLib['arrowBottomLeftThick'], 'arrow-bottom-left-thick'),
  new IconDefinition(iconLib['arrowBottomRight'], 'arrow-bottom-right'),
  new IconDefinition(iconLib['arrowBottomRightBoldOutline'], 'arrow-bottom-right-bold-outline'),
  new IconDefinition(iconLib['arrowBottomRightThick'], 'arrow-bottom-right-thick'),
  new IconDefinition(iconLib['arrowCollapse'], 'arrow-collapse'),
  new IconDefinition(iconLib['arrowCollapseAll'], 'arrow-collapse-all'),
  new IconDefinition(iconLib['arrowCollapseDown'], 'arrow-collapse-down'),
  new IconDefinition(iconLib['arrowCollapseHorizontal'], 'arrow-collapse-horizontal'),
  new IconDefinition(iconLib['arrowCollapseLeft'], 'arrow-collapse-left'),
  new IconDefinition(iconLib['arrowCollapseRight'], 'arrow-collapse-right'),
  new IconDefinition(iconLib['arrowCollapseUp'], 'arrow-collapse-up'),
  new IconDefinition(iconLib['arrowCollapseVertical'], 'arrow-collapse-vertical'),
  new IconDefinition(iconLib['arrowDecision'], 'arrow-decision'),
  new IconDefinition(iconLib['arrowDecisionAuto'], 'arrow-decision-auto'),
  new IconDefinition(iconLib['arrowDecisionAutoOutline'], 'arrow-decision-auto-outline'),
  new IconDefinition(iconLib['arrowDecisionOutline'], 'arrow-decision-outline'),
  new IconDefinition(iconLib['arrowDown'], 'arrow-down'),
  new IconDefinition(iconLib['arrowDownBold'], 'arrow-down-bold'),
  new IconDefinition(iconLib['arrowDownBoldBox'], 'arrow-down-bold-box'),
  new IconDefinition(iconLib['arrowDownBoldBoxOutline'], 'arrow-down-bold-box-outline'),
  new IconDefinition(iconLib['arrowDownBoldCircle'], 'arrow-down-bold-circle'),
  new IconDefinition(iconLib['arrowDownBoldCircleOutline'], 'arrow-down-bold-circle-outline'),
  new IconDefinition(iconLib['arrowDownBoldHexagonOutline'], 'arrow-down-bold-hexagon-outline'),
  new IconDefinition(iconLib['arrowDownBoldOutline'], 'arrow-down-bold-outline'),
  new IconDefinition(iconLib['arrowDownBox'], 'arrow-down-box'),
  new IconDefinition(iconLib['arrowDownCircle'], 'arrow-down-circle'),
  new IconDefinition(iconLib['arrowDownCircleOutline'], 'arrow-down-circle-outline'),
  new IconDefinition(iconLib['arrowDownDropCircle'], 'arrow-down-drop-circle'),
  new IconDefinition(iconLib['arrowDownDropCircleOutline'], 'arrow-down-drop-circle-outline'),
  new IconDefinition(iconLib['arrowDownThick'], 'arrow-down-thick'),
  new IconDefinition(iconLib['arrowExpand'], 'arrow-expand'),
  new IconDefinition(iconLib['arrowExpandAll'], 'arrow-expand-all'),
  new IconDefinition(iconLib['arrowExpandDown'], 'arrow-expand-down'),
  new IconDefinition(iconLib['arrowExpandHorizontal'], 'arrow-expand-horizontal'),
  new IconDefinition(iconLib['arrowExpandLeft'], 'arrow-expand-left'),
  new IconDefinition(iconLib['arrowExpandRight'], 'arrow-expand-right'),
  new IconDefinition(iconLib['arrowExpandUp'], 'arrow-expand-up'),
  new IconDefinition(iconLib['arrowExpandVertical'], 'arrow-expand-vertical'),
  new IconDefinition(iconLib['arrowLeft'], 'arrow-left'),
  new IconDefinition(iconLib['arrowLeftBold'], 'arrow-left-bold'),
  new IconDefinition(iconLib['arrowLeftBoldBox'], 'arrow-left-bold-box'),
  new IconDefinition(iconLib['arrowLeftBoldBoxOutline'], 'arrow-left-bold-box-outline'),
  new IconDefinition(iconLib['arrowLeftBoldCircle'], 'arrow-left-bold-circle'),
  new IconDefinition(iconLib['arrowLeftBoldCircleOutline'], 'arrow-left-bold-circle-outline'),
  new IconDefinition(iconLib['arrowLeftBoldHexagonOutline'], 'arrow-left-bold-hexagon-outline'),
  new IconDefinition(iconLib['arrowLeftBoldOutline'], 'arrow-left-bold-outline'),
  new IconDefinition(iconLib['arrowLeftBox'], 'arrow-left-box'),
  new IconDefinition(iconLib['arrowLeftCircle'], 'arrow-left-circle'),
  new IconDefinition(iconLib['arrowLeftCircleOutline'], 'arrow-left-circle-outline'),
  new IconDefinition(iconLib['arrowLeftDropCircle'], 'arrow-left-drop-circle'),
  new IconDefinition(iconLib['arrowLeftDropCircleOutline'], 'arrow-left-drop-circle-outline'),
  new IconDefinition(iconLib['arrowLeftRight'], 'arrow-left-right'),
  new IconDefinition(iconLib['arrowLeftRightBold'], 'arrow-left-right-bold'),
  new IconDefinition(iconLib['arrowLeftRightBoldOutline'], 'arrow-left-right-bold-outline'),
  new IconDefinition(iconLib['arrowLeftThick'], 'arrow-left-thick'),
  new IconDefinition(iconLib['arrowRight'], 'arrow-right'),
  new IconDefinition(iconLib['arrowRightBold'], 'arrow-right-bold'),
  new IconDefinition(iconLib['arrowRightBoldBox'], 'arrow-right-bold-box'),
  new IconDefinition(iconLib['arrowRightBoldBoxOutline'], 'arrow-right-bold-box-outline'),
  new IconDefinition(iconLib['arrowRightBoldCircle'], 'arrow-right-bold-circle'),
  new IconDefinition(iconLib['arrowRightBoldCircleOutline'], 'arrow-right-bold-circle-outline'),
  new IconDefinition(iconLib['arrowRightBoldHexagonOutline'], 'arrow-right-bold-hexagon-outline'),
  new IconDefinition(iconLib['arrowRightBoldOutline'], 'arrow-right-bold-outline'),
  new IconDefinition(iconLib['arrowRightBox'], 'arrow-right-box'),
  new IconDefinition(iconLib['arrowRightCircle'], 'arrow-right-circle'),
  new IconDefinition(iconLib['arrowRightCircleOutline'], 'arrow-right-circle-outline'),
  new IconDefinition(iconLib['arrowRightDropCircle'], 'arrow-right-drop-circle'),
  new IconDefinition(iconLib['arrowRightDropCircleOutline'], 'arrow-right-drop-circle-outline'),
  new IconDefinition(iconLib['arrowRightThick'], 'arrow-right-thick'),
  new IconDefinition(iconLib['arrowSplitHorizontal'], 'arrow-split-horizontal'),
  new IconDefinition(iconLib['arrowSplitVertical'], 'arrow-split-vertical'),
  new IconDefinition(iconLib['arrowTopLeft'], 'arrow-top-left'),
  new IconDefinition(iconLib['arrowTopLeftBoldOutline'], 'arrow-top-left-bold-outline'),
  new IconDefinition(iconLib['arrowTopLeftBottomRight'], 'arrow-top-left-bottom-right'),
  new IconDefinition(iconLib['arrowTopLeftBottomRightBold'], 'arrow-top-left-bottom-right-bold'),
  new IconDefinition(iconLib['arrowTopLeftThick'], 'arrow-top-left-thick'),
  new IconDefinition(iconLib['arrowTopRight'], 'arrow-top-right'),
  new IconDefinition(iconLib['arrowTopRightBoldOutline'], 'arrow-top-right-bold-outline'),
  new IconDefinition(iconLib['arrowTopRightBottomLeft'], 'arrow-top-right-bottom-left'),
  new IconDefinition(iconLib['arrowTopRightBottomLeftBold'], 'arrow-top-right-bottom-left-bold'),
  new IconDefinition(iconLib['arrowTopRightThick'], 'arrow-top-right-thick'),
  new IconDefinition(iconLib['arrowUp'], 'arrow-up'),
  new IconDefinition(iconLib['arrowUpBold'], 'arrow-up-bold'),
  new IconDefinition(iconLib['arrowUpBoldBox'], 'arrow-up-bold-box'),
  new IconDefinition(iconLib['arrowUpBoldBoxOutline'], 'arrow-up-bold-box-outline'),
  new IconDefinition(iconLib['arrowUpBoldCircle'], 'arrow-up-bold-circle'),
  new IconDefinition(iconLib['arrowUpBoldCircleOutline'], 'arrow-up-bold-circle-outline'),
  new IconDefinition(iconLib['arrowUpBoldHexagonOutline'], 'arrow-up-bold-hexagon-outline'),
  new IconDefinition(iconLib['arrowUpBoldOutline'], 'arrow-up-bold-outline'),
  new IconDefinition(iconLib['arrowUpBox'], 'arrow-up-box'),
  new IconDefinition(iconLib['arrowUpCircle'], 'arrow-up-circle'),
  new IconDefinition(iconLib['arrowUpCircleOutline'], 'arrow-up-circle-outline'),
  new IconDefinition(iconLib['arrowUpDown'], 'arrow-up-down'),
  new IconDefinition(iconLib['arrowUpDownBold'], 'arrow-up-down-bold'),
  new IconDefinition(iconLib['arrowUpDownBoldOutline'], 'arrow-up-down-bold-outline'),
  new IconDefinition(iconLib['arrowUpDropCircle'], 'arrow-up-drop-circle'),
  new IconDefinition(iconLib['arrowUpDropCircleOutline'], 'arrow-up-drop-circle-outline'),
  new IconDefinition(iconLib['arrowUpThick'], 'arrow-up-thick'),
  new IconDefinition(iconLib['artist'], 'artist'),
  new IconDefinition(iconLib['artistOutline'], 'artist-outline'),
  new IconDefinition(iconLib['artstation'], 'artstation'),
  new IconDefinition(iconLib['aspectRatio'], 'aspect-ratio'),
  new IconDefinition(iconLib['assistant'], 'assistant'),
  new IconDefinition(iconLib['asterisk'], 'asterisk'),
  new IconDefinition(iconLib['at'], 'at'),
  new IconDefinition(iconLib['atlassian'], 'atlassian'),
  new IconDefinition(iconLib['atm'], 'atm'),
  new IconDefinition(iconLib['atom'], 'atom'),
  new IconDefinition(iconLib['atomVariant'], 'atom-variant'),
  new IconDefinition(iconLib['attachment'], 'attachment'),
  new IconDefinition(iconLib['audioVideo'], 'audio-video'),
  new IconDefinition(iconLib['audiobook'], 'audiobook'),
  new IconDefinition(iconLib['augmentedReality'], 'augmented-reality'),
  new IconDefinition(iconLib['autoFix'], 'auto-fix'),
  new IconDefinition(iconLib['autoUpload'], 'auto-upload'),
  new IconDefinition(iconLib['autorenew'], 'autorenew'),
  new IconDefinition(iconLib['avTimer'], 'av-timer'),
  new IconDefinition(iconLib['aws'], 'aws'),
  new IconDefinition(iconLib['axe'], 'axe'),
  new IconDefinition(iconLib['axis'], 'axis'),
  new IconDefinition(iconLib['axisArrow'], 'axis-arrow'),
  new IconDefinition(iconLib['axisArrowLock'], 'axis-arrow-lock'),
  new IconDefinition(iconLib['axisLock'], 'axis-lock'),
  new IconDefinition(iconLib['axisXArrow'], 'axis-x-arrow'),
  new IconDefinition(iconLib['axisXArrowLock'], 'axis-x-arrow-lock'),
  new IconDefinition(iconLib['axisXRotateClockwise'], 'axis-x-rotate-clockwise'),
  new IconDefinition(iconLib['axisXRotateCounterclockwise'], 'axis-x-rotate-counterclockwise'),
  new IconDefinition(iconLib['axisXYArrowLock'], 'axis-x-y-arrow-lock'),
  new IconDefinition(iconLib['axisYArrow'], 'axis-y-arrow'),
  new IconDefinition(iconLib['axisYArrowLock'], 'axis-y-arrow-lock'),
  new IconDefinition(iconLib['axisYRotateClockwise'], 'axis-y-rotate-clockwise'),
  new IconDefinition(iconLib['axisYRotateCounterclockwise'], 'axis-y-rotate-counterclockwise'),
  new IconDefinition(iconLib['axisZArrow'], 'axis-z-arrow'),
  new IconDefinition(iconLib['axisZArrowLock'], 'axis-z-arrow-lock'),
  new IconDefinition(iconLib['axisZRotateClockwise'], 'axis-z-rotate-clockwise'),
  new IconDefinition(iconLib['axisZRotateCounterclockwise'], 'axis-z-rotate-counterclockwise'),
  new IconDefinition(iconLib['azure'], 'azure'),
  new IconDefinition(iconLib['babel'], 'babel'),
  new IconDefinition(iconLib['baby'], 'baby'),
  new IconDefinition(iconLib['babyBuggy'], 'baby-buggy'),
  new IconDefinition(iconLib['babyFace'], 'baby-face'),
  new IconDefinition(iconLib['babyFaceOutline'], 'baby-face-outline'),
  new IconDefinition(iconLib['backburger'], 'backburger'),
  new IconDefinition(iconLib['backspace'], 'backspace'),
  new IconDefinition(iconLib['backspaceOutline'], 'backspace-outline'),
  new IconDefinition(iconLib['backspaceReverse'], 'backspace-reverse'),
  new IconDefinition(iconLib['backspaceReverseOutline'], 'backspace-reverse-outline'),
  new IconDefinition(iconLib['backupRestore'], 'backup-restore'),
  new IconDefinition(iconLib['bacteria'], 'bacteria'),
  new IconDefinition(iconLib['bacteriaOutline'], 'bacteria-outline'),
  new IconDefinition(iconLib['badminton'], 'badminton'),
  new IconDefinition(iconLib['bagPersonal'], 'bag-personal'),
  new IconDefinition(iconLib['bagPersonalOff'], 'bag-personal-off'),
  new IconDefinition(iconLib['bagPersonalOffOutline'], 'bag-personal-off-outline'),
  new IconDefinition(iconLib['bagPersonalOutline'], 'bag-personal-outline'),
  new IconDefinition(iconLib['balloon'], 'balloon'),
  new IconDefinition(iconLib['ballot'], 'ballot'),
  new IconDefinition(iconLib['ballotOutline'], 'ballot-outline'),
  new IconDefinition(iconLib['ballotRecount'], 'ballot-recount'),
  new IconDefinition(iconLib['ballotRecountOutline'], 'ballot-recount-outline'),
  new IconDefinition(iconLib['bandage'], 'bandage'),
  new IconDefinition(iconLib['bandcamp'], 'bandcamp'),
  new IconDefinition(iconLib['bank'], 'bank'),
  new IconDefinition(iconLib['bankMinus'], 'bank-minus'),
  new IconDefinition(iconLib['bankOutline'], 'bank-outline'),
  new IconDefinition(iconLib['bankPlus'], 'bank-plus'),
  new IconDefinition(iconLib['bankRemove'], 'bank-remove'),
  new IconDefinition(iconLib['bankTransfer'], 'bank-transfer'),
  new IconDefinition(iconLib['bankTransferIn'], 'bank-transfer-in'),
  new IconDefinition(iconLib['bankTransferOut'], 'bank-transfer-out'),
  new IconDefinition(iconLib['barcode'], 'barcode'),
  new IconDefinition(iconLib['barcodeScan'], 'barcode-scan'),
  new IconDefinition(iconLib['barley'], 'barley'),
  new IconDefinition(iconLib['barleyOff'], 'barley-off'),
  new IconDefinition(iconLib['barn'], 'barn'),
  new IconDefinition(iconLib['barrel'], 'barrel'),
  new IconDefinition(iconLib['baseball'], 'baseball'),
  new IconDefinition(iconLib['baseballBat'], 'baseball-bat'),
  new IconDefinition(iconLib['basecamp'], 'basecamp'),
  new IconDefinition(iconLib['basket'], 'basket'),
  new IconDefinition(iconLib['basketFill'], 'basket-fill'),
  new IconDefinition(iconLib['basketUnfill'], 'basket-unfill'),
  new IconDefinition(iconLib['basketball'], 'basketball'),
  new IconDefinition(iconLib['basketballHoop'], 'basketball-hoop'),
  new IconDefinition(iconLib['basketballHoopOutline'], 'basketball-hoop-outline'),
  new IconDefinition(iconLib['bat'], 'bat'),
  new IconDefinition(iconLib['battery'], 'battery'),
  new IconDefinition(iconLib['battery10'], 'battery-10'),
  new IconDefinition(iconLib['battery10Bluetooth'], 'battery-10-bluetooth'),
  new IconDefinition(iconLib['battery20'], 'battery-20'),
  new IconDefinition(iconLib['battery20Bluetooth'], 'battery-20-bluetooth'),
  new IconDefinition(iconLib['battery30'], 'battery-30'),
  new IconDefinition(iconLib['battery30Bluetooth'], 'battery-30-bluetooth'),
  new IconDefinition(iconLib['battery40'], 'battery-40'),
  new IconDefinition(iconLib['battery40Bluetooth'], 'battery-40-bluetooth'),
  new IconDefinition(iconLib['battery50'], 'battery-50'),
  new IconDefinition(iconLib['battery50Bluetooth'], 'battery-50-bluetooth'),
  new IconDefinition(iconLib['battery60'], 'battery-60'),
  new IconDefinition(iconLib['battery60Bluetooth'], 'battery-60-bluetooth'),
  new IconDefinition(iconLib['battery70'], 'battery-70'),
  new IconDefinition(iconLib['battery70Bluetooth'], 'battery-70-bluetooth'),
  new IconDefinition(iconLib['battery80'], 'battery-80'),
  new IconDefinition(iconLib['battery80Bluetooth'], 'battery-80-bluetooth'),
  new IconDefinition(iconLib['battery90'], 'battery-90'),
  new IconDefinition(iconLib['battery90Bluetooth'], 'battery-90-bluetooth'),
  new IconDefinition(iconLib['batteryAlert'], 'battery-alert'),
  new IconDefinition(iconLib['batteryAlertBluetooth'], 'battery-alert-bluetooth'),
  new IconDefinition(iconLib['batteryBluetooth'], 'battery-bluetooth'),
  new IconDefinition(iconLib['batteryBluetoothVariant'], 'battery-bluetooth-variant'),
  new IconDefinition(iconLib['batteryCharging'], 'battery-charging'),
  new IconDefinition(iconLib['batteryCharging10'], 'battery-charging-10'),
  new IconDefinition(iconLib['batteryCharging100'], 'battery-charging-100'),
  new IconDefinition(iconLib['batteryCharging20'], 'battery-charging-20'),
  new IconDefinition(iconLib['batteryCharging30'], 'battery-charging-30'),
  new IconDefinition(iconLib['batteryCharging40'], 'battery-charging-40'),
  new IconDefinition(iconLib['batteryCharging50'], 'battery-charging-50'),
  new IconDefinition(iconLib['batteryCharging60'], 'battery-charging-60'),
  new IconDefinition(iconLib['batteryCharging70'], 'battery-charging-70'),
  new IconDefinition(iconLib['batteryCharging80'], 'battery-charging-80'),
  new IconDefinition(iconLib['batteryCharging90'], 'battery-charging-90'),
  new IconDefinition(iconLib['batteryChargingOutline'], 'battery-charging-outline'),
  new IconDefinition(iconLib['batteryChargingWireless'], 'battery-charging-wireless'),
  new IconDefinition(iconLib['batteryChargingWireless10'], 'battery-charging-wireless-10'),
  new IconDefinition(iconLib['batteryChargingWireless20'], 'battery-charging-wireless-20'),
  new IconDefinition(iconLib['batteryChargingWireless30'], 'battery-charging-wireless-30'),
  new IconDefinition(iconLib['batteryChargingWireless40'], 'battery-charging-wireless-40'),
  new IconDefinition(iconLib['batteryChargingWireless50'], 'battery-charging-wireless-50'),
  new IconDefinition(iconLib['batteryChargingWireless60'], 'battery-charging-wireless-60'),
  new IconDefinition(iconLib['batteryChargingWireless70'], 'battery-charging-wireless-70'),
  new IconDefinition(iconLib['batteryChargingWireless80'], 'battery-charging-wireless-80'),
  new IconDefinition(iconLib['batteryChargingWireless90'], 'battery-charging-wireless-90'),
  new IconDefinition(iconLib['batteryChargingWirelessAlert'], 'battery-charging-wireless-alert'),
  new IconDefinition(iconLib['batteryChargingWirelessOutline'], 'battery-charging-wireless-outline'),
  new IconDefinition(iconLib['batteryMinus'], 'battery-minus'),
  new IconDefinition(iconLib['batteryNegative'], 'battery-negative'),
  new IconDefinition(iconLib['batteryOutline'], 'battery-outline'),
  new IconDefinition(iconLib['batteryPlus'], 'battery-plus'),
  new IconDefinition(iconLib['batteryPositive'], 'battery-positive'),
  new IconDefinition(iconLib['batteryUnknown'], 'battery-unknown'),
  new IconDefinition(iconLib['batteryUnknownBluetooth'], 'battery-unknown-bluetooth'),
  new IconDefinition(iconLib['battlenet'], 'battlenet'),
  new IconDefinition(iconLib['beach'], 'beach'),
  new IconDefinition(iconLib['beaker'], 'beaker'),
  new IconDefinition(iconLib['beakerOutline'], 'beaker-outline'),
  new IconDefinition(iconLib['beats'], 'beats'),
  new IconDefinition(iconLib['bedEmpty'], 'bed-empty'),
  new IconDefinition(iconLib['beer'], 'beer'),
  new IconDefinition(iconLib['behance'], 'behance'),
  new IconDefinition(iconLib['bell'], 'bell'),
  new IconDefinition(iconLib['bellAlert'], 'bell-alert'),
  new IconDefinition(iconLib['bellAlertOutline'], 'bell-alert-outline'),
  new IconDefinition(iconLib['bellCircle'], 'bell-circle'),
  new IconDefinition(iconLib['bellCircleOutline'], 'bell-circle-outline'),
  new IconDefinition(iconLib['bellOff'], 'bell-off'),
  new IconDefinition(iconLib['bellOffOutline'], 'bell-off-outline'),
  new IconDefinition(iconLib['bellOutline'], 'bell-outline'),
  new IconDefinition(iconLib['bellPlus'], 'bell-plus'),
  new IconDefinition(iconLib['bellPlusOutline'], 'bell-plus-outline'),
  new IconDefinition(iconLib['bellRing'], 'bell-ring'),
  new IconDefinition(iconLib['bellRingOutline'], 'bell-ring-outline'),
  new IconDefinition(iconLib['bellSleep'], 'bell-sleep'),
  new IconDefinition(iconLib['bellSleepOutline'], 'bell-sleep-outline'),
  new IconDefinition(iconLib['beta'], 'beta'),
  new IconDefinition(iconLib['betamax'], 'betamax'),
  new IconDefinition(iconLib['biathlon'], 'biathlon'),
  new IconDefinition(iconLib['bible'], 'bible'),
  new IconDefinition(iconLib['bike'], 'bike'),
  new IconDefinition(iconLib['billiards'], 'billiards'),
  new IconDefinition(iconLib['billiardsRack'], 'billiards-rack'),
  new IconDefinition(iconLib['bing'], 'bing'),
  new IconDefinition(iconLib['binoculars'], 'binoculars'),
  new IconDefinition(iconLib['bio'], 'bio'),
  new IconDefinition(iconLib['biohazard'], 'biohazard'),
  new IconDefinition(iconLib['bitbucket'], 'bitbucket'),
  new IconDefinition(iconLib['bitcoin'], 'bitcoin'),
  new IconDefinition(iconLib['blackMesa'], 'black-mesa'),
  new IconDefinition(iconLib['blackberry'], 'blackberry'),
  new IconDefinition(iconLib['blender'], 'blender'),
  new IconDefinition(iconLib['blenderSoftware'], 'blender-software'),
  new IconDefinition(iconLib['blinds'], 'blinds'),
  new IconDefinition(iconLib['blockHelper'], 'block-helper'),
  new IconDefinition(iconLib['blogger'], 'blogger'),
  new IconDefinition(iconLib['bloodBag'], 'blood-bag'),
  new IconDefinition(iconLib['bluetooth'], 'bluetooth'),
  new IconDefinition(iconLib['bluetoothAudio'], 'bluetooth-audio'),
  new IconDefinition(iconLib['bluetoothConnect'], 'bluetooth-connect'),
  new IconDefinition(iconLib['bluetoothOff'], 'bluetooth-off'),
  new IconDefinition(iconLib['bluetoothSettings'], 'bluetooth-settings'),
  new IconDefinition(iconLib['bluetoothTransfer'], 'bluetooth-transfer'),
  new IconDefinition(iconLib['blur'], 'blur'),
  new IconDefinition(iconLib['blurLinear'], 'blur-linear'),
  new IconDefinition(iconLib['blurOff'], 'blur-off'),
  new IconDefinition(iconLib['blurRadial'], 'blur-radial'),
  new IconDefinition(iconLib['bolnisiCross'], 'bolnisi-cross'),
  new IconDefinition(iconLib['bolt'], 'bolt'),
  new IconDefinition(iconLib['bomb'], 'bomb'),
  new IconDefinition(iconLib['bombOff'], 'bomb-off'),
  new IconDefinition(iconLib['bone'], 'bone'),
  new IconDefinition(iconLib['book'], 'book'),
  new IconDefinition(iconLib['bookLock'], 'book-lock'),
  new IconDefinition(iconLib['bookLockOpen'], 'book-lock-open'),
  new IconDefinition(iconLib['bookMinus'], 'book-minus'),
  new IconDefinition(iconLib['bookMultiple'], 'book-multiple'),
  new IconDefinition(iconLib['bookMultipleMinus'], 'book-multiple-minus'),
  new IconDefinition(iconLib['bookMultiplePlus'], 'book-multiple-plus'),
  new IconDefinition(iconLib['bookMultipleRemove'], 'book-multiple-remove'),
  new IconDefinition(iconLib['bookMultipleVariant'], 'book-multiple-variant'),
  new IconDefinition(iconLib['bookOpen'], 'book-open'),
  new IconDefinition(iconLib['bookOpenOutline'], 'book-open-outline'),
  new IconDefinition(iconLib['bookOpenPageVariant'], 'book-open-page-variant'),
  new IconDefinition(iconLib['bookOpenVariant'], 'book-open-variant'),
  new IconDefinition(iconLib['bookOutline'], 'book-outline'),
  new IconDefinition(iconLib['bookPlay'], 'book-play'),
  new IconDefinition(iconLib['bookPlayOutline'], 'book-play-outline'),
  new IconDefinition(iconLib['bookPlus'], 'book-plus'),
  new IconDefinition(iconLib['bookRemove'], 'book-remove'),
  new IconDefinition(iconLib['bookSearch'], 'book-search'),
  new IconDefinition(iconLib['bookSearchOutline'], 'book-search-outline'),
  new IconDefinition(iconLib['bookVariant'], 'book-variant'),
  new IconDefinition(iconLib['bookmark'], 'bookmark'),
  new IconDefinition(iconLib['bookmarkCheck'], 'bookmark-check'),
  new IconDefinition(iconLib['bookmarkMinus'], 'bookmark-minus'),
  new IconDefinition(iconLib['bookmarkMinusOutline'], 'bookmark-minus-outline'),
  new IconDefinition(iconLib['bookmarkMultiple'], 'bookmark-multiple'),
  new IconDefinition(iconLib['bookmarkMultipleOutline'], 'bookmark-multiple-outline'),
  new IconDefinition(iconLib['bookmarkMusic'], 'bookmark-music'),
  new IconDefinition(iconLib['bookmarkOff'], 'bookmark-off'),
  new IconDefinition(iconLib['bookmarkOffOutline'], 'bookmark-off-outline'),
  new IconDefinition(iconLib['bookmarkOutline'], 'bookmark-outline'),
  new IconDefinition(iconLib['bookmarkPlus'], 'bookmark-plus'),
  new IconDefinition(iconLib['bookmarkPlusOutline'], 'bookmark-plus-outline'),
  new IconDefinition(iconLib['bookmarkRemove'], 'bookmark-remove'),
  new IconDefinition(iconLib['boomGate'], 'boom-gate'),
  new IconDefinition(iconLib['boomGateAlert'], 'boom-gate-alert'),
  new IconDefinition(iconLib['boomGateAlertOutline'], 'boom-gate-alert-outline'),
  new IconDefinition(iconLib['boomGateDown'], 'boom-gate-down'),
  new IconDefinition(iconLib['boomGateDownOutline'], 'boom-gate-down-outline'),
  new IconDefinition(iconLib['boomGateOutline'], 'boom-gate-outline'),
  new IconDefinition(iconLib['boomGateUp'], 'boom-gate-up'),
  new IconDefinition(iconLib['boomGateUpOutline'], 'boom-gate-up-outline'),
  new IconDefinition(iconLib['boombox'], 'boombox'),
  new IconDefinition(iconLib['bootstrap'], 'bootstrap'),
  new IconDefinition(iconLib['borderAll'], 'border-all'),
  new IconDefinition(iconLib['borderAllVariant'], 'border-all-variant'),
  new IconDefinition(iconLib['borderBottom'], 'border-bottom'),
  new IconDefinition(iconLib['borderBottomVariant'], 'border-bottom-variant'),
  new IconDefinition(iconLib['borderColor'], 'border-color'),
  new IconDefinition(iconLib['borderHorizontal'], 'border-horizontal'),
  new IconDefinition(iconLib['borderInside'], 'border-inside'),
  new IconDefinition(iconLib['borderLeft'], 'border-left'),
  new IconDefinition(iconLib['borderLeftVariant'], 'border-left-variant'),
  new IconDefinition(iconLib['borderNone'], 'border-none'),
  new IconDefinition(iconLib['borderNoneVariant'], 'border-none-variant'),
  new IconDefinition(iconLib['borderOutside'], 'border-outside'),
  new IconDefinition(iconLib['borderRight'], 'border-right'),
  new IconDefinition(iconLib['borderRightVariant'], 'border-right-variant'),
  new IconDefinition(iconLib['borderStyle'], 'border-style'),
  new IconDefinition(iconLib['borderTop'], 'border-top'),
  new IconDefinition(iconLib['borderTopVariant'], 'border-top-variant'),
  new IconDefinition(iconLib['borderVertical'], 'border-vertical'),
  new IconDefinition(iconLib['bottleWine'], 'bottle-wine'),
  new IconDefinition(iconLib['bowTie'], 'bow-tie'),
  new IconDefinition(iconLib['bowl'], 'bowl'),
  new IconDefinition(iconLib['bowling'], 'bowling'),
  new IconDefinition(iconLib['box'], 'box'),
  new IconDefinition(iconLib['boxCutter'], 'box-cutter'),
  new IconDefinition(iconLib['boxShadow'], 'box-shadow'),
  new IconDefinition(iconLib['boxingGlove'], 'boxing-glove'),
  new IconDefinition(iconLib['braille'], 'braille'),
  new IconDefinition(iconLib['brain'], 'brain'),
  new IconDefinition(iconLib['breadSlice'], 'bread-slice'),
  new IconDefinition(iconLib['breadSliceOutline'], 'bread-slice-outline'),
  new IconDefinition(iconLib['bridge'], 'bridge'),
  new IconDefinition(iconLib['briefcase'], 'briefcase'),
  new IconDefinition(iconLib['briefcaseAccount'], 'briefcase-account'),
  new IconDefinition(iconLib['briefcaseAccountOutline'], 'briefcase-account-outline'),
  new IconDefinition(iconLib['briefcaseCheck'], 'briefcase-check'),
  new IconDefinition(iconLib['briefcaseDownload'], 'briefcase-download'),
  new IconDefinition(iconLib['briefcaseDownloadOutline'], 'briefcase-download-outline'),
  new IconDefinition(iconLib['briefcaseEdit'], 'briefcase-edit'),
  new IconDefinition(iconLib['briefcaseEditOutline'], 'briefcase-edit-outline'),
  new IconDefinition(iconLib['briefcaseMinus'], 'briefcase-minus'),
  new IconDefinition(iconLib['briefcaseMinusOutline'], 'briefcase-minus-outline'),
  new IconDefinition(iconLib['briefcaseOutline'], 'briefcase-outline'),
  new IconDefinition(iconLib['briefcasePlus'], 'briefcase-plus'),
  new IconDefinition(iconLib['briefcasePlusOutline'], 'briefcase-plus-outline'),
  new IconDefinition(iconLib['briefcaseRemove'], 'briefcase-remove'),
  new IconDefinition(iconLib['briefcaseRemoveOutline'], 'briefcase-remove-outline'),
  new IconDefinition(iconLib['briefcaseSearch'], 'briefcase-search'),
  new IconDefinition(iconLib['briefcaseSearchOutline'], 'briefcase-search-outline'),
  new IconDefinition(iconLib['briefcaseUpload'], 'briefcase-upload'),
  new IconDefinition(iconLib['briefcaseUploadOutline'], 'briefcase-upload-outline'),
  new IconDefinition(iconLib['brightness1'], 'brightness-1'),
  new IconDefinition(iconLib['brightness2'], 'brightness-2'),
  new IconDefinition(iconLib['brightness3'], 'brightness-3'),
  new IconDefinition(iconLib['brightness4'], 'brightness-4'),
  new IconDefinition(iconLib['brightness5'], 'brightness-5'),
  new IconDefinition(iconLib['brightness6'], 'brightness-6'),
  new IconDefinition(iconLib['brightness7'], 'brightness-7'),
  new IconDefinition(iconLib['brightnessAuto'], 'brightness-auto'),
  new IconDefinition(iconLib['brightnessPercent'], 'brightness-percent'),
  new IconDefinition(iconLib['broom'], 'broom'),
  new IconDefinition(iconLib['brush'], 'brush'),
  new IconDefinition(iconLib['buddhism'], 'buddhism'),
  new IconDefinition(iconLib['buffer'], 'buffer'),
  new IconDefinition(iconLib['bug'], 'bug'),
  new IconDefinition(iconLib['bugCheck'], 'bug-check'),
  new IconDefinition(iconLib['bugCheckOutline'], 'bug-check-outline'),
  new IconDefinition(iconLib['bugOutline'], 'bug-outline'),
  new IconDefinition(iconLib['bugle'], 'bugle'),
  new IconDefinition(iconLib['bulldozer'], 'bulldozer'),
  new IconDefinition(iconLib['bullet'], 'bullet'),
  new IconDefinition(iconLib['bulletinBoard'], 'bulletin-board'),
  new IconDefinition(iconLib['bullhorn'], 'bullhorn'),
  new IconDefinition(iconLib['bullhornOutline'], 'bullhorn-outline'),
  new IconDefinition(iconLib['bullseye'], 'bullseye'),
  new IconDefinition(iconLib['bullseyeArrow'], 'bullseye-arrow'),
  new IconDefinition(iconLib['bus'], 'bus'),
  new IconDefinition(iconLib['busAlert'], 'bus-alert'),
  new IconDefinition(iconLib['busArticulatedEnd'], 'bus-articulated-end'),
  new IconDefinition(iconLib['busArticulatedFront'], 'bus-articulated-front'),
  new IconDefinition(iconLib['busClock'], 'bus-clock'),
  new IconDefinition(iconLib['busDoubleDecker'], 'bus-double-decker'),
  new IconDefinition(iconLib['busSchool'], 'bus-school'),
  new IconDefinition(iconLib['busSide'], 'bus-side'),
  new IconDefinition(iconLib['cached'], 'cached'),
  new IconDefinition(iconLib['cactus'], 'cactus'),
  new IconDefinition(iconLib['cake'], 'cake'),
  new IconDefinition(iconLib['cakeLayered'], 'cake-layered'),
  new IconDefinition(iconLib['cakeVariant'], 'cake-variant'),
  new IconDefinition(iconLib['calculator'], 'calculator'),
  new IconDefinition(iconLib['calculatorVariant'], 'calculator-variant'),
  new IconDefinition(iconLib['calendar'], 'calendar'),
  new IconDefinition(iconLib['calendarAccount'], 'calendar-account'),
  new IconDefinition(iconLib['calendarAccountOutline'], 'calendar-account-outline'),
  new IconDefinition(iconLib['calendarAlert'], 'calendar-alert'),
  new IconDefinition(iconLib['calendarBlank'], 'calendar-blank'),
  new IconDefinition(iconLib['calendarBlankOutline'], 'calendar-blank-outline'),
  new IconDefinition(iconLib['calendarCheck'], 'calendar-check'),
  new IconDefinition(iconLib['calendarCheckOutline'], 'calendar-check-outline'),
  new IconDefinition(iconLib['calendarClock'], 'calendar-clock'),
  new IconDefinition(iconLib['calendarEdit'], 'calendar-edit'),
  new IconDefinition(iconLib['calendarExport'], 'calendar-export'),
  new IconDefinition(iconLib['calendarHeart'], 'calendar-heart'),
  new IconDefinition(iconLib['calendarImport'], 'calendar-import'),
  new IconDefinition(iconLib['calendarMinus'], 'calendar-minus'),
  new IconDefinition(iconLib['calendarMonth'], 'calendar-month'),
  new IconDefinition(iconLib['calendarMonthOutline'], 'calendar-month-outline'),
  new IconDefinition(iconLib['calendarMultiple'], 'calendar-multiple'),
  new IconDefinition(iconLib['calendarMultipleCheck'], 'calendar-multiple-check'),
  new IconDefinition(iconLib['calendarMultiselect'], 'calendar-multiselect'),
  new IconDefinition(iconLib['calendarOutline'], 'calendar-outline'),
  new IconDefinition(iconLib['calendarPlus'], 'calendar-plus'),
  new IconDefinition(iconLib['calendarQuestion'], 'calendar-question'),
  new IconDefinition(iconLib['calendarRange'], 'calendar-range'),
  new IconDefinition(iconLib['calendarRangeOutline'], 'calendar-range-outline'),
  new IconDefinition(iconLib['calendarRemove'], 'calendar-remove'),
  new IconDefinition(iconLib['calendarRemoveOutline'], 'calendar-remove-outline'),
  new IconDefinition(iconLib['calendarRepeat'], 'calendar-repeat'),
  new IconDefinition(iconLib['calendarRepeatOutline'], 'calendar-repeat-outline'),
  new IconDefinition(iconLib['calendarSearch'], 'calendar-search'),
  new IconDefinition(iconLib['calendarStar'], 'calendar-star'),
  new IconDefinition(iconLib['calendarText'], 'calendar-text'),
  new IconDefinition(iconLib['calendarTextOutline'], 'calendar-text-outline'),
  new IconDefinition(iconLib['calendarToday'], 'calendar-today'),
  new IconDefinition(iconLib['calendarWeek'], 'calendar-week'),
  new IconDefinition(iconLib['calendarWeekBegin'], 'calendar-week-begin'),
  new IconDefinition(iconLib['calendarWeekend'], 'calendar-weekend'),
  new IconDefinition(iconLib['calendarWeekendOutline'], 'calendar-weekend-outline'),
  new IconDefinition(iconLib['callMade'], 'call-made'),
  new IconDefinition(iconLib['callMerge'], 'call-merge'),
  new IconDefinition(iconLib['callMissed'], 'call-missed'),
  new IconDefinition(iconLib['callReceived'], 'call-received'),
  new IconDefinition(iconLib['callSplit'], 'call-split'),
  new IconDefinition(iconLib['camcorder'], 'camcorder'),
  new IconDefinition(iconLib['camcorderBox'], 'camcorder-box'),
  new IconDefinition(iconLib['camcorderBoxOff'], 'camcorder-box-off'),
  new IconDefinition(iconLib['camcorderOff'], 'camcorder-off'),
  new IconDefinition(iconLib['camera'], 'camera'),
  new IconDefinition(iconLib['cameraAccount'], 'camera-account'),
  new IconDefinition(iconLib['cameraBurst'], 'camera-burst'),
  new IconDefinition(iconLib['cameraControl'], 'camera-control'),
  new IconDefinition(iconLib['cameraEnhance'], 'camera-enhance'),
  new IconDefinition(iconLib['cameraEnhanceOutline'], 'camera-enhance-outline'),
  new IconDefinition(iconLib['cameraFront'], 'camera-front'),
  new IconDefinition(iconLib['cameraFrontVariant'], 'camera-front-variant'),
  new IconDefinition(iconLib['cameraGopro'], 'camera-gopro'),
  new IconDefinition(iconLib['cameraImage'], 'camera-image'),
  new IconDefinition(iconLib['cameraIris'], 'camera-iris'),
  new IconDefinition(iconLib['cameraMeteringCenter'], 'camera-metering-center'),
  new IconDefinition(iconLib['cameraMeteringMatrix'], 'camera-metering-matrix'),
  new IconDefinition(iconLib['cameraMeteringPartial'], 'camera-metering-partial'),
  new IconDefinition(iconLib['cameraMeteringSpot'], 'camera-metering-spot'),
  new IconDefinition(iconLib['cameraOff'], 'camera-off'),
  new IconDefinition(iconLib['cameraOutline'], 'camera-outline'),
  new IconDefinition(iconLib['cameraPartyMode'], 'camera-party-mode'),
  new IconDefinition(iconLib['cameraPlus'], 'camera-plus'),
  new IconDefinition(iconLib['cameraPlusOutline'], 'camera-plus-outline'),
  new IconDefinition(iconLib['cameraRear'], 'camera-rear'),
  new IconDefinition(iconLib['cameraRearVariant'], 'camera-rear-variant'),
  new IconDefinition(iconLib['cameraRetake'], 'camera-retake'),
  new IconDefinition(iconLib['cameraRetakeOutline'], 'camera-retake-outline'),
  new IconDefinition(iconLib['cameraSwitch'], 'camera-switch'),
  new IconDefinition(iconLib['cameraTimer'], 'camera-timer'),
  new IconDefinition(iconLib['cameraWireless'], 'camera-wireless'),
  new IconDefinition(iconLib['cameraWirelessOutline'], 'camera-wireless-outline'),
  new IconDefinition(iconLib['campfire'], 'campfire'),
  new IconDefinition(iconLib['cancel'], 'cancel'),
  new IconDefinition(iconLib['candle'], 'candle'),
  new IconDefinition(iconLib['candycane'], 'candycane'),
  new IconDefinition(iconLib['cannabis'], 'cannabis'),
  new IconDefinition(iconLib['capsLock'], 'caps-lock'),
  new IconDefinition(iconLib['car'], 'car'),
  new IconDefinition(iconLib['carBack'], 'car-back'),
  new IconDefinition(iconLib['carBattery'], 'car-battery'),
  new IconDefinition(iconLib['carBrakeAbs'], 'car-brake-abs'),
  new IconDefinition(iconLib['carBrakeAlert'], 'car-brake-alert'),
  new IconDefinition(iconLib['carBrakeHold'], 'car-brake-hold'),
  new IconDefinition(iconLib['carBrakeParking'], 'car-brake-parking'),
  new IconDefinition(iconLib['carConnected'], 'car-connected'),
  new IconDefinition(iconLib['carConvertible'], 'car-convertible'),
  new IconDefinition(iconLib['carCruiseControl'], 'car-cruise-control'),
  new IconDefinition(iconLib['carDefrostFront'], 'car-defrost-front'),
  new IconDefinition(iconLib['carDefrostRear'], 'car-defrost-rear'),
  new IconDefinition(iconLib['carDoor'], 'car-door'),
  new IconDefinition(iconLib['carElectric'], 'car-electric'),
  new IconDefinition(iconLib['carEsp'], 'car-esp'),
  new IconDefinition(iconLib['carEstate'], 'car-estate'),
  new IconDefinition(iconLib['carHatchback'], 'car-hatchback'),
  new IconDefinition(iconLib['carKey'], 'car-key'),
  new IconDefinition(iconLib['carLightDimmed'], 'car-light-dimmed'),
  new IconDefinition(iconLib['carLightFog'], 'car-light-fog'),
  new IconDefinition(iconLib['carLightHigh'], 'car-light-high'),
  new IconDefinition(iconLib['carLimousine'], 'car-limousine'),
  new IconDefinition(iconLib['carMultiple'], 'car-multiple'),
  new IconDefinition(iconLib['carOff'], 'car-off'),
  new IconDefinition(iconLib['carParkingLights'], 'car-parking-lights'),
  new IconDefinition(iconLib['carPickup'], 'car-pickup'),
  new IconDefinition(iconLib['carSide'], 'car-side'),
  new IconDefinition(iconLib['carSports'], 'car-sports'),
  new IconDefinition(iconLib['carTireAlert'], 'car-tire-alert'),
  new IconDefinition(iconLib['carTractionControl'], 'car-traction-control'),
  new IconDefinition(iconLib['carWash'], 'car-wash'),
  new IconDefinition(iconLib['caravan'], 'caravan'),
  new IconDefinition(iconLib['card'], 'card'),
  new IconDefinition(iconLib['cardBulleted'], 'card-bulleted'),
  new IconDefinition(iconLib['cardBulletedOff'], 'card-bulleted-off'),
  new IconDefinition(iconLib['cardBulletedOffOutline'], 'card-bulleted-off-outline'),
  new IconDefinition(iconLib['cardBulletedOutline'], 'card-bulleted-outline'),
  new IconDefinition(iconLib['cardBulletedSettings'], 'card-bulleted-settings'),
  new IconDefinition(iconLib['cardBulletedSettingsOutline'], 'card-bulleted-settings-outline'),
  new IconDefinition(iconLib['cardOutline'], 'card-outline'),
  new IconDefinition(iconLib['cardText'], 'card-text'),
  new IconDefinition(iconLib['cardTextOutline'], 'card-text-outline'),
  new IconDefinition(iconLib['cards'], 'cards'),
  new IconDefinition(iconLib['cardsClub'], 'cards-club'),
  new IconDefinition(iconLib['cardsDiamond'], 'cards-diamond'),
  new IconDefinition(iconLib['cardsHeart'], 'cards-heart'),
  new IconDefinition(iconLib['cardsOutline'], 'cards-outline'),
  new IconDefinition(iconLib['cardsPlayingOutline'], 'cards-playing-outline'),
  new IconDefinition(iconLib['cardsSpade'], 'cards-spade'),
  new IconDefinition(iconLib['cardsVariant'], 'cards-variant'),
  new IconDefinition(iconLib['carrot'], 'carrot'),
  new IconDefinition(iconLib['carryOnBagCheck'], 'carry-on-bag-check'),
  new IconDefinition(iconLib['cart'], 'cart'),
  new IconDefinition(iconLib['cartArrowDown'], 'cart-arrow-down'),
  new IconDefinition(iconLib['cartArrowRight'], 'cart-arrow-right'),
  new IconDefinition(iconLib['cartArrowUp'], 'cart-arrow-up'),
  new IconDefinition(iconLib['cartMinus'], 'cart-minus'),
  new IconDefinition(iconLib['cartOff'], 'cart-off'),
  new IconDefinition(iconLib['cartOutline'], 'cart-outline'),
  new IconDefinition(iconLib['cartPlus'], 'cart-plus'),
  new IconDefinition(iconLib['cartRemove'], 'cart-remove'),
  new IconDefinition(iconLib['caseSensitiveAlt'], 'case-sensitive-alt'),
  new IconDefinition(iconLib['cash'], 'cash'),
  new IconDefinition(iconLib['cash100'], 'cash-100'),
  new IconDefinition(iconLib['cashMarker'], 'cash-marker'),
  new IconDefinition(iconLib['cashMultiple'], 'cash-multiple'),
  new IconDefinition(iconLib['cashRefund'], 'cash-refund'),
  new IconDefinition(iconLib['cashRegister'], 'cash-register'),
  new IconDefinition(iconLib['cashUsd'], 'cash-usd'),
  new IconDefinition(iconLib['cassette'], 'cassette'),
  new IconDefinition(iconLib['cast'], 'cast'),
  new IconDefinition(iconLib['castConnected'], 'cast-connected'),
  new IconDefinition(iconLib['castEducation'], 'cast-education'),
  new IconDefinition(iconLib['castOff'], 'cast-off'),
  new IconDefinition(iconLib['castle'], 'castle'),
  new IconDefinition(iconLib['cat'], 'cat'),
  new IconDefinition(iconLib['cctv'], 'cctv'),
  new IconDefinition(iconLib['ceilingLight'], 'ceiling-light'),
  new IconDefinition(iconLib['cellphone'], 'cellphone'),
  new IconDefinition(iconLib['cellphoneAndroid'], 'cellphone-android'),
  new IconDefinition(iconLib['cellphoneArrowDown'], 'cellphone-arrow-down'),
  new IconDefinition(iconLib['cellphoneBasic'], 'cellphone-basic'),
  new IconDefinition(iconLib['cellphoneDock'], 'cellphone-dock'),
  new IconDefinition(iconLib['cellphoneErase'], 'cellphone-erase'),
  new IconDefinition(iconLib['cellphoneIphone'], 'cellphone-iphone'),
  new IconDefinition(iconLib['cellphoneKey'], 'cellphone-key'),
  new IconDefinition(iconLib['cellphoneLink'], 'cellphone-link'),
  new IconDefinition(iconLib['cellphoneLinkOff'], 'cellphone-link-off'),
  new IconDefinition(iconLib['cellphoneLock'], 'cellphone-lock'),
  new IconDefinition(iconLib['cellphoneMessage'], 'cellphone-message'),
  new IconDefinition(iconLib['cellphoneNfc'], 'cellphone-nfc'),
  new IconDefinition(iconLib['cellphoneOff'], 'cellphone-off'),
  new IconDefinition(iconLib['cellphoneScreenshot'], 'cellphone-screenshot'),
  new IconDefinition(iconLib['cellphoneSettings'], 'cellphone-settings'),
  new IconDefinition(iconLib['cellphoneSettingsVariant'], 'cellphone-settings-variant'),
  new IconDefinition(iconLib['cellphoneSound'], 'cellphone-sound'),
  new IconDefinition(iconLib['cellphoneText'], 'cellphone-text'),
  new IconDefinition(iconLib['cellphoneWireless'], 'cellphone-wireless'),
  new IconDefinition(iconLib['celticCross'], 'celtic-cross'),
  new IconDefinition(iconLib['certificate'], 'certificate'),
  new IconDefinition(iconLib['chairSchool'], 'chair-school'),
  new IconDefinition(iconLib['charity'], 'charity'),
  new IconDefinition(iconLib['chartArc'], 'chart-arc'),
  new IconDefinition(iconLib['chartAreaspline'], 'chart-areaspline'),
  new IconDefinition(iconLib['chartAreasplineVariant'], 'chart-areaspline-variant'),
  new IconDefinition(iconLib['chartBar'], 'chart-bar'),
  new IconDefinition(iconLib['chartBarStacked'], 'chart-bar-stacked'),
  new IconDefinition(iconLib['chartBellCurve'], 'chart-bell-curve'),
  new IconDefinition(iconLib['chartBubble'], 'chart-bubble'),
  new IconDefinition(iconLib['chartDonut'], 'chart-donut'),
  new IconDefinition(iconLib['chartDonutVariant'], 'chart-donut-variant'),
  new IconDefinition(iconLib['chartGantt'], 'chart-gantt'),
  new IconDefinition(iconLib['chartHistogram'], 'chart-histogram'),
  new IconDefinition(iconLib['chartLine'], 'chart-line'),
  new IconDefinition(iconLib['chartLineStacked'], 'chart-line-stacked'),
  new IconDefinition(iconLib['chartLineVariant'], 'chart-line-variant'),
  new IconDefinition(iconLib['chartMultiline'], 'chart-multiline'),
  new IconDefinition(iconLib['chartPie'], 'chart-pie'),
  new IconDefinition(iconLib['chartScatterPlot'], 'chart-scatter-plot'),
  new IconDefinition(iconLib['chartScatterPlotHexbin'], 'chart-scatter-plot-hexbin'),
  new IconDefinition(iconLib['chartTimeline'], 'chart-timeline'),
  new IconDefinition(iconLib['chartTimelineVariant'], 'chart-timeline-variant'),
  new IconDefinition(iconLib['chartTree'], 'chart-tree'),
  new IconDefinition(iconLib['chat'], 'chat'),
  new IconDefinition(iconLib['chatAlert'], 'chat-alert'),
  new IconDefinition(iconLib['chatOutline'], 'chat-outline'),
  new IconDefinition(iconLib['chatProcessing'], 'chat-processing'),
  new IconDefinition(iconLib['check'], 'check'),
  new IconDefinition(iconLib['checkAll'], 'check-all'),
  new IconDefinition(iconLib['checkBold'], 'check-bold'),
  new IconDefinition(iconLib['checkBoxMultipleOutline'], 'check-box-multiple-outline'),
  new IconDefinition(iconLib['checkBoxOutline'], 'check-box-outline'),
  new IconDefinition(iconLib['checkCircle'], 'check-circle'),
  new IconDefinition(iconLib['checkCircleOutline'], 'check-circle-outline'),
  new IconDefinition(iconLib['checkDecagram'], 'check-decagram'),
  new IconDefinition(iconLib['checkNetwork'], 'check-network'),
  new IconDefinition(iconLib['checkNetworkOutline'], 'check-network-outline'),
  new IconDefinition(iconLib['checkOutline'], 'check-outline'),
  new IconDefinition(iconLib['checkUnderline'], 'check-underline'),
  new IconDefinition(iconLib['checkUnderlineCircle'], 'check-underline-circle'),
  new IconDefinition(iconLib['checkUnderlineCircleOutline'], 'check-underline-circle-outline'),
  new IconDefinition(iconLib['checkbook'], 'checkbook'),
  new IconDefinition(iconLib['checkboxBlank'], 'checkbox-blank'),
  new IconDefinition(iconLib['checkboxBlankCircle'], 'checkbox-blank-circle'),
  new IconDefinition(iconLib['checkboxBlankCircleOutline'], 'checkbox-blank-circle-outline'),
  new IconDefinition(iconLib['checkboxBlankOutline'], 'checkbox-blank-outline'),
  new IconDefinition(iconLib['checkboxIntermediate'], 'checkbox-intermediate'),
  new IconDefinition(iconLib['checkboxMarked'], 'checkbox-marked'),
  new IconDefinition(iconLib['checkboxMarkedCircle'], 'checkbox-marked-circle'),
  new IconDefinition(iconLib['checkboxMarkedCircleOutline'], 'checkbox-marked-circle-outline'),
  new IconDefinition(iconLib['checkboxMarkedOutline'], 'checkbox-marked-outline'),
  new IconDefinition(iconLib['checkboxMultipleBlank'], 'checkbox-multiple-blank'),
  new IconDefinition(iconLib['checkboxMultipleBlankCircle'], 'checkbox-multiple-blank-circle'),
  new IconDefinition(iconLib['checkboxMultipleBlankCircleOutline'], 'checkbox-multiple-blank-circle-outline'),
  new IconDefinition(iconLib['checkboxMultipleBlankOutline'], 'checkbox-multiple-blank-outline'),
  new IconDefinition(iconLib['checkboxMultipleMarked'], 'checkbox-multiple-marked'),
  new IconDefinition(iconLib['checkboxMultipleMarkedCircle'], 'checkbox-multiple-marked-circle'),
  new IconDefinition(iconLib['checkboxMultipleMarkedCircleOutline'], 'checkbox-multiple-marked-circle-outline'),
  new IconDefinition(iconLib['checkboxMultipleMarkedOutline'], 'checkbox-multiple-marked-outline'),
  new IconDefinition(iconLib['checkerboard'], 'checkerboard'),
  new IconDefinition(iconLib['chefHat'], 'chef-hat'),
  new IconDefinition(iconLib['chemicalWeapon'], 'chemical-weapon'),
  new IconDefinition(iconLib['chessBishop'], 'chess-bishop'),
  new IconDefinition(iconLib['chessKing'], 'chess-king'),
  new IconDefinition(iconLib['chessKnight'], 'chess-knight'),
  new IconDefinition(iconLib['chessPawn'], 'chess-pawn'),
  new IconDefinition(iconLib['chessQueen'], 'chess-queen'),
  new IconDefinition(iconLib['chessRook'], 'chess-rook'),
  new IconDefinition(iconLib['chevronDoubleDown'], 'chevron-double-down'),
  new IconDefinition(iconLib['chevronDoubleLeft'], 'chevron-double-left'),
  new IconDefinition(iconLib['chevronDoubleRight'], 'chevron-double-right'),
  new IconDefinition(iconLib['chevronDoubleUp'], 'chevron-double-up'),
  new IconDefinition(iconLib['chevronDown'], 'chevron-down'),
  new IconDefinition(iconLib['chevronDownBox'], 'chevron-down-box'),
  new IconDefinition(iconLib['chevronDownBoxOutline'], 'chevron-down-box-outline'),
  new IconDefinition(iconLib['chevronDownCircle'], 'chevron-down-circle'),
  new IconDefinition(iconLib['chevronDownCircleOutline'], 'chevron-down-circle-outline'),
  new IconDefinition(iconLib['chevronLeft'], 'chevron-left'),
  new IconDefinition(iconLib['chevronLeftBox'], 'chevron-left-box'),
  new IconDefinition(iconLib['chevronLeftBoxOutline'], 'chevron-left-box-outline'),
  new IconDefinition(iconLib['chevronLeftCircle'], 'chevron-left-circle'),
  new IconDefinition(iconLib['chevronLeftCircleOutline'], 'chevron-left-circle-outline'),
  new IconDefinition(iconLib['chevronRight'], 'chevron-right'),
  new IconDefinition(iconLib['chevronRightBox'], 'chevron-right-box'),
  new IconDefinition(iconLib['chevronRightBoxOutline'], 'chevron-right-box-outline'),
  new IconDefinition(iconLib['chevronRightCircle'], 'chevron-right-circle'),
  new IconDefinition(iconLib['chevronRightCircleOutline'], 'chevron-right-circle-outline'),
  new IconDefinition(iconLib['chevronTripleDown'], 'chevron-triple-down'),
  new IconDefinition(iconLib['chevronTripleLeft'], 'chevron-triple-left'),
  new IconDefinition(iconLib['chevronTripleRight'], 'chevron-triple-right'),
  new IconDefinition(iconLib['chevronTripleUp'], 'chevron-triple-up'),
  new IconDefinition(iconLib['chevronUp'], 'chevron-up'),
  new IconDefinition(iconLib['chevronUpBox'], 'chevron-up-box'),
  new IconDefinition(iconLib['chevronUpBoxOutline'], 'chevron-up-box-outline'),
  new IconDefinition(iconLib['chevronUpCircle'], 'chevron-up-circle'),
  new IconDefinition(iconLib['chevronUpCircleOutline'], 'chevron-up-circle-outline'),
  new IconDefinition(iconLib['chiliHot'], 'chili-hot'),
  new IconDefinition(iconLib['chiliMedium'], 'chili-medium'),
  new IconDefinition(iconLib['chiliMild'], 'chili-mild'),
  new IconDefinition(iconLib['chip'], 'chip'),
  new IconDefinition(iconLib['christianity'], 'christianity'),
  new IconDefinition(iconLib['christianityOutline'], 'christianity-outline'),
  new IconDefinition(iconLib['church'], 'church'),
  new IconDefinition(iconLib['circle'], 'circle'),
  new IconDefinition(iconLib['circleDouble'], 'circle-double'),
  new IconDefinition(iconLib['circleEditOutline'], 'circle-edit-outline'),
  new IconDefinition(iconLib['circleExpand'], 'circle-expand'),
  new IconDefinition(iconLib['circleMedium'], 'circle-medium'),
  new IconDefinition(iconLib['circleOutline'], 'circle-outline'),
  new IconDefinition(iconLib['circleSlice1'], 'circle-slice-1'),
  new IconDefinition(iconLib['circleSlice2'], 'circle-slice-2'),
  new IconDefinition(iconLib['circleSlice3'], 'circle-slice-3'),
  new IconDefinition(iconLib['circleSlice4'], 'circle-slice-4'),
  new IconDefinition(iconLib['circleSlice5'], 'circle-slice-5'),
  new IconDefinition(iconLib['circleSlice6'], 'circle-slice-6'),
  new IconDefinition(iconLib['circleSlice7'], 'circle-slice-7'),
  new IconDefinition(iconLib['circleSlice8'], 'circle-slice-8'),
  new IconDefinition(iconLib['circleSmall'], 'circle-small'),
  new IconDefinition(iconLib['circularSaw'], 'circular-saw'),
  new IconDefinition(iconLib['ciscoWebex'], 'cisco-webex'),
  new IconDefinition(iconLib['city'], 'city'),
  new IconDefinition(iconLib['cityVariant'], 'city-variant'),
  new IconDefinition(iconLib['cityVariantOutline'], 'city-variant-outline'),
  new IconDefinition(iconLib['clipboard'], 'clipboard'),
  new IconDefinition(iconLib['clipboardAccount'], 'clipboard-account'),
  new IconDefinition(iconLib['clipboardAccountOutline'], 'clipboard-account-outline'),
  new IconDefinition(iconLib['clipboardAlert'], 'clipboard-alert'),
  new IconDefinition(iconLib['clipboardAlertOutline'], 'clipboard-alert-outline'),
  new IconDefinition(iconLib['clipboardArrowDown'], 'clipboard-arrow-down'),
  new IconDefinition(iconLib['clipboardArrowDownOutline'], 'clipboard-arrow-down-outline'),
  new IconDefinition(iconLib['clipboardArrowLeft'], 'clipboard-arrow-left'),
  new IconDefinition(iconLib['clipboardArrowLeftOutline'], 'clipboard-arrow-left-outline'),
  new IconDefinition(iconLib['clipboardArrowRight'], 'clipboard-arrow-right'),
  new IconDefinition(iconLib['clipboardArrowRightOutline'], 'clipboard-arrow-right-outline'),
  new IconDefinition(iconLib['clipboardArrowUp'], 'clipboard-arrow-up'),
  new IconDefinition(iconLib['clipboardArrowUpOutline'], 'clipboard-arrow-up-outline'),
  new IconDefinition(iconLib['clipboardCheck'], 'clipboard-check'),
  new IconDefinition(iconLib['clipboardCheckOutline'], 'clipboard-check-outline'),
  new IconDefinition(iconLib['clipboardFlow'], 'clipboard-flow'),
  new IconDefinition(iconLib['clipboardOutline'], 'clipboard-outline'),
  new IconDefinition(iconLib['clipboardPlay'], 'clipboard-play'),
  new IconDefinition(iconLib['clipboardPlayOutline'], 'clipboard-play-outline'),
  new IconDefinition(iconLib['clipboardPlus'], 'clipboard-plus'),
  new IconDefinition(iconLib['clipboardPulse'], 'clipboard-pulse'),
  new IconDefinition(iconLib['clipboardPulseOutline'], 'clipboard-pulse-outline'),
  new IconDefinition(iconLib['clipboardText'], 'clipboard-text'),
  new IconDefinition(iconLib['clipboardTextOutline'], 'clipboard-text-outline'),
  new IconDefinition(iconLib['clipboardTextPlay'], 'clipboard-text-play'),
  new IconDefinition(iconLib['clipboardTextPlayOutline'], 'clipboard-text-play-outline'),
  new IconDefinition(iconLib['clippy'], 'clippy'),
  new IconDefinition(iconLib['clock'], 'clock'),
  new IconDefinition(iconLib['clockAlert'], 'clock-alert'),
  new IconDefinition(iconLib['clockAlertOutline'], 'clock-alert-outline'),
  new IconDefinition(iconLib['clockDigital'], 'clock-digital'),
  new IconDefinition(iconLib['clockEnd'], 'clock-end'),
  new IconDefinition(iconLib['clockFast'], 'clock-fast'),
  new IconDefinition(iconLib['clockIn'], 'clock-in'),
  new IconDefinition(iconLib['clockOut'], 'clock-out'),
  new IconDefinition(iconLib['clockOutline'], 'clock-outline'),
  new IconDefinition(iconLib['clockStart'], 'clock-start'),
  new IconDefinition(iconLib['close'], 'close'),
  new IconDefinition(iconLib['closeBox'], 'close-box'),
  new IconDefinition(iconLib['closeBoxMultiple'], 'close-box-multiple'),
  new IconDefinition(iconLib['closeBoxMultipleOutline'], 'close-box-multiple-outline'),
  new IconDefinition(iconLib['closeBoxOutline'], 'close-box-outline'),
  new IconDefinition(iconLib['closeCircle'], 'close-circle'),
  new IconDefinition(iconLib['closeCircleOutline'], 'close-circle-outline'),
  new IconDefinition(iconLib['closeNetwork'], 'close-network'),
  new IconDefinition(iconLib['closeNetworkOutline'], 'close-network-outline'),
  new IconDefinition(iconLib['closeOctagon'], 'close-octagon'),
  new IconDefinition(iconLib['closeOctagonOutline'], 'close-octagon-outline'),
  new IconDefinition(iconLib['closeOutline'], 'close-outline'),
  new IconDefinition(iconLib['closedCaption'], 'closed-caption'),
  new IconDefinition(iconLib['closedCaptionOutline'], 'closed-caption-outline'),
  new IconDefinition(iconLib['cloud'], 'cloud'),
  new IconDefinition(iconLib['cloudAlert'], 'cloud-alert'),
  new IconDefinition(iconLib['cloudBraces'], 'cloud-braces'),
  new IconDefinition(iconLib['cloudCheck'], 'cloud-check'),
  new IconDefinition(iconLib['cloudCircle'], 'cloud-circle'),
  new IconDefinition(iconLib['cloudDownload'], 'cloud-download'),
  new IconDefinition(iconLib['cloudDownloadOutline'], 'cloud-download-outline'),
  new IconDefinition(iconLib['cloudOffOutline'], 'cloud-off-outline'),
  new IconDefinition(iconLib['cloudOutline'], 'cloud-outline'),
  new IconDefinition(iconLib['cloudPrint'], 'cloud-print'),
  new IconDefinition(iconLib['cloudPrintOutline'], 'cloud-print-outline'),
  new IconDefinition(iconLib['cloudQuestion'], 'cloud-question'),
  new IconDefinition(iconLib['cloudSearch'], 'cloud-search'),
  new IconDefinition(iconLib['cloudSearchOutline'], 'cloud-search-outline'),
  new IconDefinition(iconLib['cloudSync'], 'cloud-sync'),
  new IconDefinition(iconLib['cloudTags'], 'cloud-tags'),
  new IconDefinition(iconLib['cloudUpload'], 'cloud-upload'),
  new IconDefinition(iconLib['cloudUploadOutline'], 'cloud-upload-outline'),
  new IconDefinition(iconLib['clover'], 'clover'),
  new IconDefinition(iconLib['codeArray'], 'code-array'),
  new IconDefinition(iconLib['codeBraces'], 'code-braces'),
  new IconDefinition(iconLib['codeBrackets'], 'code-brackets'),
  new IconDefinition(iconLib['codeEqual'], 'code-equal'),
  new IconDefinition(iconLib['codeGreaterThan'], 'code-greater-than'),
  new IconDefinition(iconLib['codeGreaterThanOrEqual'], 'code-greater-than-or-equal'),
  new IconDefinition(iconLib['codeLessThan'], 'code-less-than'),
  new IconDefinition(iconLib['codeLessThanOrEqual'], 'code-less-than-or-equal'),
  new IconDefinition(iconLib['codeNotEqual'], 'code-not-equal'),
  new IconDefinition(iconLib['codeNotEqualVariant'], 'code-not-equal-variant'),
  new IconDefinition(iconLib['codeParentheses'], 'code-parentheses'),
  new IconDefinition(iconLib['codeString'], 'code-string'),
  new IconDefinition(iconLib['codeTags'], 'code-tags'),
  new IconDefinition(iconLib['codeTagsCheck'], 'code-tags-check'),
  new IconDefinition(iconLib['codepen'], 'codepen'),
  new IconDefinition(iconLib['coffee'], 'coffee'),
  new IconDefinition(iconLib['coffeeOutline'], 'coffee-outline'),
  new IconDefinition(iconLib['coffeeToGo'], 'coffee-to-go'),
  new IconDefinition(iconLib['coffin'], 'coffin'),
  new IconDefinition(iconLib['cogs'], 'cogs'),
  new IconDefinition(iconLib['coin'], 'coin'),
  new IconDefinition(iconLib['coins'], 'coins'),
  new IconDefinition(iconLib['collage'], 'collage'),
  new IconDefinition(iconLib['collapseAll'], 'collapse-all'),
  new IconDefinition(iconLib['collapseAllOutline'], 'collapse-all-outline'),
  new IconDefinition(iconLib['colorHelper'], 'color-helper'),
  new IconDefinition(iconLib['comma'], 'comma'),
  new IconDefinition(iconLib['commaBox'], 'comma-box'),
  new IconDefinition(iconLib['commaBoxOutline'], 'comma-box-outline'),
  new IconDefinition(iconLib['commaCircle'], 'comma-circle'),
  new IconDefinition(iconLib['commaCircleOutline'], 'comma-circle-outline'),
  new IconDefinition(iconLib['comment'], 'comment'),
  new IconDefinition(iconLib['commentAccount'], 'comment-account'),
  new IconDefinition(iconLib['commentAccountOutline'], 'comment-account-outline'),
  new IconDefinition(iconLib['commentAlert'], 'comment-alert'),
  new IconDefinition(iconLib['commentAlertOutline'], 'comment-alert-outline'),
  new IconDefinition(iconLib['commentArrowLeft'], 'comment-arrow-left'),
  new IconDefinition(iconLib['commentArrowLeftOutline'], 'comment-arrow-left-outline'),
  new IconDefinition(iconLib['commentArrowRight'], 'comment-arrow-right'),
  new IconDefinition(iconLib['commentArrowRightOutline'], 'comment-arrow-right-outline'),
  new IconDefinition(iconLib['commentCheck'], 'comment-check'),
  new IconDefinition(iconLib['commentCheckOutline'], 'comment-check-outline'),
  new IconDefinition(iconLib['commentEye'], 'comment-eye'),
  new IconDefinition(iconLib['commentEyeOutline'], 'comment-eye-outline'),
  new IconDefinition(iconLib['commentMultiple'], 'comment-multiple'),
  new IconDefinition(iconLib['commentMultipleOutline'], 'comment-multiple-outline'),
  new IconDefinition(iconLib['commentOutline'], 'comment-outline'),
  new IconDefinition(iconLib['commentPlus'], 'comment-plus'),
  new IconDefinition(iconLib['commentPlusOutline'], 'comment-plus-outline'),
  new IconDefinition(iconLib['commentProcessing'], 'comment-processing'),
  new IconDefinition(iconLib['commentProcessingOutline'], 'comment-processing-outline'),
  new IconDefinition(iconLib['commentQuestion'], 'comment-question'),
  new IconDefinition(iconLib['commentQuestionOutline'], 'comment-question-outline'),
  new IconDefinition(iconLib['commentRemove'], 'comment-remove'),
  new IconDefinition(iconLib['commentRemoveOutline'], 'comment-remove-outline'),
  new IconDefinition(iconLib['commentSearch'], 'comment-search'),
  new IconDefinition(iconLib['commentSearchOutline'], 'comment-search-outline'),
  new IconDefinition(iconLib['commentText'], 'comment-text'),
  new IconDefinition(iconLib['commentTextMultiple'], 'comment-text-multiple'),
  new IconDefinition(iconLib['commentTextMultipleOutline'], 'comment-text-multiple-outline'),
  new IconDefinition(iconLib['commentTextOutline'], 'comment-text-outline'),
  new IconDefinition(iconLib['compare'], 'compare'),
  new IconDefinition(iconLib['compass'], 'compass'),
  new IconDefinition(iconLib['compassOff'], 'compass-off'),
  new IconDefinition(iconLib['compassOffOutline'], 'compass-off-outline'),
  new IconDefinition(iconLib['compassOutline'], 'compass-outline'),
  new IconDefinition(iconLib['console'], 'console'),
  new IconDefinition(iconLib['consoleLine'], 'console-line'),
  new IconDefinition(iconLib['consoleNetwork'], 'console-network'),
  new IconDefinition(iconLib['consoleNetworkOutline'], 'console-network-outline'),
  new IconDefinition(iconLib['contactMail'], 'contact-mail'),
  new IconDefinition(iconLib['contactMailOutline'], 'contact-mail-outline'),
  new IconDefinition(iconLib['contactPhone'], 'contact-phone'),
  new IconDefinition(iconLib['contactPhoneOutline'], 'contact-phone-outline'),
  new IconDefinition(iconLib['contactlessPayment'], 'contactless-payment'),
  new IconDefinition(iconLib['contacts'], 'contacts'),
  new IconDefinition(iconLib['contain'], 'contain'),
  new IconDefinition(iconLib['containEnd'], 'contain-end'),
  new IconDefinition(iconLib['containStart'], 'contain-start'),
  new IconDefinition(iconLib['contentCopy'], 'content-copy'),
  new IconDefinition(iconLib['contentCut'], 'content-cut'),
  new IconDefinition(iconLib['contentDuplicate'], 'content-duplicate'),
  new IconDefinition(iconLib['contentPaste'], 'content-paste'),
  new IconDefinition(iconLib['contentSave'], 'content-save'),
  new IconDefinition(iconLib['contentSaveAll'], 'content-save-all'),
  new IconDefinition(iconLib['contentSaveEdit'], 'content-save-edit'),
  new IconDefinition(iconLib['contentSaveEditOutline'], 'content-save-edit-outline'),
  new IconDefinition(iconLib['contentSaveMove'], 'content-save-move'),
  new IconDefinition(iconLib['contentSaveMoveOutline'], 'content-save-move-outline'),
  new IconDefinition(iconLib['contentSaveOutline'], 'content-save-outline'),
  new IconDefinition(iconLib['contentSaveSettings'], 'content-save-settings'),
  new IconDefinition(iconLib['contentSaveSettingsOutline'], 'content-save-settings-outline'),
  new IconDefinition(iconLib['contrast'], 'contrast'),
  new IconDefinition(iconLib['contrastBox'], 'contrast-box'),
  new IconDefinition(iconLib['contrastCircle'], 'contrast-circle'),
  new IconDefinition(iconLib['controllerClassic'], 'controller-classic'),
  new IconDefinition(iconLib['controllerClassicOutline'], 'controller-classic-outline'),
  new IconDefinition(iconLib['cookie'], 'cookie'),
  new IconDefinition(iconLib['copyright'], 'copyright'),
  new IconDefinition(iconLib['cordova'], 'cordova'),
  new IconDefinition(iconLib['corn'], 'corn'),
  new IconDefinition(iconLib['counter'], 'counter'),
  new IconDefinition(iconLib['cow'], 'cow'),
  new IconDefinition(iconLib['cowboy'], 'cowboy'),
  new IconDefinition(iconLib['cpu32Bit'], 'cpu-32-bit'),
  new IconDefinition(iconLib['cpu64Bit'], 'cpu-64-bit'),
  new IconDefinition(iconLib['crane'], 'crane'),
  new IconDefinition(iconLib['creation'], 'creation'),
  new IconDefinition(iconLib['creativeCommons'], 'creative-commons'),
  new IconDefinition(iconLib['creditCard'], 'credit-card'),
  new IconDefinition(iconLib['creditCardClock'], 'credit-card-clock'),
  new IconDefinition(iconLib['creditCardClockOutline'], 'credit-card-clock-outline'),
  new IconDefinition(iconLib['creditCardMarker'], 'credit-card-marker'),
  new IconDefinition(iconLib['creditCardMultiple'], 'credit-card-multiple'),
  new IconDefinition(iconLib['creditCardOff'], 'credit-card-off'),
  new IconDefinition(iconLib['creditCardPlus'], 'credit-card-plus'),
  new IconDefinition(iconLib['creditCardRefund'], 'credit-card-refund'),
  new IconDefinition(iconLib['creditCardScan'], 'credit-card-scan'),
  new IconDefinition(iconLib['creditCardSettings'], 'credit-card-settings'),
  new IconDefinition(iconLib['creditCardWireless'], 'credit-card-wireless'),
  new IconDefinition(iconLib['cricket'], 'cricket'),
  new IconDefinition(iconLib['crop'], 'crop'),
  new IconDefinition(iconLib['cropFree'], 'crop-free'),
  new IconDefinition(iconLib['cropLandscape'], 'crop-landscape'),
  new IconDefinition(iconLib['cropPortrait'], 'crop-portrait'),
  new IconDefinition(iconLib['cropRotate'], 'crop-rotate'),
  new IconDefinition(iconLib['cropSquare'], 'crop-square'),
  new IconDefinition(iconLib['crosshairs'], 'crosshairs'),
  new IconDefinition(iconLib['crosshairsGps'], 'crosshairs-gps'),
  new IconDefinition(iconLib['crown'], 'crown'),
  new IconDefinition(iconLib['cryengine'], 'cryengine'),
  new IconDefinition(iconLib['crystalBall'], 'crystal-ball'),
  new IconDefinition(iconLib['cube'], 'cube'),
  new IconDefinition(iconLib['cubeOutline'], 'cube-outline'),
  new IconDefinition(iconLib['cubeScan'], 'cube-scan'),
  new IconDefinition(iconLib['cubeSend'], 'cube-send'),
  new IconDefinition(iconLib['cubeUnfolded'], 'cube-unfolded'),
  new IconDefinition(iconLib['cup'], 'cup'),
  new IconDefinition(iconLib['cupOff'], 'cup-off'),
  new IconDefinition(iconLib['cupWater'], 'cup-water'),
  new IconDefinition(iconLib['cupcake'], 'cupcake'),
  new IconDefinition(iconLib['curling'], 'curling'),
  new IconDefinition(iconLib['currencyBdt'], 'currency-bdt'),
  new IconDefinition(iconLib['currencyBrl'], 'currency-brl'),
  new IconDefinition(iconLib['currencyBtc'], 'currency-btc'),
  new IconDefinition(iconLib['currencyChf'], 'currency-chf'),
  new IconDefinition(iconLib['currencyCny'], 'currency-cny'),
  new IconDefinition(iconLib['currencyEth'], 'currency-eth'),
  new IconDefinition(iconLib['currencyEur'], 'currency-eur'),
  new IconDefinition(iconLib['currencyGbp'], 'currency-gbp'),
  new IconDefinition(iconLib['currencyIls'], 'currency-ils'),
  new IconDefinition(iconLib['currencyInr'], 'currency-inr'),
  new IconDefinition(iconLib['currencyJpy'], 'currency-jpy'),
  new IconDefinition(iconLib['currencyKrw'], 'currency-krw'),
  new IconDefinition(iconLib['currencyKzt'], 'currency-kzt'),
  new IconDefinition(iconLib['currencyNgn'], 'currency-ngn'),
  new IconDefinition(iconLib['currencyPhp'], 'currency-php'),
  new IconDefinition(iconLib['currencyRial'], 'currency-rial'),
  new IconDefinition(iconLib['currencyRub'], 'currency-rub'),
  new IconDefinition(iconLib['currencySign'], 'currency-sign'),
  new IconDefinition(iconLib['currencyTry'], 'currency-try'),
  new IconDefinition(iconLib['currencyTwd'], 'currency-twd'),
  new IconDefinition(iconLib['currencyUsd'], 'currency-usd'),
  new IconDefinition(iconLib['currencyUsdOff'], 'currency-usd-off'),
  new IconDefinition(iconLib['currentAc'], 'current-ac'),
  new IconDefinition(iconLib['currentDc'], 'current-dc'),
  new IconDefinition(iconLib['cursorDefault'], 'cursor-default'),
  new IconDefinition(iconLib['cursorDefaultClick'], 'cursor-default-click'),
  new IconDefinition(iconLib['cursorDefaultClickOutline'], 'cursor-default-click-outline'),
  new IconDefinition(iconLib['cursorDefaultOutline'], 'cursor-default-outline'),
  new IconDefinition(iconLib['cursorMove'], 'cursor-move'),
  new IconDefinition(iconLib['cursorPointer'], 'cursor-pointer'),
  new IconDefinition(iconLib['cursorText'], 'cursor-text'),
  new IconDefinition(iconLib['database'], 'database'),
  new IconDefinition(iconLib['databaseCheck'], 'database-check'),
  new IconDefinition(iconLib['databaseEdit'], 'database-edit'),
  new IconDefinition(iconLib['databaseExport'], 'database-export'),
  new IconDefinition(iconLib['databaseImport'], 'database-import'),
  new IconDefinition(iconLib['databaseLock'], 'database-lock'),
  new IconDefinition(iconLib['databaseMinus'], 'database-minus'),
  new IconDefinition(iconLib['databasePlus'], 'database-plus'),
  new IconDefinition(iconLib['databaseRefresh'], 'database-refresh'),
  new IconDefinition(iconLib['databaseRemove'], 'database-remove'),
  new IconDefinition(iconLib['databaseSearch'], 'database-search'),
  new IconDefinition(iconLib['databaseSettings'], 'database-settings'),
  new IconDefinition(iconLib['deathStar'], 'death-star'),
  new IconDefinition(iconLib['deathStarVariant'], 'death-star-variant'),
  new IconDefinition(iconLib['deathlyHallows'], 'deathly-hallows'),
  new IconDefinition(iconLib['debian'], 'debian'),
  new IconDefinition(iconLib['debugStepInto'], 'debug-step-into'),
  new IconDefinition(iconLib['debugStepOut'], 'debug-step-out'),
  new IconDefinition(iconLib['debugStepOver'], 'debug-step-over'),
  new IconDefinition(iconLib['decagram'], 'decagram'),
  new IconDefinition(iconLib['decagramOutline'], 'decagram-outline'),
  new IconDefinition(iconLib['decimalDecrease'], 'decimal-decrease'),
  new IconDefinition(iconLib['decimalIncrease'], 'decimal-increase'),
  new IconDefinition(iconLib['delete'], 'delete'),
  new IconDefinition(iconLib['deleteCircle'], 'delete-circle'),
  new IconDefinition(iconLib['deleteCircleOutline'], 'delete-circle-outline'),
  new IconDefinition(iconLib['deleteEmpty'], 'delete-empty'),
  new IconDefinition(iconLib['deleteEmptyOutline'], 'delete-empty-outline'),
  new IconDefinition(iconLib['deleteForever'], 'delete-forever'),
  new IconDefinition(iconLib['deleteForeverOutline'], 'delete-forever-outline'),
  new IconDefinition(iconLib['deleteOutline'], 'delete-outline'),
  new IconDefinition(iconLib['deleteRestore'], 'delete-restore'),
  new IconDefinition(iconLib['deleteSweep'], 'delete-sweep'),
  new IconDefinition(iconLib['deleteSweepOutline'], 'delete-sweep-outline'),
  new IconDefinition(iconLib['deleteVariant'], 'delete-variant'),
  new IconDefinition(iconLib['delta'], 'delta'),
  new IconDefinition(iconLib['deskLamp'], 'desk-lamp'),
  new IconDefinition(iconLib['deskphone'], 'deskphone'),
  new IconDefinition(iconLib['desktopClassic'], 'desktop-classic'),
  new IconDefinition(iconLib['desktopMac'], 'desktop-mac'),
  new IconDefinition(iconLib['desktopMacDashboard'], 'desktop-mac-dashboard'),
  new IconDefinition(iconLib['desktopTower'], 'desktop-tower'),
  new IconDefinition(iconLib['desktopTowerMonitor'], 'desktop-tower-monitor'),
  new IconDefinition(iconLib['details'], 'details'),
  new IconDefinition(iconLib['devTo'], 'dev-to'),
  new IconDefinition(iconLib['developerBoard'], 'developer-board'),
  new IconDefinition(iconLib['deviantart'], 'deviantart'),
  new IconDefinition(iconLib['dialpad'], 'dialpad'),
  new IconDefinition(iconLib['diameter'], 'diameter'),
  new IconDefinition(iconLib['diameterOutline'], 'diameter-outline'),
  new IconDefinition(iconLib['diameterVariant'], 'diameter-variant'),
  new IconDefinition(iconLib['diamond'], 'diamond'),
  new IconDefinition(iconLib['diamondOutline'], 'diamond-outline'),
  new IconDefinition(iconLib['diamondStone'], 'diamond-stone'),
  new IconDefinition(iconLib['dice1'], 'dice-1'),
  new IconDefinition(iconLib['dice2'], 'dice-2'),
  new IconDefinition(iconLib['dice3'], 'dice-3'),
  new IconDefinition(iconLib['dice4'], 'dice-4'),
  new IconDefinition(iconLib['dice5'], 'dice-5'),
  new IconDefinition(iconLib['dice6'], 'dice-6'),
  new IconDefinition(iconLib['diceD10'], 'dice-d10'),
  new IconDefinition(iconLib['diceD12'], 'dice-d12'),
  new IconDefinition(iconLib['diceD20'], 'dice-d20'),
  new IconDefinition(iconLib['diceD4'], 'dice-d4'),
  new IconDefinition(iconLib['diceD6'], 'dice-d6'),
  new IconDefinition(iconLib['diceD8'], 'dice-d8'),
  new IconDefinition(iconLib['diceMultiple'], 'dice-multiple'),
  new IconDefinition(iconLib['dictionary'], 'dictionary'),
  new IconDefinition(iconLib['dipSwitch'], 'dip-switch'),
  new IconDefinition(iconLib['directions'], 'directions'),
  new IconDefinition(iconLib['directionsFork'], 'directions-fork'),
  new IconDefinition(iconLib['disc'], 'disc'),
  new IconDefinition(iconLib['discAlert'], 'disc-alert'),
  new IconDefinition(iconLib['discPlayer'], 'disc-player'),
  new IconDefinition(iconLib['discord'], 'discord'),
  new IconDefinition(iconLib['dishwasher'], 'dishwasher'),
  new IconDefinition(iconLib['disqus'], 'disqus'),
  new IconDefinition(iconLib['disqusOutline'], 'disqus-outline'),
  new IconDefinition(iconLib['divingFlippers'], 'diving-flippers'),
  new IconDefinition(iconLib['divingHelmet'], 'diving-helmet'),
  new IconDefinition(iconLib['divingScuba'], 'diving-scuba'),
  new IconDefinition(iconLib['divingScubaFlag'], 'diving-scuba-flag'),
  new IconDefinition(iconLib['divingScubaTank'], 'diving-scuba-tank'),
  new IconDefinition(iconLib['divingScubaTankMultiple'], 'diving-scuba-tank-multiple'),
  new IconDefinition(iconLib['divingSnorkel'], 'diving-snorkel'),
  new IconDefinition(iconLib['division'], 'division'),
  new IconDefinition(iconLib['divisionBox'], 'division-box'),
  new IconDefinition(iconLib['dlna'], 'dlna'),
  new IconDefinition(iconLib['dna'], 'dna'),
  new IconDefinition(iconLib['dns'], 'dns'),
  new IconDefinition(iconLib['dnsOutline'], 'dns-outline'),
  new IconDefinition(iconLib['doNotDisturb'], 'do-not-disturb'),
  new IconDefinition(iconLib['doNotDisturbOff'], 'do-not-disturb-off'),
  new IconDefinition(iconLib['docker'], 'docker'),
  new IconDefinition(iconLib['doctor'], 'doctor'),
  new IconDefinition(iconLib['dog'], 'dog'),
  new IconDefinition(iconLib['dogService'], 'dog-service'),
  new IconDefinition(iconLib['dogSide'], 'dog-side'),
  new IconDefinition(iconLib['dolby'], 'dolby'),
  new IconDefinition(iconLib['dolly'], 'dolly'),
  new IconDefinition(iconLib['domain'], 'domain'),
  new IconDefinition(iconLib['domainOff'], 'domain-off'),
  new IconDefinition(iconLib['donkey'], 'donkey'),
  new IconDefinition(iconLib['door'], 'door'),
  new IconDefinition(iconLib['doorClosed'], 'door-closed'),
  new IconDefinition(iconLib['doorOpen'], 'door-open'),
  new IconDefinition(iconLib['doorbellVideo'], 'doorbell-video'),
  new IconDefinition(iconLib['dotNet'], 'dot-net'),
  new IconDefinition(iconLib['dotsHorizontal'], 'dots-horizontal'),
  new IconDefinition(iconLib['dotsHorizontalCircle'], 'dots-horizontal-circle'),
  new IconDefinition(iconLib['dotsHorizontalCircleOutline'], 'dots-horizontal-circle-outline'),
  new IconDefinition(iconLib['dotsVertical'], 'dots-vertical'),
  new IconDefinition(iconLib['dotsVerticalCircle'], 'dots-vertical-circle'),
  new IconDefinition(iconLib['dotsVerticalCircleOutline'], 'dots-vertical-circle-outline'),
  new IconDefinition(iconLib['douban'], 'douban'),
  new IconDefinition(iconLib['download'], 'download'),
  new IconDefinition(iconLib['downloadMultiple'], 'download-multiple'),
  new IconDefinition(iconLib['downloadNetwork'], 'download-network'),
  new IconDefinition(iconLib['downloadNetworkOutline'], 'download-network-outline'),
  new IconDefinition(iconLib['downloadOutline'], 'download-outline'),
  new IconDefinition(iconLib['drag'], 'drag'),
  new IconDefinition(iconLib['dragHorizontal'], 'drag-horizontal'),
  new IconDefinition(iconLib['dragVariant'], 'drag-variant'),
  new IconDefinition(iconLib['dragVertical'], 'drag-vertical'),
  new IconDefinition(iconLib['dramaMasks'], 'drama-masks'),
  new IconDefinition(iconLib['drawing'], 'drawing'),
  new IconDefinition(iconLib['drawingBox'], 'drawing-box'),
  new IconDefinition(iconLib['dribbble'], 'dribbble'),
  new IconDefinition(iconLib['dribbbleBox'], 'dribbble-box'),
  new IconDefinition(iconLib['drone'], 'drone'),
  new IconDefinition(iconLib['dropbox'], 'dropbox'),
  new IconDefinition(iconLib['drupal'], 'drupal'),
  new IconDefinition(iconLib['duck'], 'duck'),
  new IconDefinition(iconLib['dumbbell'], 'dumbbell'),
  new IconDefinition(iconLib['dumpTruck'], 'dump-truck'),
  new IconDefinition(iconLib['earHearing'], 'ear-hearing'),
  new IconDefinition(iconLib['earHearingOff'], 'ear-hearing-off'),
  new IconDefinition(iconLib['earth'], 'earth'),
  new IconDefinition(iconLib['earthBox'], 'earth-box'),
  new IconDefinition(iconLib['earthBoxOff'], 'earth-box-off'),
  new IconDefinition(iconLib['earthOff'], 'earth-off'),
  new IconDefinition(iconLib['edge'], 'edge'),
  new IconDefinition(iconLib['egg'], 'egg'),
  new IconDefinition(iconLib['eggEaster'], 'egg-easter'),
  new IconDefinition(iconLib['eightTrack'], 'eight-track'),
  new IconDefinition(iconLib['eject'], 'eject'),
  new IconDefinition(iconLib['ejectOutline'], 'eject-outline'),
  new IconDefinition(iconLib['electricSwitch'], 'electric-switch'),
  new IconDefinition(iconLib['elephant'], 'elephant'),
  new IconDefinition(iconLib['elevationDecline'], 'elevation-decline'),
  new IconDefinition(iconLib['elevationRise'], 'elevation-rise'),
  new IconDefinition(iconLib['elevator'], 'elevator'),
  new IconDefinition(iconLib['ellipse'], 'ellipse'),
  new IconDefinition(iconLib['ellipseOutline'], 'ellipse-outline'),
  new IconDefinition(iconLib['email'], 'email'),
  new IconDefinition(iconLib['emailAlert'], 'email-alert'),
  new IconDefinition(iconLib['emailBox'], 'email-box'),
  new IconDefinition(iconLib['emailCheck'], 'email-check'),
  new IconDefinition(iconLib['emailCheckOutline'], 'email-check-outline'),
  new IconDefinition(iconLib['emailEdit'], 'email-edit'),
  new IconDefinition(iconLib['emailEditOutline'], 'email-edit-outline'),
  new IconDefinition(iconLib['emailLock'], 'email-lock'),
  new IconDefinition(iconLib['emailMarkAsUnread'], 'email-mark-as-unread'),
  new IconDefinition(iconLib['emailMinus'], 'email-minus'),
  new IconDefinition(iconLib['emailMinusOutline'], 'email-minus-outline'),
  new IconDefinition(iconLib['emailMultiple'], 'email-multiple'),
  new IconDefinition(iconLib['emailMultipleOutline'], 'email-multiple-outline'),
  new IconDefinition(iconLib['emailOpen'], 'email-open'),
  new IconDefinition(iconLib['emailOpenMultiple'], 'email-open-multiple'),
  new IconDefinition(iconLib['emailOpenMultipleOutline'], 'email-open-multiple-outline'),
  new IconDefinition(iconLib['emailOpenOutline'], 'email-open-outline'),
  new IconDefinition(iconLib['emailOutline'], 'email-outline'),
  new IconDefinition(iconLib['emailPlus'], 'email-plus'),
  new IconDefinition(iconLib['emailPlusOutline'], 'email-plus-outline'),
  new IconDefinition(iconLib['emailSearch'], 'email-search'),
  new IconDefinition(iconLib['emailSearchOutline'], 'email-search-outline'),
  new IconDefinition(iconLib['emailVariant'], 'email-variant'),
  new IconDefinition(iconLib['ember'], 'ember'),
  new IconDefinition(iconLib['emby'], 'emby'),
  new IconDefinition(iconLib['emoticon'], 'emoticon'),
  new IconDefinition(iconLib['emoticonAngry'], 'emoticon-angry'),
  new IconDefinition(iconLib['emoticonAngryOutline'], 'emoticon-angry-outline'),
  new IconDefinition(iconLib['emoticonCool'], 'emoticon-cool'),
  new IconDefinition(iconLib['emoticonCoolOutline'], 'emoticon-cool-outline'),
  new IconDefinition(iconLib['emoticonCry'], 'emoticon-cry'),
  new IconDefinition(iconLib['emoticonCryOutline'], 'emoticon-cry-outline'),
  new IconDefinition(iconLib['emoticonDead'], 'emoticon-dead'),
  new IconDefinition(iconLib['emoticonDeadOutline'], 'emoticon-dead-outline'),
  new IconDefinition(iconLib['emoticonDevil'], 'emoticon-devil'),
  new IconDefinition(iconLib['emoticonDevilOutline'], 'emoticon-devil-outline'),
  new IconDefinition(iconLib['emoticonExcited'], 'emoticon-excited'),
  new IconDefinition(iconLib['emoticonExcitedOutline'], 'emoticon-excited-outline'),
  new IconDefinition(iconLib['emoticonHappy'], 'emoticon-happy'),
  new IconDefinition(iconLib['emoticonHappyOutline'], 'emoticon-happy-outline'),
  new IconDefinition(iconLib['emoticonKiss'], 'emoticon-kiss'),
  new IconDefinition(iconLib['emoticonKissOutline'], 'emoticon-kiss-outline'),
  new IconDefinition(iconLib['emoticonNeutral'], 'emoticon-neutral'),
  new IconDefinition(iconLib['emoticonNeutralOutline'], 'emoticon-neutral-outline'),
  new IconDefinition(iconLib['emoticonOutline'], 'emoticon-outline'),
  new IconDefinition(iconLib['emoticonPoop'], 'emoticon-poop'),
  new IconDefinition(iconLib['emoticonPoopOutline'], 'emoticon-poop-outline'),
  new IconDefinition(iconLib['emoticonSad'], 'emoticon-sad'),
  new IconDefinition(iconLib['emoticonSadOutline'], 'emoticon-sad-outline'),
  new IconDefinition(iconLib['emoticonTongue'], 'emoticon-tongue'),
  new IconDefinition(iconLib['emoticonTongueOutline'], 'emoticon-tongue-outline'),
  new IconDefinition(iconLib['emoticonWink'], 'emoticon-wink'),
  new IconDefinition(iconLib['emoticonWinkOutline'], 'emoticon-wink-outline'),
  new IconDefinition(iconLib['engine'], 'engine'),
  new IconDefinition(iconLib['engineOff'], 'engine-off'),
  new IconDefinition(iconLib['engineOffOutline'], 'engine-off-outline'),
  new IconDefinition(iconLib['engineOutline'], 'engine-outline'),
  new IconDefinition(iconLib['equal'], 'equal'),
  new IconDefinition(iconLib['equalBox'], 'equal-box'),
  new IconDefinition(iconLib['equalizer'], 'equalizer'),
  new IconDefinition(iconLib['equalizerOutline'], 'equalizer-outline'),
  new IconDefinition(iconLib['eraser'], 'eraser'),
  new IconDefinition(iconLib['eraserVariant'], 'eraser-variant'),
  new IconDefinition(iconLib['escalator'], 'escalator'),
  new IconDefinition(iconLib['eslint'], 'eslint'),
  new IconDefinition(iconLib['et'], 'et'),
  new IconDefinition(iconLib['ethereum'], 'ethereum'),
  new IconDefinition(iconLib['ethernet'], 'ethernet'),
  new IconDefinition(iconLib['ethernetCable'], 'ethernet-cable'),
  new IconDefinition(iconLib['ethernetCableOff'], 'ethernet-cable-off'),
  new IconDefinition(iconLib['etsy'], 'etsy'),
  new IconDefinition(iconLib['evStation'], 'ev-station'),
  new IconDefinition(iconLib['eventbrite'], 'eventbrite'),
  new IconDefinition(iconLib['evernote'], 'evernote'),
  new IconDefinition(iconLib['exclamation'], 'exclamation'),
  new IconDefinition(iconLib['exitRun'], 'exit-run'),
  new IconDefinition(iconLib['exitToApp'], 'exit-to-app'),
  new IconDefinition(iconLib['expandAll'], 'expand-all'),
  new IconDefinition(iconLib['expandAllOutline'], 'expand-all-outline'),
  new IconDefinition(iconLib['exponent'], 'exponent'),
  new IconDefinition(iconLib['exponentBox'], 'exponent-box'),
  new IconDefinition(iconLib['export'], 'export'),
  new IconDefinition(iconLib['exportVariant'], 'export-variant'),
  new IconDefinition(iconLib['eye'], 'eye'),
  new IconDefinition(iconLib['eyeCheck'], 'eye-check'),
  new IconDefinition(iconLib['eyeCheckOutline'], 'eye-check-outline'),
  new IconDefinition(iconLib['eyeCircle'], 'eye-circle'),
  new IconDefinition(iconLib['eyeCircleOutline'], 'eye-circle-outline'),
  new IconDefinition(iconLib['eyeOff'], 'eye-off'),
  new IconDefinition(iconLib['eyeOffOutline'], 'eye-off-outline'),
  new IconDefinition(iconLib['eyeOutline'], 'eye-outline'),
  new IconDefinition(iconLib['eyePlus'], 'eye-plus'),
  new IconDefinition(iconLib['eyePlusOutline'], 'eye-plus-outline'),
  new IconDefinition(iconLib['eyeSettings'], 'eye-settings'),
  new IconDefinition(iconLib['eyeSettingsOutline'], 'eye-settings-outline'),
  new IconDefinition(iconLib['eyedropper'], 'eyedropper'),
  new IconDefinition(iconLib['eyedropperVariant'], 'eyedropper-variant'),
  new IconDefinition(iconLib['face'], 'face'),
  new IconDefinition(iconLib['faceAgent'], 'face-agent'),
  new IconDefinition(iconLib['faceOutline'], 'face-outline'),
  new IconDefinition(iconLib['faceProfile'], 'face-profile'),
  new IconDefinition(iconLib['faceRecognition'], 'face-recognition'),
  new IconDefinition(iconLib['facebook'], 'facebook'),
  new IconDefinition(iconLib['facebookBox'], 'facebook-box'),
  new IconDefinition(iconLib['facebookMessenger'], 'facebook-messenger'),
  new IconDefinition(iconLib['facebookWorkplace'], 'facebook-workplace'),
  new IconDefinition(iconLib['factoryIcon'], 'factory'),
  new IconDefinition(iconLib['fan'], 'fan'),
  new IconDefinition(iconLib['fanOff'], 'fan-off'),
  new IconDefinition(iconLib['fastForward'], 'fast-forward'),
  new IconDefinition(iconLib['fastForward10'], 'fast-forward-10'),
  new IconDefinition(iconLib['fastForward30'], 'fast-forward-30'),
  new IconDefinition(iconLib['fastForwardOutline'], 'fast-forward-outline'),
  new IconDefinition(iconLib['fax'], 'fax'),
  new IconDefinition(iconLib['feather'], 'feather'),
  new IconDefinition(iconLib['featureSearch'], 'feature-search'),
  new IconDefinition(iconLib['featureSearchOutline'], 'feature-search-outline'),
  new IconDefinition(iconLib['fedora'], 'fedora'),
  new IconDefinition(iconLib['ferrisWheel'], 'ferris-wheel'),
  new IconDefinition(iconLib['ferry'], 'ferry'),
  new IconDefinition(iconLib['file'], 'file'),
  new IconDefinition(iconLib['fileAccount'], 'file-account'),
  new IconDefinition(iconLib['fileAlert'], 'file-alert'),
  new IconDefinition(iconLib['fileAlertOutline'], 'file-alert-outline'),
  new IconDefinition(iconLib['fileCabinet'], 'file-cabinet'),
  new IconDefinition(iconLib['fileCad'], 'file-cad'),
  new IconDefinition(iconLib['fileCadBox'], 'file-cad-box'),
  new IconDefinition(iconLib['fileCancel'], 'file-cancel'),
  new IconDefinition(iconLib['fileCancelOutline'], 'file-cancel-outline'),
  new IconDefinition(iconLib['fileChart'], 'file-chart'),
  new IconDefinition(iconLib['fileCheck'], 'file-check'),
  new IconDefinition(iconLib['fileCheckOutline'], 'file-check-outline'),
  new IconDefinition(iconLib['fileCloud'], 'file-cloud'),
  new IconDefinition(iconLib['fileCompare'], 'file-compare'),
  new IconDefinition(iconLib['fileDelimited'], 'file-delimited'),
  new IconDefinition(iconLib['fileDelimitedOutline'], 'file-delimited-outline'),
  new IconDefinition(iconLib['fileDocument'], 'file-document'),
  new IconDefinition(iconLib['fileDocumentBox'], 'file-document-box'),
  new IconDefinition(iconLib['fileDocumentBoxCheck'], 'file-document-box-check'),
  new IconDefinition(iconLib['fileDocumentBoxCheckOutline'], 'file-document-box-check-outline'),
  new IconDefinition(iconLib['fileDocumentBoxMinus'], 'file-document-box-minus'),
  new IconDefinition(iconLib['fileDocumentBoxMinusOutline'], 'file-document-box-minus-outline'),
  new IconDefinition(iconLib['fileDocumentBoxMultiple'], 'file-document-box-multiple'),
  new IconDefinition(iconLib['fileDocumentBoxMultipleOutline'], 'file-document-box-multiple-outline'),
  new IconDefinition(iconLib['fileDocumentBoxOutline'], 'file-document-box-outline'),
  new IconDefinition(iconLib['fileDocumentBoxPlus'], 'file-document-box-plus'),
  new IconDefinition(iconLib['fileDocumentBoxPlusOutline'], 'file-document-box-plus-outline'),
  new IconDefinition(iconLib['fileDocumentBoxRemove'], 'file-document-box-remove'),
  new IconDefinition(iconLib['fileDocumentBoxRemoveOutline'], 'file-document-box-remove-outline'),
  new IconDefinition(iconLib['fileDocumentBoxSearch'], 'file-document-box-search'),
  new IconDefinition(iconLib['fileDocumentBoxSearchOutline'], 'file-document-box-search-outline'),
  new IconDefinition(iconLib['fileDocumentEdit'], 'file-document-edit'),
  new IconDefinition(iconLib['fileDocumentEditOutline'], 'file-document-edit-outline'),
  new IconDefinition(iconLib['fileDocumentOutline'], 'file-document-outline'),
  new IconDefinition(iconLib['fileDownload'], 'file-download'),
  new IconDefinition(iconLib['fileDownloadOutline'], 'file-download-outline'),
  new IconDefinition(iconLib['fileExcel'], 'file-excel'),
  new IconDefinition(iconLib['fileExcelBox'], 'file-excel-box'),
  new IconDefinition(iconLib['fileExport'], 'file-export'),
  new IconDefinition(iconLib['fileEye'], 'file-eye'),
  new IconDefinition(iconLib['fileEyeOutline'], 'file-eye-outline'),
  new IconDefinition(iconLib['fileFind'], 'file-find'),
  new IconDefinition(iconLib['fileFindOutline'], 'file-find-outline'),
  new IconDefinition(iconLib['fileHidden'], 'file-hidden'),
  new IconDefinition(iconLib['fileImage'], 'file-image'),
  new IconDefinition(iconLib['fileImageOutline'], 'file-image-outline'),
  new IconDefinition(iconLib['fileImport'], 'file-import'),
  new IconDefinition(iconLib['fileLock'], 'file-lock'),
  new IconDefinition(iconLib['fileMove'], 'file-move'),
  new IconDefinition(iconLib['fileMultiple'], 'file-multiple'),
  new IconDefinition(iconLib['fileMusic'], 'file-music'),
  new IconDefinition(iconLib['fileMusicOutline'], 'file-music-outline'),
  new IconDefinition(iconLib['fileOutline'], 'file-outline'),
  new IconDefinition(iconLib['filePdf'], 'file-pdf'),
  new IconDefinition(iconLib['filePdfBox'], 'file-pdf-box'),
  new IconDefinition(iconLib['filePdfOutline'], 'file-pdf-outline'),
  new IconDefinition(iconLib['filePercent'], 'file-percent'),
  new IconDefinition(iconLib['filePlus'], 'file-plus'),
  new IconDefinition(iconLib['filePlusOutline'], 'file-plus-outline'),
  new IconDefinition(iconLib['filePowerpoint'], 'file-powerpoint'),
  new IconDefinition(iconLib['filePowerpointBox'], 'file-powerpoint-box'),
  new IconDefinition(iconLib['filePresentationBox'], 'file-presentation-box'),
  new IconDefinition(iconLib['fileQuestion'], 'file-question'),
  new IconDefinition(iconLib['fileRemove'], 'file-remove'),
  new IconDefinition(iconLib['fileReplace'], 'file-replace'),
  new IconDefinition(iconLib['fileReplaceOutline'], 'file-replace-outline'),
  new IconDefinition(iconLib['fileRestore'], 'file-restore'),
  new IconDefinition(iconLib['fileSearch'], 'file-search'),
  new IconDefinition(iconLib['fileSearchOutline'], 'file-search-outline'),
  new IconDefinition(iconLib['fileSend'], 'file-send'),
  new IconDefinition(iconLib['fileTable'], 'file-table'),
  new IconDefinition(iconLib['fileTableOutline'], 'file-table-outline'),
  new IconDefinition(iconLib['fileTree'], 'file-tree'),
  new IconDefinition(iconLib['fileUndo'], 'file-undo'),
  new IconDefinition(iconLib['fileUpload'], 'file-upload'),
  new IconDefinition(iconLib['fileUploadOutline'], 'file-upload-outline'),
  new IconDefinition(iconLib['fileVideo'], 'file-video'),
  new IconDefinition(iconLib['fileVideoOutline'], 'file-video-outline'),
  new IconDefinition(iconLib['fileWord'], 'file-word'),
  new IconDefinition(iconLib['fileWordBox'], 'file-word-box'),
  new IconDefinition(iconLib['fileXml'], 'file-xml'),
  new IconDefinition(iconLib['film'], 'film'),
  new IconDefinition(iconLib['filmstrip'], 'filmstrip'),
  new IconDefinition(iconLib['filmstripOff'], 'filmstrip-off'),
  new IconDefinition(iconLib['filter'], 'filter'),
  new IconDefinition(iconLib['filterMinus'], 'filter-minus'),
  new IconDefinition(iconLib['filterMinusOutline'], 'filter-minus-outline'),
  new IconDefinition(iconLib['filterOutline'], 'filter-outline'),
  new IconDefinition(iconLib['filterPlus'], 'filter-plus'),
  new IconDefinition(iconLib['filterPlusOutline'], 'filter-plus-outline'),
  new IconDefinition(iconLib['filterRemove'], 'filter-remove'),
  new IconDefinition(iconLib['filterRemoveOutline'], 'filter-remove-outline'),
  new IconDefinition(iconLib['filterVariant'], 'filter-variant'),
  new IconDefinition(iconLib['finance'], 'finance'),
  new IconDefinition(iconLib['findReplace'], 'find-replace'),
  new IconDefinition(iconLib['fingerprint'], 'fingerprint'),
  new IconDefinition(iconLib['fingerprintOff'], 'fingerprint-off'),
  new IconDefinition(iconLib['fire'], 'fire'),
  new IconDefinition(iconLib['fireExtinguisher'], 'fire-extinguisher'),
  new IconDefinition(iconLib['fireTruck'], 'fire-truck'),
  new IconDefinition(iconLib['firebase'], 'firebase'),
  new IconDefinition(iconLib['firefox'], 'firefox'),
  new IconDefinition(iconLib['fireplace'], 'fireplace'),
  new IconDefinition(iconLib['fireplaceOff'], 'fireplace-off'),
  new IconDefinition(iconLib['firework'], 'firework'),
  new IconDefinition(iconLib['fish'], 'fish'),
  new IconDefinition(iconLib['fishbowl'], 'fishbowl'),
  new IconDefinition(iconLib['fishbowlOutline'], 'fishbowl-outline'),
  new IconDefinition(iconLib['fitToPage'], 'fit-to-page'),
  new IconDefinition(iconLib['fitToPageOutline'], 'fit-to-page-outline'),
  new IconDefinition(iconLib['flag'], 'flag'),
  new IconDefinition(iconLib['flagCheckered'], 'flag-checkered'),
  new IconDefinition(iconLib['flagMinus'], 'flag-minus'),
  new IconDefinition(iconLib['flagOutline'], 'flag-outline'),
  new IconDefinition(iconLib['flagPlus'], 'flag-plus'),
  new IconDefinition(iconLib['flagRemove'], 'flag-remove'),
  new IconDefinition(iconLib['flagTriangle'], 'flag-triangle'),
  new IconDefinition(iconLib['flagVariant'], 'flag-variant'),
  new IconDefinition(iconLib['flagVariantOutline'], 'flag-variant-outline'),
  new IconDefinition(iconLib['flare'], 'flare'),
  new IconDefinition(iconLib['flash'], 'flash'),
  new IconDefinition(iconLib['flashAlert'], 'flash-alert'),
  new IconDefinition(iconLib['flashAlertOutline'], 'flash-alert-outline'),
  new IconDefinition(iconLib['flashAuto'], 'flash-auto'),
  new IconDefinition(iconLib['flashCircle'], 'flash-circle'),
  new IconDefinition(iconLib['flashOff'], 'flash-off'),
  new IconDefinition(iconLib['flashOutline'], 'flash-outline'),
  new IconDefinition(iconLib['flashRedEye'], 'flash-red-eye'),
  new IconDefinition(iconLib['flashlight'], 'flashlight'),
  new IconDefinition(iconLib['flashlightOff'], 'flashlight-off'),
  new IconDefinition(iconLib['flask'], 'flask'),
  new IconDefinition(iconLib['flaskEmpty'], 'flask-empty'),
  new IconDefinition(iconLib['flaskEmptyOutline'], 'flask-empty-outline'),
  new IconDefinition(iconLib['flaskOutline'], 'flask-outline'),
  new IconDefinition(iconLib['flattr'], 'flattr'),
  new IconDefinition(iconLib['flickr'], 'flickr'),
  new IconDefinition(iconLib['flipToBack'], 'flip-to-back'),
  new IconDefinition(iconLib['flipToFront'], 'flip-to-front'),
  new IconDefinition(iconLib['floorLamp'], 'floor-lamp'),
  new IconDefinition(iconLib['floorPlan'], 'floor-plan'),
  new IconDefinition(iconLib['floppy'], 'floppy'),
  new IconDefinition(iconLib['floppyVariant'], 'floppy-variant'),
  new IconDefinition(iconLib['flower'], 'flower'),
  new IconDefinition(iconLib['flowerOutline'], 'flower-outline'),
  new IconDefinition(iconLib['flowerPoppy'], 'flower-poppy'),
  new IconDefinition(iconLib['flowerTulip'], 'flower-tulip'),
  new IconDefinition(iconLib['flowerTulipOutline'], 'flower-tulip-outline'),
  new IconDefinition(iconLib['folder'], 'folder'),
  new IconDefinition(iconLib['folderAccount'], 'folder-account'),
  new IconDefinition(iconLib['folderAccountOutline'], 'folder-account-outline'),
  new IconDefinition(iconLib['folderAlert'], 'folder-alert'),
  new IconDefinition(iconLib['folderAlertOutline'], 'folder-alert-outline'),
  new IconDefinition(iconLib['folderClock'], 'folder-clock'),
  new IconDefinition(iconLib['folderClockOutline'], 'folder-clock-outline'),
  new IconDefinition(iconLib['folderDownload'], 'folder-download'),
  new IconDefinition(iconLib['folderEdit'], 'folder-edit'),
  new IconDefinition(iconLib['folderEditOutline'], 'folder-edit-outline'),
  new IconDefinition(iconLib['folderGoogleDrive'], 'folder-google-drive'),
  new IconDefinition(iconLib['folderImage'], 'folder-image'),
  new IconDefinition(iconLib['folderKey'], 'folder-key'),
  new IconDefinition(iconLib['folderKeyNetwork'], 'folder-key-network'),
  new IconDefinition(iconLib['folderKeyNetworkOutline'], 'folder-key-network-outline'),
  new IconDefinition(iconLib['folderLock'], 'folder-lock'),
  new IconDefinition(iconLib['folderLockOpen'], 'folder-lock-open'),
  new IconDefinition(iconLib['folderMove'], 'folder-move'),
  new IconDefinition(iconLib['folderMultiple'], 'folder-multiple'),
  new IconDefinition(iconLib['folderMultipleImage'], 'folder-multiple-image'),
  new IconDefinition(iconLib['folderMultipleOutline'], 'folder-multiple-outline'),
  new IconDefinition(iconLib['folderNetwork'], 'folder-network'),
  new IconDefinition(iconLib['folderNetworkOutline'], 'folder-network-outline'),
  new IconDefinition(iconLib['folderOpen'], 'folder-open'),
  new IconDefinition(iconLib['folderOpenOutline'], 'folder-open-outline'),
  new IconDefinition(iconLib['folderOutline'], 'folder-outline'),
  new IconDefinition(iconLib['folderPlus'], 'folder-plus'),
  new IconDefinition(iconLib['folderPlusOutline'], 'folder-plus-outline'),
  new IconDefinition(iconLib['folderPound'], 'folder-pound'),
  new IconDefinition(iconLib['folderPoundOutline'], 'folder-pound-outline'),
  new IconDefinition(iconLib['folderRemove'], 'folder-remove'),
  new IconDefinition(iconLib['folderRemoveOutline'], 'folder-remove-outline'),
  new IconDefinition(iconLib['folderSearch'], 'folder-search'),
  new IconDefinition(iconLib['folderSearchOutline'], 'folder-search-outline'),
  new IconDefinition(iconLib['folderStar'], 'folder-star'),
  new IconDefinition(iconLib['folderStarOutline'], 'folder-star-outline'),
  new IconDefinition(iconLib['folderSync'], 'folder-sync'),
  new IconDefinition(iconLib['folderSyncOutline'], 'folder-sync-outline'),
  new IconDefinition(iconLib['folderText'], 'folder-text'),
  new IconDefinition(iconLib['folderTextOutline'], 'folder-text-outline'),
  new IconDefinition(iconLib['folderUpload'], 'folder-upload'),
  new IconDefinition(iconLib['fontAwesome'], 'font-awesome'),
  new IconDefinition(iconLib['food'], 'food'),
  new IconDefinition(iconLib['foodApple'], 'food-apple'),
  new IconDefinition(iconLib['foodAppleOutline'], 'food-apple-outline'),
  new IconDefinition(iconLib['foodCroissant'], 'food-croissant'),
  new IconDefinition(iconLib['foodForkDrink'], 'food-fork-drink'),
  new IconDefinition(iconLib['foodOff'], 'food-off'),
  new IconDefinition(iconLib['foodVariant'], 'food-variant'),
  new IconDefinition(iconLib['football'], 'football'),
  new IconDefinition(iconLib['footballAustralian'], 'football-australian'),
  new IconDefinition(iconLib['footballHelmet'], 'football-helmet'),
  new IconDefinition(iconLib['forklift'], 'forklift'),
  new IconDefinition(iconLib['formatAlignBottom'], 'format-align-bottom'),
  new IconDefinition(iconLib['formatAlignCenter'], 'format-align-center'),
  new IconDefinition(iconLib['formatAlignJustify'], 'format-align-justify'),
  new IconDefinition(iconLib['formatAlignLeft'], 'format-align-left'),
  new IconDefinition(iconLib['formatAlignMiddle'], 'format-align-middle'),
  new IconDefinition(iconLib['formatAlignRight'], 'format-align-right'),
  new IconDefinition(iconLib['formatAlignTop'], 'format-align-top'),
  new IconDefinition(iconLib['formatAnnotationMinus'], 'format-annotation-minus'),
  new IconDefinition(iconLib['formatAnnotationPlus'], 'format-annotation-plus'),
  new IconDefinition(iconLib['formatBold'], 'format-bold'),
  new IconDefinition(iconLib['formatClear'], 'format-clear'),
  new IconDefinition(iconLib['formatColorFill'], 'format-color-fill'),
  new IconDefinition(iconLib['formatColorHighlight'], 'format-color-highlight'),
  new IconDefinition(iconLib['formatColorText'], 'format-color-text'),
  new IconDefinition(iconLib['formatColumns'], 'format-columns'),
  new IconDefinition(iconLib['formatFloatCenter'], 'format-float-center'),
  new IconDefinition(iconLib['formatFloatLeft'], 'format-float-left'),
  new IconDefinition(iconLib['formatFloatNone'], 'format-float-none'),
  new IconDefinition(iconLib['formatFloatRight'], 'format-float-right'),
  new IconDefinition(iconLib['formatFont'], 'format-font'),
  new IconDefinition(iconLib['formatFontSizeDecrease'], 'format-font-size-decrease'),
  new IconDefinition(iconLib['formatFontSizeIncrease'], 'format-font-size-increase'),
  new IconDefinition(iconLib['formatHeader1'], 'format-header-1'),
  new IconDefinition(iconLib['formatHeader2'], 'format-header-2'),
  new IconDefinition(iconLib['formatHeader3'], 'format-header-3'),
  new IconDefinition(iconLib['formatHeader4'], 'format-header-4'),
  new IconDefinition(iconLib['formatHeader5'], 'format-header-5'),
  new IconDefinition(iconLib['formatHeader6'], 'format-header-6'),
  new IconDefinition(iconLib['formatHeaderDecrease'], 'format-header-decrease'),
  new IconDefinition(iconLib['formatHeaderEqual'], 'format-header-equal'),
  new IconDefinition(iconLib['formatHeaderIncrease'], 'format-header-increase'),
  new IconDefinition(iconLib['formatHeaderPound'], 'format-header-pound'),
  new IconDefinition(iconLib['formatHorizontalAlignCenter'], 'format-horizontal-align-center'),
  new IconDefinition(iconLib['formatHorizontalAlignLeft'], 'format-horizontal-align-left'),
  new IconDefinition(iconLib['formatHorizontalAlignRight'], 'format-horizontal-align-right'),
  new IconDefinition(iconLib['formatIndentDecrease'], 'format-indent-decrease'),
  new IconDefinition(iconLib['formatIndentIncrease'], 'format-indent-increase'),
  new IconDefinition(iconLib['formatItalic'], 'format-italic'),
  new IconDefinition(iconLib['formatLetterCase'], 'format-letter-case'),
  new IconDefinition(iconLib['formatLetterCaseLower'], 'format-letter-case-lower'),
  new IconDefinition(iconLib['formatLetterCaseUpper'], 'format-letter-case-upper'),
  new IconDefinition(iconLib['formatLineSpacing'], 'format-line-spacing'),
  new IconDefinition(iconLib['formatLineStyle'], 'format-line-style'),
  new IconDefinition(iconLib['formatLineWeight'], 'format-line-weight'),
  new IconDefinition(iconLib['formatListBulleted'], 'format-list-bulleted'),
  new IconDefinition(iconLib['formatListBulletedSquare'], 'format-list-bulleted-square'),
  new IconDefinition(iconLib['formatListBulletedType'], 'format-list-bulleted-type'),
  new IconDefinition(iconLib['formatListCheckbox'], 'format-list-checkbox'),
  new IconDefinition(iconLib['formatListChecks'], 'format-list-checks'),
  new IconDefinition(iconLib['formatListNumbered'], 'format-list-numbered'),
  new IconDefinition(iconLib['formatListNumberedRtl'], 'format-list-numbered-rtl'),
  new IconDefinition(iconLib['formatListTriangle'], 'format-list-triangle'),
  new IconDefinition(iconLib['formatOverline'], 'format-overline'),
  new IconDefinition(iconLib['formatPageBreak'], 'format-page-break'),
  new IconDefinition(iconLib['formatPaint'], 'format-paint'),
  new IconDefinition(iconLib['formatParagraph'], 'format-paragraph'),
  new IconDefinition(iconLib['formatPilcrow'], 'format-pilcrow'),
  new IconDefinition(iconLib['formatQuoteClose'], 'format-quote-close'),
  new IconDefinition(iconLib['formatQuoteOpen'], 'format-quote-open'),
  new IconDefinition(iconLib['formatRotate90'], 'format-rotate-90'),
  new IconDefinition(iconLib['formatSection'], 'format-section'),
  new IconDefinition(iconLib['formatSize'], 'format-size'),
  new IconDefinition(iconLib['formatStrikethrough'], 'format-strikethrough'),
  new IconDefinition(iconLib['formatStrikethroughVariant'], 'format-strikethrough-variant'),
  new IconDefinition(iconLib['formatSubscript'], 'format-subscript'),
  new IconDefinition(iconLib['formatSuperscript'], 'format-superscript'),
  new IconDefinition(iconLib['formatText'], 'format-text'),
  new IconDefinition(iconLib['formatTextRotationDown'], 'format-text-rotation-down'),
  new IconDefinition(iconLib['formatTextRotationNone'], 'format-text-rotation-none'),
  new IconDefinition(iconLib['formatTextVariant'], 'format-text-variant'),
  new IconDefinition(iconLib['formatTextWrappingClip'], 'format-text-wrapping-clip'),
  new IconDefinition(iconLib['formatTextWrappingOverflow'], 'format-text-wrapping-overflow'),
  new IconDefinition(iconLib['formatTextWrappingWrap'], 'format-text-wrapping-wrap'),
  new IconDefinition(iconLib['formatTextbox'], 'format-textbox'),
  new IconDefinition(iconLib['formatTextdirectionLToR'], 'format-textdirection-l-to-r'),
  new IconDefinition(iconLib['formatTextdirectionRToL'], 'format-textdirection-r-to-l'),
  new IconDefinition(iconLib['formatTitle'], 'format-title'),
  new IconDefinition(iconLib['formatUnderline'], 'format-underline'),
  new IconDefinition(iconLib['formatVerticalAlignBottom'], 'format-vertical-align-bottom'),
  new IconDefinition(iconLib['formatVerticalAlignCenter'], 'format-vertical-align-center'),
  new IconDefinition(iconLib['formatVerticalAlignTop'], 'format-vertical-align-top'),
  new IconDefinition(iconLib['formatWrapInline'], 'format-wrap-inline'),
  new IconDefinition(iconLib['formatWrapSquare'], 'format-wrap-square'),
  new IconDefinition(iconLib['formatWrapTight'], 'format-wrap-tight'),
  new IconDefinition(iconLib['formatWrapTopBottom'], 'format-wrap-top-bottom'),
  new IconDefinition(iconLib['forum'], 'forum'),
  new IconDefinition(iconLib['forumOutline'], 'forum-outline'),
  new IconDefinition(iconLib['forward'], 'forward'),
  new IconDefinition(iconLib['forwardburger'], 'forwardburger'),
  new IconDefinition(iconLib['fountain'], 'fountain'),
  new IconDefinition(iconLib['fountainPen'], 'fountain-pen'),
  new IconDefinition(iconLib['fountainPenTip'], 'fountain-pen-tip'),
  new IconDefinition(iconLib['foursquare'], 'foursquare'),
  new IconDefinition(iconLib['freebsd'], 'freebsd'),
  new IconDefinition(iconLib['frequentlyAskedQuestions'], 'frequently-asked-questions'),
  new IconDefinition(iconLib['fridge'], 'fridge'),
  new IconDefinition(iconLib['fridgeBottom'], 'fridge-bottom'),
  new IconDefinition(iconLib['fridgeOutline'], 'fridge-outline'),
  new IconDefinition(iconLib['fridgeTop'], 'fridge-top'),
  new IconDefinition(iconLib['fuel'], 'fuel'),
  new IconDefinition(iconLib['fullscreen'], 'fullscreen'),
  new IconDefinition(iconLib['fullscreenExit'], 'fullscreen-exit'),
  new IconDefinition(iconLib['function'], 'function'),
  new IconDefinition(iconLib['functionVariant'], 'function-variant'),
  new IconDefinition(iconLib['fuse'], 'fuse'),
  new IconDefinition(iconLib['fuseBlade'], 'fuse-blade'),
  new IconDefinition(iconLib['gamepad'], 'gamepad'),
  new IconDefinition(iconLib['gamepadCircle'], 'gamepad-circle'),
  new IconDefinition(iconLib['gamepadCircleDown'], 'gamepad-circle-down'),
  new IconDefinition(iconLib['gamepadCircleLeft'], 'gamepad-circle-left'),
  new IconDefinition(iconLib['gamepadCircleOutline'], 'gamepad-circle-outline'),
  new IconDefinition(iconLib['gamepadCircleRight'], 'gamepad-circle-right'),
  new IconDefinition(iconLib['gamepadCircleUp'], 'gamepad-circle-up'),
  new IconDefinition(iconLib['gamepadDown'], 'gamepad-down'),
  new IconDefinition(iconLib['gamepadLeft'], 'gamepad-left'),
  new IconDefinition(iconLib['gamepadRight'], 'gamepad-right'),
  new IconDefinition(iconLib['gamepadRound'], 'gamepad-round'),
  new IconDefinition(iconLib['gamepadRoundDown'], 'gamepad-round-down'),
  new IconDefinition(iconLib['gamepadRoundLeft'], 'gamepad-round-left'),
  new IconDefinition(iconLib['gamepadRoundOutline'], 'gamepad-round-outline'),
  new IconDefinition(iconLib['gamepadRoundRight'], 'gamepad-round-right'),
  new IconDefinition(iconLib['gamepadRoundUp'], 'gamepad-round-up'),
  new IconDefinition(iconLib['gamepadSquare'], 'gamepad-square'),
  new IconDefinition(iconLib['gamepadSquareOutline'], 'gamepad-square-outline'),
  new IconDefinition(iconLib['gamepadUp'], 'gamepad-up'),
  new IconDefinition(iconLib['gamepadVariant'], 'gamepad-variant'),
  new IconDefinition(iconLib['gamepadVariantOutline'], 'gamepad-variant-outline'),
  new IconDefinition(iconLib['gantryCrane'], 'gantry-crane'),
  new IconDefinition(iconLib['garage'], 'garage'),
  new IconDefinition(iconLib['garageAlert'], 'garage-alert'),
  new IconDefinition(iconLib['garageOpen'], 'garage-open'),
  new IconDefinition(iconLib['gasCylinder'], 'gas-cylinder'),
  new IconDefinition(iconLib['gasStation'], 'gas-station'),
  new IconDefinition(iconLib['gasStationOutline'], 'gas-station-outline'),
  new IconDefinition(iconLib['gate'], 'gate'),
  new IconDefinition(iconLib['gateAnd'], 'gate-and'),
  new IconDefinition(iconLib['gateNand'], 'gate-nand'),
  new IconDefinition(iconLib['gateNor'], 'gate-nor'),
  new IconDefinition(iconLib['gateNot'], 'gate-not'),
  new IconDefinition(iconLib['gateOr'], 'gate-or'),
  new IconDefinition(iconLib['gateXnor'], 'gate-xnor'),
  new IconDefinition(iconLib['gateXor'], 'gate-xor'),
  new IconDefinition(iconLib['gatsby'], 'gatsby'),
  new IconDefinition(iconLib['gauge'], 'gauge'),
  new IconDefinition(iconLib['gaugeEmpty'], 'gauge-empty'),
  new IconDefinition(iconLib['gaugeFull'], 'gauge-full'),
  new IconDefinition(iconLib['gaugeLow'], 'gauge-low'),
  new IconDefinition(iconLib['gavel'], 'gavel'),
  new IconDefinition(iconLib['genderFemale'], 'gender-female'),
  new IconDefinition(iconLib['genderMale'], 'gender-male'),
  new IconDefinition(iconLib['genderMaleFemale'], 'gender-male-female'),
  new IconDefinition(iconLib['genderTransgender'], 'gender-transgender'),
  new IconDefinition(iconLib['gentoo'], 'gentoo'),
  new IconDefinition(iconLib['gesture'], 'gesture'),
  new IconDefinition(iconLib['gestureDoubleTap'], 'gesture-double-tap'),
  new IconDefinition(iconLib['gesturePinch'], 'gesture-pinch'),
  new IconDefinition(iconLib['gestureSpread'], 'gesture-spread'),
  new IconDefinition(iconLib['gestureSwipe'], 'gesture-swipe'),
  new IconDefinition(iconLib['gestureSwipeDown'], 'gesture-swipe-down'),
  new IconDefinition(iconLib['gestureSwipeHorizontal'], 'gesture-swipe-horizontal'),
  new IconDefinition(iconLib['gestureSwipeLeft'], 'gesture-swipe-left'),
  new IconDefinition(iconLib['gestureSwipeRight'], 'gesture-swipe-right'),
  new IconDefinition(iconLib['gestureSwipeUp'], 'gesture-swipe-up'),
  new IconDefinition(iconLib['gestureSwipeVertical'], 'gesture-swipe-vertical'),
  new IconDefinition(iconLib['gestureTap'], 'gesture-tap'),
  new IconDefinition(iconLib['gestureTapHold'], 'gesture-tap-hold'),
  new IconDefinition(iconLib['gestureTwoDoubleTap'], 'gesture-two-double-tap'),
  new IconDefinition(iconLib['gestureTwoTap'], 'gesture-two-tap'),
  new IconDefinition(iconLib['ghost'], 'ghost'),
  new IconDefinition(iconLib['ghostOff'], 'ghost-off'),
  new IconDefinition(iconLib['gif'], 'gif'),
  new IconDefinition(iconLib['gift'], 'gift'),
  new IconDefinition(iconLib['giftOutline'], 'gift-outline'),
  new IconDefinition(iconLib['git'], 'git'),
  new IconDefinition(iconLib['githubBox'], 'github-box'),
  new IconDefinition(iconLib['githubCircle'], 'github-circle'),
  new IconDefinition(iconLib['githubFace'], 'github-face'),
  new IconDefinition(iconLib['gitlab'], 'gitlab'),
  new IconDefinition(iconLib['glassCocktail'], 'glass-cocktail'),
  new IconDefinition(iconLib['glassFlute'], 'glass-flute'),
  new IconDefinition(iconLib['glassMug'], 'glass-mug'),
  new IconDefinition(iconLib['glassStange'], 'glass-stange'),
  new IconDefinition(iconLib['glassTulip'], 'glass-tulip'),
  new IconDefinition(iconLib['glassWine'], 'glass-wine'),
  new IconDefinition(iconLib['glassdoor'], 'glassdoor'),
  new IconDefinition(iconLib['glasses'], 'glasses'),
  new IconDefinition(iconLib['globeModel'], 'globe-model'),
  new IconDefinition(iconLib['gmail'], 'gmail'),
  new IconDefinition(iconLib['gnome'], 'gnome'),
  new IconDefinition(iconLib['goKart'], 'go-kart'),
  new IconDefinition(iconLib['goKartTrack'], 'go-kart-track'),
  new IconDefinition(iconLib['gog'], 'gog'),
  new IconDefinition(iconLib['golf'], 'golf'),
  new IconDefinition(iconLib['gondola'], 'gondola'),
  new IconDefinition(iconLib['goodreads'], 'goodreads'),
  new IconDefinition(iconLib['google'], 'google'),
  new IconDefinition(iconLib['googleAdwords'], 'google-adwords'),
  new IconDefinition(iconLib['googleAllo'], 'google-allo'),
  new IconDefinition(iconLib['googleAnalytics'], 'google-analytics'),
  new IconDefinition(iconLib['googleAssistant'], 'google-assistant'),
  new IconDefinition(iconLib['googleCardboard'], 'google-cardboard'),
  new IconDefinition(iconLib['googleChrome'], 'google-chrome'),
  new IconDefinition(iconLib['googleCircles'], 'google-circles'),
  new IconDefinition(iconLib['googleCirclesCommunities'], 'google-circles-communities'),
  new IconDefinition(iconLib['googleCirclesExtended'], 'google-circles-extended'),
  new IconDefinition(iconLib['googleCirclesGroup'], 'google-circles-group'),
  new IconDefinition(iconLib['googleClassroom'], 'google-classroom'),
  new IconDefinition(iconLib['googleController'], 'google-controller'),
  new IconDefinition(iconLib['googleControllerOff'], 'google-controller-off'),
  new IconDefinition(iconLib['googleDrive'], 'google-drive'),
  new IconDefinition(iconLib['googleEarth'], 'google-earth'),
  new IconDefinition(iconLib['googleFit'], 'google-fit'),
  new IconDefinition(iconLib['googleGlass'], 'google-glass'),
  new IconDefinition(iconLib['googleHangouts'], 'google-hangouts'),
  new IconDefinition(iconLib['googleHome'], 'google-home'),
  new IconDefinition(iconLib['googleKeep'], 'google-keep'),
  new IconDefinition(iconLib['googleLens'], 'google-lens'),
  new IconDefinition(iconLib['googleMaps'], 'google-maps'),
  new IconDefinition(iconLib['googleNearby'], 'google-nearby'),
  new IconDefinition(iconLib['googlePages'], 'google-pages'),
  new IconDefinition(iconLib['googlePhotos'], 'google-photos'),
  new IconDefinition(iconLib['googlePhysicalWeb'], 'google-physical-web'),
  new IconDefinition(iconLib['googlePlay'], 'google-play'),
  new IconDefinition(iconLib['googlePlus'], 'google-plus'),
  new IconDefinition(iconLib['googlePlusBox'], 'google-plus-box'),
  new IconDefinition(iconLib['googlePodcast'], 'google-podcast'),
  new IconDefinition(iconLib['googleSpreadsheet'], 'google-spreadsheet'),
  new IconDefinition(iconLib['googleStreetView'], 'google-street-view'),
  new IconDefinition(iconLib['googleTranslate'], 'google-translate'),
  new IconDefinition(iconLib['gpu'], 'gpu'),
  new IconDefinition(iconLib['gradient'], 'gradient'),
  new IconDefinition(iconLib['grain'], 'grain'),
  new IconDefinition(iconLib['graphql'], 'graphql'),
  new IconDefinition(iconLib['graveStone'], 'grave-stone'),
  new IconDefinition(iconLib['greasePencil'], 'grease-pencil'),
  new IconDefinition(iconLib['greaterThan'], 'greater-than'),
  new IconDefinition(iconLib['greaterThanOrEqual'], 'greater-than-or-equal'),
  new IconDefinition(iconLib['grid'], 'grid'),
  new IconDefinition(iconLib['gridLarge'], 'grid-large'),
  new IconDefinition(iconLib['gridOff'], 'grid-off'),
  new IconDefinition(iconLib['grill'], 'grill'),
  new IconDefinition(iconLib['group'], 'group'),
  new IconDefinition(iconLib['guitarAcoustic'], 'guitar-acoustic'),
  new IconDefinition(iconLib['guitarElectric'], 'guitar-electric'),
  new IconDefinition(iconLib['guitarPick'], 'guitar-pick'),
  new IconDefinition(iconLib['guitarPickOutline'], 'guitar-pick-outline'),
  new IconDefinition(iconLib['guyFawkesMask'], 'guy-fawkes-mask'),
  new IconDefinition(iconLib['hackernews'], 'hackernews'),
  new IconDefinition(iconLib['hail'], 'hail'),
  new IconDefinition(iconLib['halloween'], 'halloween'),
  new IconDefinition(iconLib['hamburger'], 'hamburger'),
  new IconDefinition(iconLib['hammer'], 'hammer'),
  new IconDefinition(iconLib['hand'], 'hand'),
  new IconDefinition(iconLib['handLeft'], 'hand-left'),
  new IconDefinition(iconLib['handOkay'], 'hand-okay'),
  new IconDefinition(iconLib['handPeace'], 'hand-peace'),
  new IconDefinition(iconLib['handPeaceVariant'], 'hand-peace-variant'),
  new IconDefinition(iconLib['handPointingDown'], 'hand-pointing-down'),
  new IconDefinition(iconLib['handPointingLeft'], 'hand-pointing-left'),
  new IconDefinition(iconLib['handPointingRight'], 'hand-pointing-right'),
  new IconDefinition(iconLib['handPointingUp'], 'hand-pointing-up'),
  new IconDefinition(iconLib['handRight'], 'hand-right'),
  new IconDefinition(iconLib['handSaw'], 'hand-saw'),
  new IconDefinition(iconLib['hanger'], 'hanger'),
  new IconDefinition(iconLib['hardHat'], 'hard-hat'),
  new IconDefinition(iconLib['harddisk'], 'harddisk'),
  new IconDefinition(iconLib['hatFedora'], 'hat-fedora'),
  new IconDefinition(iconLib['hazardLights'], 'hazard-lights'),
  new IconDefinition(iconLib['hdr'], 'hdr'),
  new IconDefinition(iconLib['hdrOff'], 'hdr-off'),
  new IconDefinition(iconLib['headphones'], 'headphones'),
  new IconDefinition(iconLib['headphonesBluetooth'], 'headphones-bluetooth'),
  new IconDefinition(iconLib['headphonesBox'], 'headphones-box'),
  new IconDefinition(iconLib['headphonesOff'], 'headphones-off'),
  new IconDefinition(iconLib['headphonesSettings'], 'headphones-settings'),
  new IconDefinition(iconLib['headset'], 'headset'),
  new IconDefinition(iconLib['headsetDock'], 'headset-dock'),
  new IconDefinition(iconLib['headsetOff'], 'headset-off'),
  new IconDefinition(iconLib['heart'], 'heart'),
  new IconDefinition(iconLib['heartBox'], 'heart-box'),
  new IconDefinition(iconLib['heartBoxOutline'], 'heart-box-outline'),
  new IconDefinition(iconLib['heartBroken'], 'heart-broken'),
  new IconDefinition(iconLib['heartBrokenOutline'], 'heart-broken-outline'),
  new IconDefinition(iconLib['heartCircle'], 'heart-circle'),
  new IconDefinition(iconLib['heartCircleOutline'], 'heart-circle-outline'),
  new IconDefinition(iconLib['heartFlash'], 'heart-flash'),
  new IconDefinition(iconLib['heartHalf'], 'heart-half'),
  new IconDefinition(iconLib['heartHalfFull'], 'heart-half-full'),
  new IconDefinition(iconLib['heartHalfOutline'], 'heart-half-outline'),
  new IconDefinition(iconLib['heartMultiple'], 'heart-multiple'),
  new IconDefinition(iconLib['heartMultipleOutline'], 'heart-multiple-outline'),
  new IconDefinition(iconLib['heartOff'], 'heart-off'),
  new IconDefinition(iconLib['heartOutline'], 'heart-outline'),
  new IconDefinition(iconLib['heartPulse'], 'heart-pulse'),
  new IconDefinition(iconLib['helicopter'], 'helicopter'),
  new IconDefinition(iconLib['help'], 'help'),
  new IconDefinition(iconLib['helpBox'], 'help-box'),
  new IconDefinition(iconLib['helpCircle'], 'help-circle'),
  new IconDefinition(iconLib['helpCircleOutline'], 'help-circle-outline'),
  new IconDefinition(iconLib['helpNetwork'], 'help-network'),
  new IconDefinition(iconLib['helpNetworkOutline'], 'help-network-outline'),
  new IconDefinition(iconLib['helpRhombus'], 'help-rhombus'),
  new IconDefinition(iconLib['helpRhombusOutline'], 'help-rhombus-outline'),
  new IconDefinition(iconLib['hexagon'], 'hexagon'),
  new IconDefinition(iconLib['hexagonMultiple'], 'hexagon-multiple'),
  new IconDefinition(iconLib['hexagonOutline'], 'hexagon-outline'),
  new IconDefinition(iconLib['hexagonSlice1'], 'hexagon-slice-1'),
  new IconDefinition(iconLib['hexagonSlice2'], 'hexagon-slice-2'),
  new IconDefinition(iconLib['hexagonSlice3'], 'hexagon-slice-3'),
  new IconDefinition(iconLib['hexagonSlice4'], 'hexagon-slice-4'),
  new IconDefinition(iconLib['hexagonSlice5'], 'hexagon-slice-5'),
  new IconDefinition(iconLib['hexagonSlice6'], 'hexagon-slice-6'),
  new IconDefinition(iconLib['hexagram'], 'hexagram'),
  new IconDefinition(iconLib['hexagramOutline'], 'hexagram-outline'),
  new IconDefinition(iconLib['highDefinition'], 'high-definition'),
  new IconDefinition(iconLib['highDefinitionBox'], 'high-definition-box'),
  new IconDefinition(iconLib['highway'], 'highway'),
  new IconDefinition(iconLib['hiking'], 'hiking'),
  new IconDefinition(iconLib['hinduism'], 'hinduism'),
  new IconDefinition(iconLib['history'], 'history'),
  new IconDefinition(iconLib['hockeyPuck'], 'hockey-puck'),
  new IconDefinition(iconLib['hockeySticks'], 'hockey-sticks'),
  new IconDefinition(iconLib['hololens'], 'hololens'),
  new IconDefinition(iconLib['home'], 'home'),
  new IconDefinition(iconLib['homeAccount'], 'home-account'),
  new IconDefinition(iconLib['homeAlert'], 'home-alert'),
  new IconDefinition(iconLib['homeAnalytics'], 'home-analytics'),
  new IconDefinition(iconLib['homeAssistant'], 'home-assistant'),
  new IconDefinition(iconLib['homeAutomation'], 'home-automation'),
  new IconDefinition(iconLib['homeCircle'], 'home-circle'),
  new IconDefinition(iconLib['homeCity'], 'home-city'),
  new IconDefinition(iconLib['homeCityOutline'], 'home-city-outline'),
  new IconDefinition(iconLib['homeCurrencyUsd'], 'home-currency-usd'),
  new IconDefinition(iconLib['homeFlood'], 'home-flood'),
  new IconDefinition(iconLib['homeFloor0'], 'home-floor-0'),
  new IconDefinition(iconLib['homeFloor1'], 'home-floor-1'),
  new IconDefinition(iconLib['homeFloor2'], 'home-floor-2'),
  new IconDefinition(iconLib['homeFloor3'], 'home-floor-3'),
  new IconDefinition(iconLib['homeFloorA'], 'home-floor-a'),
  new IconDefinition(iconLib['homeFloorB'], 'home-floor-b'),
  new IconDefinition(iconLib['homeFloorG'], 'home-floor-g'),
  new IconDefinition(iconLib['homeFloorL'], 'home-floor-l'),
  new IconDefinition(iconLib['homeFloorNegative1'], 'home-floor-negative-1'),
  new IconDefinition(iconLib['homeGroup'], 'home-group'),
  new IconDefinition(iconLib['homeHeart'], 'home-heart'),
  new IconDefinition(iconLib['homeLock'], 'home-lock'),
  new IconDefinition(iconLib['homeLockOpen'], 'home-lock-open'),
  new IconDefinition(iconLib['homeMapMarker'], 'home-map-marker'),
  new IconDefinition(iconLib['homeMinus'], 'home-minus'),
  new IconDefinition(iconLib['homeModern'], 'home-modern'),
  new IconDefinition(iconLib['homeOutline'], 'home-outline'),
  new IconDefinition(iconLib['homePlus'], 'home-plus'),
  new IconDefinition(iconLib['homeVariant'], 'home-variant'),
  new IconDefinition(iconLib['homeVariantOutline'], 'home-variant-outline'),
  new IconDefinition(iconLib['hook'], 'hook'),
  new IconDefinition(iconLib['hookOff'], 'hook-off'),
  new IconDefinition(iconLib['hops'], 'hops'),
  new IconDefinition(iconLib['horseshoe'], 'horseshoe'),
  new IconDefinition(iconLib['hospital'], 'hospital'),
  new IconDefinition(iconLib['hospitalBuilding'], 'hospital-building'),
  new IconDefinition(iconLib['hospitalMarker'], 'hospital-marker'),
  new IconDefinition(iconLib['hotTub'], 'hot-tub'),
  new IconDefinition(iconLib['hotel'], 'hotel'),
  new IconDefinition(iconLib['houzz'], 'houzz'),
  new IconDefinition(iconLib['houzzBox'], 'houzz-box'),
  new IconDefinition(iconLib['hubspot'], 'hubspot'),
  new IconDefinition(iconLib['hulu'], 'hulu'),
  new IconDefinition(iconLib['human'], 'human'),
  new IconDefinition(iconLib['humanChild'], 'human-child'),
  new IconDefinition(iconLib['humanFemale'], 'human-female'),
  new IconDefinition(iconLib['humanFemaleBoy'], 'human-female-boy'),
  new IconDefinition(iconLib['humanFemaleFemale'], 'human-female-female'),
  new IconDefinition(iconLib['humanFemaleGirl'], 'human-female-girl'),
  new IconDefinition(iconLib['humanGreeting'], 'human-greeting'),
  new IconDefinition(iconLib['humanHandsdown'], 'human-handsdown'),
  new IconDefinition(iconLib['humanHandsup'], 'human-handsup'),
  new IconDefinition(iconLib['humanMale'], 'human-male'),
  new IconDefinition(iconLib['humanMaleBoy'], 'human-male-boy'),
  new IconDefinition(iconLib['humanMaleFemale'], 'human-male-female'),
  new IconDefinition(iconLib['humanMaleGirl'], 'human-male-girl'),
  new IconDefinition(iconLib['humanMaleHeight'], 'human-male-height'),
  new IconDefinition(iconLib['humanMaleHeightVariant'], 'human-male-height-variant'),
  new IconDefinition(iconLib['humanMaleMale'], 'human-male-male'),
  new IconDefinition(iconLib['humanPregnant'], 'human-pregnant'),
  new IconDefinition(iconLib['humbleBundle'], 'humble-bundle'),
  new IconDefinition(iconLib['iceCream'], 'ice-cream'),
  new IconDefinition(iconLib['icePop'], 'ice-pop'),
  new IconDefinition(iconLib['identifier'], 'identifier'),
  new IconDefinition(iconLib['iframe'], 'iframe'),
  new IconDefinition(iconLib['iframeOutline'], 'iframe-outline'),
  new IconDefinition(iconLib['image'], 'image'),
  new IconDefinition(iconLib['imageAlbum'], 'image-album'),
  new IconDefinition(iconLib['imageArea'], 'image-area'),
  new IconDefinition(iconLib['imageAreaClose'], 'image-area-close'),
  new IconDefinition(iconLib['imageBroken'], 'image-broken'),
  new IconDefinition(iconLib['imageBrokenVariant'], 'image-broken-variant'),
  new IconDefinition(iconLib['imageFilter'], 'image-filter'),
  new IconDefinition(iconLib['imageFilterBlackWhite'], 'image-filter-black-white'),
  new IconDefinition(iconLib['imageFilterCenterFocus'], 'image-filter-center-focus'),
  new IconDefinition(iconLib['imageFilterCenterFocusStrong'], 'image-filter-center-focus-strong'),
  new IconDefinition(iconLib['imageFilterCenterFocusStrongOutline'], 'image-filter-center-focus-strong-outline'),
  new IconDefinition(iconLib['imageFilterCenterFocusWeak'], 'image-filter-center-focus-weak'),
  new IconDefinition(iconLib['imageFilterDrama'], 'image-filter-drama'),
  new IconDefinition(iconLib['imageFilterFrames'], 'image-filter-frames'),
  new IconDefinition(iconLib['imageFilterHdr'], 'image-filter-hdr'),
  new IconDefinition(iconLib['imageFilterNone'], 'image-filter-none'),
  new IconDefinition(iconLib['imageFilterTiltShift'], 'image-filter-tilt-shift'),
  new IconDefinition(iconLib['imageFilterVintage'], 'image-filter-vintage'),
  new IconDefinition(iconLib['imageFrame'], 'image-frame'),
  new IconDefinition(iconLib['imageMove'], 'image-move'),
  new IconDefinition(iconLib['imageMultiple'], 'image-multiple'),
  new IconDefinition(iconLib['imageOff'], 'image-off'),
  new IconDefinition(iconLib['imageOutline'], 'image-outline'),
  new IconDefinition(iconLib['imagePlus'], 'image-plus'),
  new IconDefinition(iconLib['imageSearch'], 'image-search'),
  new IconDefinition(iconLib['imageSearchOutline'], 'image-search-outline'),
  new IconDefinition(iconLib['imageSizeSelectActual'], 'image-size-select-actual'),
  new IconDefinition(iconLib['imageSizeSelectLarge'], 'image-size-select-large'),
  new IconDefinition(iconLib['imageSizeSelectSmall'], 'image-size-select-small'),
  new IconDefinition(iconLib['import'], 'import'),
  new IconDefinition(iconLib['inbox'], 'inbox'),
  new IconDefinition(iconLib['inboxArrowDown'], 'inbox-arrow-down'),
  new IconDefinition(iconLib['inboxArrowUp'], 'inbox-arrow-up'),
  new IconDefinition(iconLib['inboxMultiple'], 'inbox-multiple'),
  new IconDefinition(iconLib['inboxMultipleOutline'], 'inbox-multiple-outline'),
  new IconDefinition(iconLib['incognito'], 'incognito'),
  new IconDefinition(iconLib['infinity'], 'infinity'),
  new IconDefinition(iconLib['information'], 'information'),
  new IconDefinition(iconLib['informationOutline'], 'information-outline'),
  new IconDefinition(iconLib['informationVariant'], 'information-variant'),
  new IconDefinition(iconLib['instagram'], 'instagram'),
  new IconDefinition(iconLib['instapaper'], 'instapaper'),
  new IconDefinition(iconLib['internetExplorer'], 'internet-explorer'),
  new IconDefinition(iconLib['invertColors'], 'invert-colors'),
  new IconDefinition(iconLib['invertColorsOff'], 'invert-colors-off'),
  new IconDefinition(iconLib['ip'], 'ip'),
  new IconDefinition(iconLib['ipNetwork'], 'ip-network'),
  new IconDefinition(iconLib['ipNetworkOutline'], 'ip-network-outline'),
  new IconDefinition(iconLib['ipod'], 'ipod'),
  new IconDefinition(iconLib['islam'], 'islam'),
  new IconDefinition(iconLib['itunes'], 'itunes'),
  new IconDefinition(iconLib['jabber'], 'jabber'),
  new IconDefinition(iconLib['jeepney'], 'jeepney'),
  new IconDefinition(iconLib['jellyfish'], 'jellyfish'),
  new IconDefinition(iconLib['jellyfishOutline'], 'jellyfish-outline'),
  new IconDefinition(iconLib['jira'], 'jira'),
  new IconDefinition(iconLib['jquery'], 'jquery'),
  new IconDefinition(iconLib['jsfiddle'], 'jsfiddle'),
  new IconDefinition(iconLib['json'], 'json'),
  new IconDefinition(iconLib['judaism'], 'judaism'),
  new IconDefinition(iconLib['kabaddi'], 'kabaddi'),
  new IconDefinition(iconLib['karate'], 'karate'),
  new IconDefinition(iconLib['keg'], 'keg'),
  new IconDefinition(iconLib['kettle'], 'kettle'),
  new IconDefinition(iconLib['key'], 'key'),
  new IconDefinition(iconLib['keyChange'], 'key-change'),
  new IconDefinition(iconLib['keyMinus'], 'key-minus'),
  new IconDefinition(iconLib['keyOutline'], 'key-outline'),
  new IconDefinition(iconLib['keyPlus'], 'key-plus'),
  new IconDefinition(iconLib['keyRemove'], 'key-remove'),
  new IconDefinition(iconLib['keyVariant'], 'key-variant'),
  new IconDefinition(iconLib['keyboard'], 'keyboard'),
  new IconDefinition(iconLib['keyboardBackspace'], 'keyboard-backspace'),
  new IconDefinition(iconLib['keyboardCaps'], 'keyboard-caps'),
  new IconDefinition(iconLib['keyboardClose'], 'keyboard-close'),
  new IconDefinition(iconLib['keyboardOff'], 'keyboard-off'),
  new IconDefinition(iconLib['keyboardOffOutline'], 'keyboard-off-outline'),
  new IconDefinition(iconLib['keyboardOutline'], 'keyboard-outline'),
  new IconDefinition(iconLib['keyboardReturn'], 'keyboard-return'),
  new IconDefinition(iconLib['keyboardSettings'], 'keyboard-settings'),
  new IconDefinition(iconLib['keyboardSettingsOutline'], 'keyboard-settings-outline'),
  new IconDefinition(iconLib['keyboardTab'], 'keyboard-tab'),
  new IconDefinition(iconLib['keyboardVariant'], 'keyboard-variant'),
  new IconDefinition(iconLib['kickstarter'], 'kickstarter'),
  new IconDefinition(iconLib['knife'], 'knife'),
  new IconDefinition(iconLib['knifeMilitary'], 'knife-military'),
  new IconDefinition(iconLib['kodi'], 'kodi'),
  new IconDefinition(iconLib['label'], 'label'),
  new IconDefinition(iconLib['labelOff'], 'label-off'),
  new IconDefinition(iconLib['labelOffOutline'], 'label-off-outline'),
  new IconDefinition(iconLib['labelOutline'], 'label-outline'),
  new IconDefinition(iconLib['labelVariant'], 'label-variant'),
  new IconDefinition(iconLib['labelVariantOutline'], 'label-variant-outline'),
  new IconDefinition(iconLib['ladybug'], 'ladybug'),
  new IconDefinition(iconLib['lambda'], 'lambda'),
  new IconDefinition(iconLib['lamp'], 'lamp'),
  new IconDefinition(iconLib['lan'], 'lan'),
  new IconDefinition(iconLib['lanConnect'], 'lan-connect'),
  new IconDefinition(iconLib['lanDisconnect'], 'lan-disconnect'),
  new IconDefinition(iconLib['lanPending'], 'lan-pending'),
  new IconDefinition(iconLib['languageC'], 'language-c'),
  new IconDefinition(iconLib['languageCpp'], 'language-cpp'),
  new IconDefinition(iconLib['languageCsharp'], 'language-csharp'),
  new IconDefinition(iconLib['languageCss3'], 'language-css3'),
  new IconDefinition(iconLib['languageGo'], 'language-go'),
  new IconDefinition(iconLib['languageHaskell'], 'language-haskell'),
  new IconDefinition(iconLib['languageHtml5'], 'language-html5'),
  new IconDefinition(iconLib['languageJava'], 'language-java'),
  new IconDefinition(iconLib['languageJavascript'], 'language-javascript'),
  new IconDefinition(iconLib['languageLua'], 'language-lua'),
  new IconDefinition(iconLib['languagePhp'], 'language-php'),
  new IconDefinition(iconLib['languagePython'], 'language-python'),
  new IconDefinition(iconLib['languagePythonText'], 'language-python-text'),
  new IconDefinition(iconLib['languageR'], 'language-r'),
  new IconDefinition(iconLib['languageRubyOnRails'], 'language-ruby-on-rails'),
  new IconDefinition(iconLib['languageSwift'], 'language-swift'),
  new IconDefinition(iconLib['languageTypescript'], 'language-typescript'),
  new IconDefinition(iconLib['laptop'], 'laptop'),
  new IconDefinition(iconLib['laptopChromebook'], 'laptop-chromebook'),
  new IconDefinition(iconLib['laptopMac'], 'laptop-mac'),
  new IconDefinition(iconLib['laptopOff'], 'laptop-off'),
  new IconDefinition(iconLib['laptopWindows'], 'laptop-windows'),
  new IconDefinition(iconLib['laravel'], 'laravel'),
  new IconDefinition(iconLib['lasso'], 'lasso'),
  new IconDefinition(iconLib['lastfm'], 'lastfm'),
  new IconDefinition(iconLib['lastpass'], 'lastpass'),
  new IconDefinition(iconLib['launch'], 'launch'),
  new IconDefinition(iconLib['lavaLamp'], 'lava-lamp'),
  new IconDefinition(iconLib['layers'], 'layers'),
  new IconDefinition(iconLib['layersMinus'], 'layers-minus'),
  new IconDefinition(iconLib['layersOff'], 'layers-off'),
  new IconDefinition(iconLib['layersOffOutline'], 'layers-off-outline'),
  new IconDefinition(iconLib['layersOutline'], 'layers-outline'),
  new IconDefinition(iconLib['layersPlus'], 'layers-plus'),
  new IconDefinition(iconLib['layersRemove'], 'layers-remove'),
  new IconDefinition(iconLib['leadPencil'], 'lead-pencil'),
  new IconDefinition(iconLib['leaf'], 'leaf'),
  new IconDefinition(iconLib['leafMaple'], 'leaf-maple'),
  new IconDefinition(iconLib['leak'], 'leak'),
  new IconDefinition(iconLib['leakOff'], 'leak-off'),
  new IconDefinition(iconLib['ledOff'], 'led-off'),
  new IconDefinition(iconLib['ledOn'], 'led-on'),
  new IconDefinition(iconLib['ledOutline'], 'led-outline'),
  new IconDefinition(iconLib['ledStrip'], 'led-strip'),
  new IconDefinition(iconLib['ledVariantOff'], 'led-variant-off'),
  new IconDefinition(iconLib['ledVariantOn'], 'led-variant-on'),
  new IconDefinition(iconLib['ledVariantOutline'], 'led-variant-outline'),
  new IconDefinition(iconLib['lessThan'], 'less-than'),
  new IconDefinition(iconLib['lessThanOrEqual'], 'less-than-or-equal'),
  new IconDefinition(iconLib['library'], 'library'),
  new IconDefinition(iconLib['libraryBooks'], 'library-books'),
  new IconDefinition(iconLib['libraryMovie'], 'library-movie'),
  new IconDefinition(iconLib['libraryMusic'], 'library-music'),
  new IconDefinition(iconLib['libraryMusicOutline'], 'library-music-outline'),
  new IconDefinition(iconLib['libraryPlus'], 'library-plus'),
  new IconDefinition(iconLib['libraryShelves'], 'library-shelves'),
  new IconDefinition(iconLib['libraryVideo'], 'library-video'),
  new IconDefinition(iconLib['lifebuoy'], 'lifebuoy'),
  new IconDefinition(iconLib['lightSwitch'], 'light-switch'),
  new IconDefinition(iconLib['lightbulb'], 'lightbulb'),
  new IconDefinition(iconLib['lightbulbOff'], 'lightbulb-off'),
  new IconDefinition(iconLib['lightbulbOffOutline'], 'lightbulb-off-outline'),
  new IconDefinition(iconLib['lightbulbOn'], 'lightbulb-on'),
  new IconDefinition(iconLib['lightbulbOnOutline'], 'lightbulb-on-outline'),
  new IconDefinition(iconLib['lightbulbOutline'], 'lightbulb-outline'),
  new IconDefinition(iconLib['lighthouse'], 'lighthouse'),
  new IconDefinition(iconLib['lighthouseOn'], 'lighthouse-on'),
  new IconDefinition(iconLib['link'], 'link'),
  new IconDefinition(iconLib['linkBox'], 'link-box'),
  new IconDefinition(iconLib['linkBoxOutline'], 'link-box-outline'),
  new IconDefinition(iconLib['linkBoxVariant'], 'link-box-variant'),
  new IconDefinition(iconLib['linkBoxVariantOutline'], 'link-box-variant-outline'),
  new IconDefinition(iconLib['linkOff'], 'link-off'),
  new IconDefinition(iconLib['linkPlus'], 'link-plus'),
  new IconDefinition(iconLib['linkVariant'], 'link-variant'),
  new IconDefinition(iconLib['linkVariantOff'], 'link-variant-off'),
  new IconDefinition(iconLib['linkedin'], 'linkedin'),
  new IconDefinition(iconLib['linkedinBox'], 'linkedin-box'),
  new IconDefinition(iconLib['linux'], 'linux'),
  new IconDefinition(iconLib['linuxMint'], 'linux-mint'),
  new IconDefinition(iconLib['litecoin'], 'litecoin'),
  new IconDefinition(iconLib['loading'], 'loading'),
  new IconDefinition(iconLib['lock'], 'lock'),
  new IconDefinition(iconLib['lockAlert'], 'lock-alert'),
  new IconDefinition(iconLib['lockClock'], 'lock-clock'),
  new IconDefinition(iconLib['lockOpen'], 'lock-open'),
  new IconDefinition(iconLib['lockOpenOutline'], 'lock-open-outline'),
  new IconDefinition(iconLib['lockOutline'], 'lock-outline'),
  new IconDefinition(iconLib['lockPattern'], 'lock-pattern'),
  new IconDefinition(iconLib['lockPlus'], 'lock-plus'),
  new IconDefinition(iconLib['lockQuestion'], 'lock-question'),
  new IconDefinition(iconLib['lockReset'], 'lock-reset'),
  new IconDefinition(iconLib['lockSmart'], 'lock-smart'),
  new IconDefinition(iconLib['locker'], 'locker'),
  new IconDefinition(iconLib['lockerMultiple'], 'locker-multiple'),
  new IconDefinition(iconLib['login'], 'login'),
  new IconDefinition(iconLib['loginVariant'], 'login-variant'),
  new IconDefinition(iconLib['logout'], 'logout'),
  new IconDefinition(iconLib['logoutVariant'], 'logout-variant'),
  new IconDefinition(iconLib['looks'], 'looks'),
  new IconDefinition(iconLib['loop'], 'loop'),
  new IconDefinition(iconLib['loupe'], 'loupe'),
  new IconDefinition(iconLib['lumx'], 'lumx'),
  new IconDefinition(iconLib['lyft'], 'lyft'),
  new IconDefinition(iconLib['magnet'], 'magnet'),
  new IconDefinition(iconLib['magnetOn'], 'magnet-on'),
  new IconDefinition(iconLib['magnify'], 'magnify'),
  new IconDefinition(iconLib['magnifyClose'], 'magnify-close'),
  new IconDefinition(iconLib['magnifyMinus'], 'magnify-minus'),
  new IconDefinition(iconLib['magnifyMinusCursor'], 'magnify-minus-cursor'),
  new IconDefinition(iconLib['magnifyMinusOutline'], 'magnify-minus-outline'),
  new IconDefinition(iconLib['magnifyPlus'], 'magnify-plus'),
  new IconDefinition(iconLib['magnifyPlusCursor'], 'magnify-plus-cursor'),
  new IconDefinition(iconLib['magnifyPlusOutline'], 'magnify-plus-outline'),
  new IconDefinition(iconLib['mail'], 'mail'),
  new IconDefinition(iconLib['mailRu'], 'mail-ru'),
  new IconDefinition(iconLib['mailbox'], 'mailbox'),
  new IconDefinition(iconLib['mailboxOpen'], 'mailbox-open'),
  new IconDefinition(iconLib['mailboxOpenOutline'], 'mailbox-open-outline'),
  new IconDefinition(iconLib['mailboxOpenUp'], 'mailbox-open-up'),
  new IconDefinition(iconLib['mailboxOpenUpOutline'], 'mailbox-open-up-outline'),
  new IconDefinition(iconLib['mailboxOutline'], 'mailbox-outline'),
  new IconDefinition(iconLib['mailboxUp'], 'mailbox-up'),
  new IconDefinition(iconLib['mailboxUpOutline'], 'mailbox-up-outline'),
  new IconDefinition(iconLib['map'], 'map'),
  new IconDefinition(iconLib['mapCheck'], 'map-check'),
  new IconDefinition(iconLib['mapCheckOutline'], 'map-check-outline'),
  new IconDefinition(iconLib['mapClock'], 'map-clock'),
  new IconDefinition(iconLib['mapClockOutline'], 'map-clock-outline'),
  new IconDefinition(iconLib['mapLegend'], 'map-legend'),
  new IconDefinition(iconLib['mapMarker'], 'map-marker'),
  new IconDefinition(iconLib['mapMarkerAlert'], 'map-marker-alert'),
  new IconDefinition(iconLib['mapMarkerAlertOutline'], 'map-marker-alert-outline'),
  new IconDefinition(iconLib['mapMarkerCheck'], 'map-marker-check'),
  new IconDefinition(iconLib['mapMarkerCircle'], 'map-marker-circle'),
  new IconDefinition(iconLib['mapMarkerDistance'], 'map-marker-distance'),
  new IconDefinition(iconLib['mapMarkerMinus'], 'map-marker-minus'),
  new IconDefinition(iconLib['mapMarkerMultiple'], 'map-marker-multiple'),
  new IconDefinition(iconLib['mapMarkerOff'], 'map-marker-off'),
  new IconDefinition(iconLib['mapMarkerOutline'], 'map-marker-outline'),
  new IconDefinition(iconLib['mapMarkerPath'], 'map-marker-path'),
  new IconDefinition(iconLib['mapMarkerPlus'], 'map-marker-plus'),
  new IconDefinition(iconLib['mapMarkerQuestion'], 'map-marker-question'),
  new IconDefinition(iconLib['mapMarkerQuestionOutline'], 'map-marker-question-outline'),
  new IconDefinition(iconLib['mapMarkerRadius'], 'map-marker-radius'),
  new IconDefinition(iconLib['mapMarkerRemove'], 'map-marker-remove'),
  new IconDefinition(iconLib['mapMarkerRemoveVariant'], 'map-marker-remove-variant'),
  new IconDefinition(iconLib['mapMinus'], 'map-minus'),
  new IconDefinition(iconLib['mapOutline'], 'map-outline'),
  new IconDefinition(iconLib['mapPlus'], 'map-plus'),
  new IconDefinition(iconLib['mapSearch'], 'map-search'),
  new IconDefinition(iconLib['mapSearchOutline'], 'map-search-outline'),
  new IconDefinition(iconLib['mapbox'], 'mapbox'),
  new IconDefinition(iconLib['margin'], 'margin'),
  new IconDefinition(iconLib['markdown'], 'markdown'),
  new IconDefinition(iconLib['marker'], 'marker'),
  new IconDefinition(iconLib['markerCancel'], 'marker-cancel'),
  new IconDefinition(iconLib['markerCheck'], 'marker-check'),
  new IconDefinition(iconLib['mastodon'], 'mastodon'),
  new IconDefinition(iconLib['mastodonVariant'], 'mastodon-variant'),
  new IconDefinition(iconLib['materialDesign'], 'material-design'),
  new IconDefinition(iconLib['materialUi'], 'material-ui'),
  new IconDefinition(iconLib['mathCompass'], 'math-compass'),
  new IconDefinition(iconLib['mathCos'], 'math-cos'),
  new IconDefinition(iconLib['mathSin'], 'math-sin'),
  new IconDefinition(iconLib['mathTan'], 'math-tan'),
  new IconDefinition(iconLib['matrix'], 'matrix'),
  new IconDefinition(iconLib['maxcdn'], 'maxcdn'),
  new IconDefinition(iconLib['medal'], 'medal'),
  new IconDefinition(iconLib['medicalBag'], 'medical-bag'),
  new IconDefinition(iconLib['medium'], 'medium'),
  new IconDefinition(iconLib['meetup'], 'meetup'),
  new IconDefinition(iconLib['memory'], 'memory'),
  new IconDefinition(iconLib['menu'], 'menu'),
  new IconDefinition(iconLib['menuDown'], 'menu-down'),
  new IconDefinition(iconLib['menuDownOutline'], 'menu-down-outline'),
  new IconDefinition(iconLib['menuLeft'], 'menu-left'),
  new IconDefinition(iconLib['menuLeftOutline'], 'menu-left-outline'),
  new IconDefinition(iconLib['menuOpen'], 'menu-open'),
  new IconDefinition(iconLib['menuRight'], 'menu-right'),
  new IconDefinition(iconLib['menuRightOutline'], 'menu-right-outline'),
  new IconDefinition(iconLib['menuSwap'], 'menu-swap'),
  new IconDefinition(iconLib['menuSwapOutline'], 'menu-swap-outline'),
  new IconDefinition(iconLib['menuUp'], 'menu-up'),
  new IconDefinition(iconLib['menuUpOutline'], 'menu-up-outline'),
  new IconDefinition(iconLib['message'], 'message'),
  new IconDefinition(iconLib['messageAlert'], 'message-alert'),
  new IconDefinition(iconLib['messageAlertOutline'], 'message-alert-outline'),
  new IconDefinition(iconLib['messageBulleted'], 'message-bulleted'),
  new IconDefinition(iconLib['messageBulletedOff'], 'message-bulleted-off'),
  new IconDefinition(iconLib['messageDraw'], 'message-draw'),
  new IconDefinition(iconLib['messageImage'], 'message-image'),
  new IconDefinition(iconLib['messageOutline'], 'message-outline'),
  new IconDefinition(iconLib['messagePlus'], 'message-plus'),
  new IconDefinition(iconLib['messageProcessing'], 'message-processing'),
  new IconDefinition(iconLib['messageReply'], 'message-reply'),
  new IconDefinition(iconLib['messageReplyText'], 'message-reply-text'),
  new IconDefinition(iconLib['messageSettings'], 'message-settings'),
  new IconDefinition(iconLib['messageSettingsVariant'], 'message-settings-variant'),
  new IconDefinition(iconLib['messageText'], 'message-text'),
  new IconDefinition(iconLib['messageTextOutline'], 'message-text-outline'),
  new IconDefinition(iconLib['messageVideo'], 'message-video'),
  new IconDefinition(iconLib['meteor'], 'meteor'),
  new IconDefinition(iconLib['metronome'], 'metronome'),
  new IconDefinition(iconLib['metronomeTick'], 'metronome-tick'),
  new IconDefinition(iconLib['microSd'], 'micro-sd'),
  new IconDefinition(iconLib['microphone'], 'microphone'),
  new IconDefinition(iconLib['microphoneMinus'], 'microphone-minus'),
  new IconDefinition(iconLib['microphoneOff'], 'microphone-off'),
  new IconDefinition(iconLib['microphoneOutline'], 'microphone-outline'),
  new IconDefinition(iconLib['microphonePlus'], 'microphone-plus'),
  new IconDefinition(iconLib['microphoneSettings'], 'microphone-settings'),
  new IconDefinition(iconLib['microphoneVariant'], 'microphone-variant'),
  new IconDefinition(iconLib['microphoneVariantOff'], 'microphone-variant-off'),
  new IconDefinition(iconLib['microscope'], 'microscope'),
  new IconDefinition(iconLib['microsoft'], 'microsoft'),
  new IconDefinition(iconLib['microsoftDynamics'], 'microsoft-dynamics'),
  new IconDefinition(iconLib['microwave'], 'microwave'),
  new IconDefinition(iconLib['midi'], 'midi'),
  new IconDefinition(iconLib['midiPort'], 'midi-port'),
  new IconDefinition(iconLib['mine'], 'mine'),
  new IconDefinition(iconLib['minecraft'], 'minecraft'),
  new IconDefinition(iconLib['miniSd'], 'mini-sd'),
  new IconDefinition(iconLib['minidisc'], 'minidisc'),
  new IconDefinition(iconLib['minus'], 'minus'),
  new IconDefinition(iconLib['minusBox'], 'minus-box'),
  new IconDefinition(iconLib['minusBoxOutline'], 'minus-box-outline'),
  new IconDefinition(iconLib['minusCircle'], 'minus-circle'),
  new IconDefinition(iconLib['minusCircleOutline'], 'minus-circle-outline'),
  new IconDefinition(iconLib['minusNetwork'], 'minus-network'),
  new IconDefinition(iconLib['minusNetworkOutline'], 'minus-network-outline'),
  new IconDefinition(iconLib['mixcloud'], 'mixcloud'),
  new IconDefinition(iconLib['mixedMartialArts'], 'mixed-martial-arts'),
  new IconDefinition(iconLib['mixedReality'], 'mixed-reality'),
  new IconDefinition(iconLib['mixer'], 'mixer'),
  new IconDefinition(iconLib['molecule'], 'molecule'),
  new IconDefinition(iconLib['monitor'], 'monitor'),
  new IconDefinition(iconLib['monitorCellphone'], 'monitor-cellphone'),
  new IconDefinition(iconLib['monitorCellphoneStar'], 'monitor-cellphone-star'),
  new IconDefinition(iconLib['monitorDashboard'], 'monitor-dashboard'),
  new IconDefinition(iconLib['monitorLock'], 'monitor-lock'),
  new IconDefinition(iconLib['monitorMultiple'], 'monitor-multiple'),
  new IconDefinition(iconLib['monitorOff'], 'monitor-off'),
  new IconDefinition(iconLib['monitorScreenshot'], 'monitor-screenshot'),
  new IconDefinition(iconLib['monitorStar'], 'monitor-star'),
  new IconDefinition(iconLib['more'], 'more'),
  new IconDefinition(iconLib['motherNurse'], 'mother-nurse'),
  new IconDefinition(iconLib['motionSensor'], 'motion-sensor'),
  new IconDefinition(iconLib['motorbike'], 'motorbike'),
  new IconDefinition(iconLib['mouse'], 'mouse'),
  new IconDefinition(iconLib['mouseBluetooth'], 'mouse-bluetooth'),
  new IconDefinition(iconLib['mouseOff'], 'mouse-off'),
  new IconDefinition(iconLib['mouseVariant'], 'mouse-variant'),
  new IconDefinition(iconLib['mouseVariantOff'], 'mouse-variant-off'),
  new IconDefinition(iconLib['moveResize'], 'move-resize'),
  new IconDefinition(iconLib['moveResizeVariant'], 'move-resize-variant'),
  new IconDefinition(iconLib['movie'], 'movie'),
  new IconDefinition(iconLib['movieOutline'], 'movie-outline'),
  new IconDefinition(iconLib['movieRoll'], 'movie-roll'),
  new IconDefinition(iconLib['muffin'], 'muffin'),
  new IconDefinition(iconLib['multiplication'], 'multiplication'),
  new IconDefinition(iconLib['multiplicationBox'], 'multiplication-box'),
  new IconDefinition(iconLib['mushroom'], 'mushroom'),
  new IconDefinition(iconLib['mushroomOutline'], 'mushroom-outline'),
  new IconDefinition(iconLib['music'], 'music'),
  new IconDefinition(iconLib['musicBox'], 'music-box'),
  new IconDefinition(iconLib['musicBoxOutline'], 'music-box-outline'),
  new IconDefinition(iconLib['musicCircle'], 'music-circle'),
  new IconDefinition(iconLib['musicCircleOutline'], 'music-circle-outline'),
  new IconDefinition(iconLib['musicNote'], 'music-note'),
  new IconDefinition(iconLib['musicNoteBluetooth'], 'music-note-bluetooth'),
  new IconDefinition(iconLib['musicNoteBluetoothOff'], 'music-note-bluetooth-off'),
  new IconDefinition(iconLib['musicNoteEighth'], 'music-note-eighth'),
  new IconDefinition(iconLib['musicNoteHalf'], 'music-note-half'),
  new IconDefinition(iconLib['musicNoteOff'], 'music-note-off'),
  new IconDefinition(iconLib['musicNotePlus'], 'music-note-plus'),
  new IconDefinition(iconLib['musicNoteQuarter'], 'music-note-quarter'),
  new IconDefinition(iconLib['musicNoteSixteenth'], 'music-note-sixteenth'),
  new IconDefinition(iconLib['musicNoteWhole'], 'music-note-whole'),
  new IconDefinition(iconLib['musicOff'], 'music-off'),
  new IconDefinition(iconLib['nail'], 'nail'),
  new IconDefinition(iconLib['nas'], 'nas'),
  new IconDefinition(iconLib['nativescript'], 'nativescript'),
  new IconDefinition(iconLib['nature'], 'nature'),
  new IconDefinition(iconLib['naturePeople'], 'nature-people'),
  new IconDefinition(iconLib['navigation'], 'navigation'),
  new IconDefinition(iconLib['nearMe'], 'near-me'),
  new IconDefinition(iconLib['necklace'], 'necklace'),
  new IconDefinition(iconLib['needle'], 'needle'),
  new IconDefinition(iconLib['netflix'], 'netflix'),
  new IconDefinition(iconLib['network'], 'network'),
  new IconDefinition(iconLib['networkOff'], 'network-off'),
  new IconDefinition(iconLib['networkOffOutline'], 'network-off-outline'),
  new IconDefinition(iconLib['networkOutline'], 'network-outline'),
  new IconDefinition(iconLib['networkStrength1'], 'network-strength-1'),
  new IconDefinition(iconLib['networkStrength1Alert'], 'network-strength-1-alert'),
  new IconDefinition(iconLib['networkStrength2'], 'network-strength-2'),
  new IconDefinition(iconLib['networkStrength2Alert'], 'network-strength-2-alert'),
  new IconDefinition(iconLib['networkStrength3'], 'network-strength-3'),
  new IconDefinition(iconLib['networkStrength3Alert'], 'network-strength-3-alert'),
  new IconDefinition(iconLib['networkStrength4'], 'network-strength-4'),
  new IconDefinition(iconLib['networkStrength4Alert'], 'network-strength-4-alert'),
  new IconDefinition(iconLib['networkStrengthOff'], 'network-strength-off'),
  new IconDefinition(iconLib['networkStrengthOffOutline'], 'network-strength-off-outline'),
  new IconDefinition(iconLib['networkStrengthOutline'], 'network-strength-outline'),
  new IconDefinition(iconLib['newBox'], 'new-box'),
  new IconDefinition(iconLib['newspaper'], 'newspaper'),
  new IconDefinition(iconLib['newspaperMinus'], 'newspaper-minus'),
  new IconDefinition(iconLib['newspaperPlus'], 'newspaper-plus'),
  new IconDefinition(iconLib['nfc'], 'nfc'),
  new IconDefinition(iconLib['nfcOff'], 'nfc-off'),
  new IconDefinition(iconLib['nfcSearchVariant'], 'nfc-search-variant'),
  new IconDefinition(iconLib['nfcTap'], 'nfc-tap'),
  new IconDefinition(iconLib['nfcVariant'], 'nfc-variant'),
  new IconDefinition(iconLib['nfcVariantOff'], 'nfc-variant-off'),
  new IconDefinition(iconLib['ninja'], 'ninja'),
  new IconDefinition(iconLib['nintendoSwitch'], 'nintendo-switch'),
  new IconDefinition(iconLib['nodejs'], 'nodejs'),
  new IconDefinition(iconLib['notEqual'], 'not-equal'),
  new IconDefinition(iconLib['notEqualVariant'], 'not-equal-variant'),
  new IconDefinition(iconLib['note'], 'note'),
  new IconDefinition(iconLib['noteCircle'], 'note-circle'),
  new IconDefinition(iconLib['noteMultiple'], 'note-multiple'),
  new IconDefinition(iconLib['noteMultipleOutline'], 'note-multiple-outline'),
  new IconDefinition(iconLib['noteOutline'], 'note-outline'),
  new IconDefinition(iconLib['notePlus'], 'note-plus'),
  new IconDefinition(iconLib['notePlusOutline'], 'note-plus-outline'),
  new IconDefinition(iconLib['noteText'], 'note-text'),
  new IconDefinition(iconLib['notebook'], 'notebook'),
  new IconDefinition(iconLib['notebookMultiple'], 'notebook-multiple'),
  new IconDefinition(iconLib['notebookOutline'], 'notebook-outline'),
  new IconDefinition(iconLib['notificationClearAll'], 'notification-clear-all'),
  new IconDefinition(iconLib['npm'], 'npm'),
  new IconDefinition(iconLib['npmVariant'], 'npm-variant'),
  new IconDefinition(iconLib['npmVariantOutline'], 'npm-variant-outline'),
  new IconDefinition(iconLib['nuke'], 'nuke'),
  new IconDefinition(iconLib['nullIcon'], 'null'),
  new IconDefinition(iconLib['numeric'], 'numeric'),
  new IconDefinition(iconLib['numeric0'], 'numeric-0'),
  new IconDefinition(iconLib['numeric0Box'], 'numeric-0-box'),
  new IconDefinition(iconLib['numeric0BoxMultiple'], 'numeric-0-box-multiple'),
  new IconDefinition(iconLib['numeric0BoxMultipleOutline'], 'numeric-0-box-multiple-outline'),
  new IconDefinition(iconLib['numeric0BoxOutline'], 'numeric-0-box-outline'),
  new IconDefinition(iconLib['numeric0Circle'], 'numeric-0-circle'),
  new IconDefinition(iconLib['numeric0CircleOutline'], 'numeric-0-circle-outline'),
  new IconDefinition(iconLib['numeric1'], 'numeric-1'),
  new IconDefinition(iconLib['numeric1Box'], 'numeric-1-box'),
  new IconDefinition(iconLib['numeric1BoxMultiple'], 'numeric-1-box-multiple'),
  new IconDefinition(iconLib['numeric1BoxMultipleOutline'], 'numeric-1-box-multiple-outline'),
  new IconDefinition(iconLib['numeric1BoxOutline'], 'numeric-1-box-outline'),
  new IconDefinition(iconLib['numeric1Circle'], 'numeric-1-circle'),
  new IconDefinition(iconLib['numeric1CircleOutline'], 'numeric-1-circle-outline'),
  new IconDefinition(iconLib['numeric2'], 'numeric-2'),
  new IconDefinition(iconLib['numeric2Box'], 'numeric-2-box'),
  new IconDefinition(iconLib['numeric2BoxMultiple'], 'numeric-2-box-multiple'),
  new IconDefinition(iconLib['numeric2BoxMultipleOutline'], 'numeric-2-box-multiple-outline'),
  new IconDefinition(iconLib['numeric2BoxOutline'], 'numeric-2-box-outline'),
  new IconDefinition(iconLib['numeric2Circle'], 'numeric-2-circle'),
  new IconDefinition(iconLib['numeric2CircleOutline'], 'numeric-2-circle-outline'),
  new IconDefinition(iconLib['numeric3'], 'numeric-3'),
  new IconDefinition(iconLib['numeric3Box'], 'numeric-3-box'),
  new IconDefinition(iconLib['numeric3BoxMultiple'], 'numeric-3-box-multiple'),
  new IconDefinition(iconLib['numeric3BoxMultipleOutline'], 'numeric-3-box-multiple-outline'),
  new IconDefinition(iconLib['numeric3BoxOutline'], 'numeric-3-box-outline'),
  new IconDefinition(iconLib['numeric3Circle'], 'numeric-3-circle'),
  new IconDefinition(iconLib['numeric3CircleOutline'], 'numeric-3-circle-outline'),
  new IconDefinition(iconLib['numeric4'], 'numeric-4'),
  new IconDefinition(iconLib['numeric4Box'], 'numeric-4-box'),
  new IconDefinition(iconLib['numeric4BoxMultiple'], 'numeric-4-box-multiple'),
  new IconDefinition(iconLib['numeric4BoxMultipleOutline'], 'numeric-4-box-multiple-outline'),
  new IconDefinition(iconLib['numeric4BoxOutline'], 'numeric-4-box-outline'),
  new IconDefinition(iconLib['numeric4Circle'], 'numeric-4-circle'),
  new IconDefinition(iconLib['numeric4CircleOutline'], 'numeric-4-circle-outline'),
  new IconDefinition(iconLib['numeric5'], 'numeric-5'),
  new IconDefinition(iconLib['numeric5Box'], 'numeric-5-box'),
  new IconDefinition(iconLib['numeric5BoxMultiple'], 'numeric-5-box-multiple'),
  new IconDefinition(iconLib['numeric5BoxMultipleOutline'], 'numeric-5-box-multiple-outline'),
  new IconDefinition(iconLib['numeric5BoxOutline'], 'numeric-5-box-outline'),
  new IconDefinition(iconLib['numeric5Circle'], 'numeric-5-circle'),
  new IconDefinition(iconLib['numeric5CircleOutline'], 'numeric-5-circle-outline'),
  new IconDefinition(iconLib['numeric6'], 'numeric-6'),
  new IconDefinition(iconLib['numeric6Box'], 'numeric-6-box'),
  new IconDefinition(iconLib['numeric6BoxMultiple'], 'numeric-6-box-multiple'),
  new IconDefinition(iconLib['numeric6BoxMultipleOutline'], 'numeric-6-box-multiple-outline'),
  new IconDefinition(iconLib['numeric6BoxOutline'], 'numeric-6-box-outline'),
  new IconDefinition(iconLib['numeric6Circle'], 'numeric-6-circle'),
  new IconDefinition(iconLib['numeric6CircleOutline'], 'numeric-6-circle-outline'),
  new IconDefinition(iconLib['numeric7'], 'numeric-7'),
  new IconDefinition(iconLib['numeric7Box'], 'numeric-7-box'),
  new IconDefinition(iconLib['numeric7BoxMultiple'], 'numeric-7-box-multiple'),
  new IconDefinition(iconLib['numeric7BoxMultipleOutline'], 'numeric-7-box-multiple-outline'),
  new IconDefinition(iconLib['numeric7BoxOutline'], 'numeric-7-box-outline'),
  new IconDefinition(iconLib['numeric7Circle'], 'numeric-7-circle'),
  new IconDefinition(iconLib['numeric7CircleOutline'], 'numeric-7-circle-outline'),
  new IconDefinition(iconLib['numeric8'], 'numeric-8'),
  new IconDefinition(iconLib['numeric8Box'], 'numeric-8-box'),
  new IconDefinition(iconLib['numeric8BoxMultiple'], 'numeric-8-box-multiple'),
  new IconDefinition(iconLib['numeric8BoxMultipleOutline'], 'numeric-8-box-multiple-outline'),
  new IconDefinition(iconLib['numeric8BoxOutline'], 'numeric-8-box-outline'),
  new IconDefinition(iconLib['numeric8Circle'], 'numeric-8-circle'),
  new IconDefinition(iconLib['numeric8CircleOutline'], 'numeric-8-circle-outline'),
  new IconDefinition(iconLib['numeric9'], 'numeric-9'),
  new IconDefinition(iconLib['numeric9Box'], 'numeric-9-box'),
  new IconDefinition(iconLib['numeric9BoxMultiple'], 'numeric-9-box-multiple'),
  new IconDefinition(iconLib['numeric9BoxMultipleOutline'], 'numeric-9-box-multiple-outline'),
  new IconDefinition(iconLib['numeric9BoxOutline'], 'numeric-9-box-outline'),
  new IconDefinition(iconLib['numeric9Circle'], 'numeric-9-circle'),
  new IconDefinition(iconLib['numeric9CircleOutline'], 'numeric-9-circle-outline'),
  new IconDefinition(iconLib['numeric9PlusBox'], 'numeric-9-plus-box'),
  new IconDefinition(iconLib['numeric9PlusBoxMultiple'], 'numeric-9-plus-box-multiple'),
  new IconDefinition(iconLib['numeric9PlusBoxMultipleOutline'], 'numeric-9-plus-box-multiple-outline'),
  new IconDefinition(iconLib['numeric9PlusBoxOutline'], 'numeric-9-plus-box-outline'),
  new IconDefinition(iconLib['numeric9PlusCircle'], 'numeric-9-plus-circle'),
  new IconDefinition(iconLib['numeric9PlusCircleOutline'], 'numeric-9-plus-circle-outline'),
  new IconDefinition(iconLib['nut'], 'nut'),
  new IconDefinition(iconLib['nutrition'], 'nutrition'),
  new IconDefinition(iconLib['oar'], 'oar'),
  new IconDefinition(iconLib['ocarina'], 'ocarina'),
  new IconDefinition(iconLib['octagon'], 'octagon'),
  new IconDefinition(iconLib['octagonOutline'], 'octagon-outline'),
  new IconDefinition(iconLib['octagram'], 'octagram'),
  new IconDefinition(iconLib['octagramOutline'], 'octagram-outline'),
  new IconDefinition(iconLib['odnoklassniki'], 'odnoklassniki'),
  new IconDefinition(iconLib['office'], 'office'),
  new IconDefinition(iconLib['officeBuilding'], 'office-building'),
  new IconDefinition(iconLib['oil'], 'oil'),
  new IconDefinition(iconLib['oilLamp'], 'oil-lamp'),
  new IconDefinition(iconLib['oilTemperature'], 'oil-temperature'),
  new IconDefinition(iconLib['omega'], 'omega'),
  new IconDefinition(iconLib['oneUp'], 'one-up'),
  new IconDefinition(iconLib['onedrive'], 'onedrive'),
  new IconDefinition(iconLib['onenote'], 'onenote'),
  new IconDefinition(iconLib['onepassword'], 'onepassword'),
  new IconDefinition(iconLib['opacity'], 'opacity'),
  new IconDefinition(iconLib['openInApp'], 'open-in-app'),
  new IconDefinition(iconLib['openInNew'], 'open-in-new'),
  new IconDefinition(iconLib['openSourceInitiative'], 'open-source-initiative'),
  new IconDefinition(iconLib['openid'], 'openid'),
  new IconDefinition(iconLib['opera'], 'opera'),
  new IconDefinition(iconLib['orbit'], 'orbit'),
  new IconDefinition(iconLib['origin'], 'origin'),
  new IconDefinition(iconLib['ornament'], 'ornament'),
  new IconDefinition(iconLib['ornamentVariant'], 'ornament-variant'),
  new IconDefinition(iconLib['outlook'], 'outlook'),
  new IconDefinition(iconLib['owl'], 'owl'),
  new IconDefinition(iconLib['pacMan'], 'pac-man'),
  new IconDefinition(iconLib['package'], 'package'),
  new IconDefinition(iconLib['packageDown'], 'package-down'),
  new IconDefinition(iconLib['packageUp'], 'package-up'),
  new IconDefinition(iconLib['packageVariant'], 'package-variant'),
  new IconDefinition(iconLib['packageVariantClosed'], 'package-variant-closed'),
  new IconDefinition(iconLib['pageFirst'], 'page-first'),
  new IconDefinition(iconLib['pageLast'], 'page-last'),
  new IconDefinition(iconLib['pageLayoutBody'], 'page-layout-body'),
  new IconDefinition(iconLib['pageLayoutFooter'], 'page-layout-footer'),
  new IconDefinition(iconLib['pageLayoutHeader'], 'page-layout-header'),
  new IconDefinition(iconLib['pageLayoutSidebarLeft'], 'page-layout-sidebar-left'),
  new IconDefinition(iconLib['pageLayoutSidebarRight'], 'page-layout-sidebar-right'),
  new IconDefinition(iconLib['pageNext'], 'page-next'),
  new IconDefinition(iconLib['pageNextOutline'], 'page-next-outline'),
  new IconDefinition(iconLib['pagePrevious'], 'page-previous'),
  new IconDefinition(iconLib['pagePreviousOutline'], 'page-previous-outline'),
  new IconDefinition(iconLib['palette'], 'palette'),
  new IconDefinition(iconLib['paletteAdvanced'], 'palette-advanced'),
  new IconDefinition(iconLib['paletteOutline'], 'palette-outline'),
  new IconDefinition(iconLib['paletteSwatch'], 'palette-swatch'),
  new IconDefinition(iconLib['pan'], 'pan'),
  new IconDefinition(iconLib['panBottomLeft'], 'pan-bottom-left'),
  new IconDefinition(iconLib['panBottomRight'], 'pan-bottom-right'),
  new IconDefinition(iconLib['panDown'], 'pan-down'),
  new IconDefinition(iconLib['panHorizontal'], 'pan-horizontal'),
  new IconDefinition(iconLib['panLeft'], 'pan-left'),
  new IconDefinition(iconLib['panRight'], 'pan-right'),
  new IconDefinition(iconLib['panTopLeft'], 'pan-top-left'),
  new IconDefinition(iconLib['panTopRight'], 'pan-top-right'),
  new IconDefinition(iconLib['panUp'], 'pan-up'),
  new IconDefinition(iconLib['panVertical'], 'pan-vertical'),
  new IconDefinition(iconLib['panda'], 'panda'),
  new IconDefinition(iconLib['pandora'], 'pandora'),
  new IconDefinition(iconLib['panorama'], 'panorama'),
  new IconDefinition(iconLib['panoramaFisheye'], 'panorama-fisheye'),
  new IconDefinition(iconLib['panoramaHorizontal'], 'panorama-horizontal'),
  new IconDefinition(iconLib['panoramaVertical'], 'panorama-vertical'),
  new IconDefinition(iconLib['panoramaWideAngle'], 'panorama-wide-angle'),
  new IconDefinition(iconLib['paperCutVertical'], 'paper-cut-vertical'),
  new IconDefinition(iconLib['paperclip'], 'paperclip'),
  new IconDefinition(iconLib['parachute'], 'parachute'),
  new IconDefinition(iconLib['parachuteOutline'], 'parachute-outline'),
  new IconDefinition(iconLib['parking'], 'parking'),
  new IconDefinition(iconLib['passport'], 'passport'),
  new IconDefinition(iconLib['passportBiometric'], 'passport-biometric'),
  new IconDefinition(iconLib['patreon'], 'patreon'),
  new IconDefinition(iconLib['pause'], 'pause'),
  new IconDefinition(iconLib['pauseCircle'], 'pause-circle'),
  new IconDefinition(iconLib['pauseCircleOutline'], 'pause-circle-outline'),
  new IconDefinition(iconLib['pauseOctagon'], 'pause-octagon'),
  new IconDefinition(iconLib['pauseOctagonOutline'], 'pause-octagon-outline'),
  new IconDefinition(iconLib['paw'], 'paw'),
  new IconDefinition(iconLib['pawOff'], 'paw-off'),
  new IconDefinition(iconLib['paypal'], 'paypal'),
  new IconDefinition(iconLib['pdfBox'], 'pdf-box'),
  new IconDefinition(iconLib['peace'], 'peace'),
  new IconDefinition(iconLib['pen'], 'pen'),
  new IconDefinition(iconLib['penLock'], 'pen-lock'),
  new IconDefinition(iconLib['penMinus'], 'pen-minus'),
  new IconDefinition(iconLib['penOff'], 'pen-off'),
  new IconDefinition(iconLib['penPlus'], 'pen-plus'),
  new IconDefinition(iconLib['penRemove'], 'pen-remove'),
  new IconDefinition(iconLib['pencil'], 'pencil'),
  new IconDefinition(iconLib['pencilBox'], 'pencil-box'),
  new IconDefinition(iconLib['pencilBoxOutline'], 'pencil-box-outline'),
  new IconDefinition(iconLib['pencilCircle'], 'pencil-circle'),
  new IconDefinition(iconLib['pencilCircleOutline'], 'pencil-circle-outline'),
  new IconDefinition(iconLib['pencilLock'], 'pencil-lock'),
  new IconDefinition(iconLib['pencilLockOutline'], 'pencil-lock-outline'),
  new IconDefinition(iconLib['pencilMinus'], 'pencil-minus'),
  new IconDefinition(iconLib['pencilMinusOutline'], 'pencil-minus-outline'),
  new IconDefinition(iconLib['pencilOff'], 'pencil-off'),
  new IconDefinition(iconLib['pencilOffOutline'], 'pencil-off-outline'),
  new IconDefinition(iconLib['pencilOutline'], 'pencil-outline'),
  new IconDefinition(iconLib['pencilPlus'], 'pencil-plus'),
  new IconDefinition(iconLib['pencilPlusOutline'], 'pencil-plus-outline'),
  new IconDefinition(iconLib['pencilRemove'], 'pencil-remove'),
  new IconDefinition(iconLib['pencilRemoveOutline'], 'pencil-remove-outline'),
  new IconDefinition(iconLib['penguin'], 'penguin'),
  new IconDefinition(iconLib['pentagon'], 'pentagon'),
  new IconDefinition(iconLib['pentagonOutline'], 'pentagon-outline'),
  new IconDefinition(iconLib['percent'], 'percent'),
  new IconDefinition(iconLib['periodicTable'], 'periodic-table'),
  new IconDefinition(iconLib['periodicTableCo2'], 'periodic-table-co2'),
  new IconDefinition(iconLib['periscope'], 'periscope'),
  new IconDefinition(iconLib['perspectiveLess'], 'perspective-less'),
  new IconDefinition(iconLib['perspectiveMore'], 'perspective-more'),
  new IconDefinition(iconLib['pharmacy'], 'pharmacy'),
  new IconDefinition(iconLib['phone'], 'phone'),
  new IconDefinition(iconLib['phoneAlert'], 'phone-alert'),
  new IconDefinition(iconLib['phoneBluetooth'], 'phone-bluetooth'),
  new IconDefinition(iconLib['phoneClassic'], 'phone-classic'),
  new IconDefinition(iconLib['phoneForward'], 'phone-forward'),
  new IconDefinition(iconLib['phoneHangup'], 'phone-hangup'),
  new IconDefinition(iconLib['phoneInTalk'], 'phone-in-talk'),
  new IconDefinition(iconLib['phoneIncoming'], 'phone-incoming'),
  new IconDefinition(iconLib['phoneLock'], 'phone-lock'),
  new IconDefinition(iconLib['phoneLog'], 'phone-log'),
  new IconDefinition(iconLib['phoneMinus'], 'phone-minus'),
  new IconDefinition(iconLib['phoneMissed'], 'phone-missed'),
  new IconDefinition(iconLib['phoneOff'], 'phone-off'),
  new IconDefinition(iconLib['phoneOutgoing'], 'phone-outgoing'),
  new IconDefinition(iconLib['phoneOutline'], 'phone-outline'),
  new IconDefinition(iconLib['phonePaused'], 'phone-paused'),
  new IconDefinition(iconLib['phonePlus'], 'phone-plus'),
  new IconDefinition(iconLib['phoneReturn'], 'phone-return'),
  new IconDefinition(iconLib['phoneRotateLandscape'], 'phone-rotate-landscape'),
  new IconDefinition(iconLib['phoneRotatePortrait'], 'phone-rotate-portrait'),
  new IconDefinition(iconLib['phoneSettings'], 'phone-settings'),
  new IconDefinition(iconLib['phoneVoip'], 'phone-voip'),
  new IconDefinition(iconLib['pi'], 'pi'),
  new IconDefinition(iconLib['piBox'], 'pi-box'),
  new IconDefinition(iconLib['piHole'], 'pi-hole'),
  new IconDefinition(iconLib['piano'], 'piano'),
  new IconDefinition(iconLib['pickaxe'], 'pickaxe'),
  new IconDefinition(iconLib['pictureInPictureBottomRight'], 'picture-in-picture-bottom-right'),
  new IconDefinition(iconLib['pictureInPictureBottomRightOutline'], 'picture-in-picture-bottom-right-outline'),
  new IconDefinition(iconLib['pictureInPictureTopRight'], 'picture-in-picture-top-right'),
  new IconDefinition(iconLib['pictureInPictureTopRightOutline'], 'picture-in-picture-top-right-outline'),
  new IconDefinition(iconLib['pier'], 'pier'),
  new IconDefinition(iconLib['pierCrane'], 'pier-crane'),
  new IconDefinition(iconLib['pig'], 'pig'),
  new IconDefinition(iconLib['pill'], 'pill'),
  new IconDefinition(iconLib['pillar'], 'pillar'),
  new IconDefinition(iconLib['pin'], 'pin'),
  new IconDefinition(iconLib['pinOff'], 'pin-off'),
  new IconDefinition(iconLib['pinOffOutline'], 'pin-off-outline'),
  new IconDefinition(iconLib['pinOutline'], 'pin-outline'),
  new IconDefinition(iconLib['pineTree'], 'pine-tree'),
  new IconDefinition(iconLib['pineTreeBox'], 'pine-tree-box'),
  new IconDefinition(iconLib['pinterest'], 'pinterest'),
  new IconDefinition(iconLib['pinterestBox'], 'pinterest-box'),
  new IconDefinition(iconLib['pinwheel'], 'pinwheel'),
  new IconDefinition(iconLib['pinwheelOutline'], 'pinwheel-outline'),
  new IconDefinition(iconLib['pipe'], 'pipe'),
  new IconDefinition(iconLib['pipeDisconnected'], 'pipe-disconnected'),
  new IconDefinition(iconLib['pipeLeak'], 'pipe-leak'),
  new IconDefinition(iconLib['pirate'], 'pirate'),
  new IconDefinition(iconLib['pistol'], 'pistol'),
  new IconDefinition(iconLib['piston'], 'piston'),
  new IconDefinition(iconLib['pizza'], 'pizza'),
  new IconDefinition(iconLib['play'], 'play'),
  new IconDefinition(iconLib['playBoxOutline'], 'play-box-outline'),
  new IconDefinition(iconLib['playCircle'], 'play-circle'),
  new IconDefinition(iconLib['playCircleOutline'], 'play-circle-outline'),
  new IconDefinition(iconLib['playNetwork'], 'play-network'),
  new IconDefinition(iconLib['playNetworkOutline'], 'play-network-outline'),
  new IconDefinition(iconLib['playOutline'], 'play-outline'),
  new IconDefinition(iconLib['playPause'], 'play-pause'),
  new IconDefinition(iconLib['playProtectedContent'], 'play-protected-content'),
  new IconDefinition(iconLib['playSpeed'], 'play-speed'),
  new IconDefinition(iconLib['playlistCheck'], 'playlist-check'),
  new IconDefinition(iconLib['playlistEdit'], 'playlist-edit'),
  new IconDefinition(iconLib['playlistMinus'], 'playlist-minus'),
  new IconDefinition(iconLib['playlistMusic'], 'playlist-music'),
  new IconDefinition(iconLib['playlistMusicOutline'], 'playlist-music-outline'),
  new IconDefinition(iconLib['playlistPlay'], 'playlist-play'),
  new IconDefinition(iconLib['playlistPlus'], 'playlist-plus'),
  new IconDefinition(iconLib['playlistRemove'], 'playlist-remove'),
  new IconDefinition(iconLib['playlistStar'], 'playlist-star'),
  new IconDefinition(iconLib['playstation'], 'playstation'),
  new IconDefinition(iconLib['plex'], 'plex'),
  new IconDefinition(iconLib['plus'], 'plus'),
  new IconDefinition(iconLib['plusBox'], 'plus-box'),
  new IconDefinition(iconLib['plusBoxOutline'], 'plus-box-outline'),
  new IconDefinition(iconLib['plusCircle'], 'plus-circle'),
  new IconDefinition(iconLib['plusCircleMultipleOutline'], 'plus-circle-multiple-outline'),
  new IconDefinition(iconLib['plusCircleOutline'], 'plus-circle-outline'),
  new IconDefinition(iconLib['plusMinus'], 'plus-minus'),
  new IconDefinition(iconLib['plusMinusBox'], 'plus-minus-box'),
  new IconDefinition(iconLib['plusNetwork'], 'plus-network'),
  new IconDefinition(iconLib['plusNetworkOutline'], 'plus-network-outline'),
  new IconDefinition(iconLib['plusOne'], 'plus-one'),
  new IconDefinition(iconLib['plusOutline'], 'plus-outline'),
  new IconDefinition(iconLib['pocket'], 'pocket'),
  new IconDefinition(iconLib['podcast'], 'podcast'),
  new IconDefinition(iconLib['podium'], 'podium'),
  new IconDefinition(iconLib['podiumBronze'], 'podium-bronze'),
  new IconDefinition(iconLib['podiumGold'], 'podium-gold'),
  new IconDefinition(iconLib['podiumSilver'], 'podium-silver'),
  new IconDefinition(iconLib['pointOfSale'], 'point-of-sale'),
  new IconDefinition(iconLib['pokeball'], 'pokeball'),
  new IconDefinition(iconLib['pokemonGo'], 'pokemon-go'),
  new IconDefinition(iconLib['pokerChip'], 'poker-chip'),
  new IconDefinition(iconLib['polaroid'], 'polaroid'),
  new IconDefinition(iconLib['poll'], 'poll'),
  new IconDefinition(iconLib['pollBox'], 'poll-box'),
  new IconDefinition(iconLib['polymer'], 'polymer'),
  new IconDefinition(iconLib['pool'], 'pool'),
  new IconDefinition(iconLib['popcorn'], 'popcorn'),
  new IconDefinition(iconLib['postageStamp'], 'postage-stamp'),
  new IconDefinition(iconLib['pot'], 'pot'),
  new IconDefinition(iconLib['potMix'], 'pot-mix'),
  new IconDefinition(iconLib['pound'], 'pound'),
  new IconDefinition(iconLib['poundBox'], 'pound-box'),
  new IconDefinition(iconLib['power'], 'power'),
  new IconDefinition(iconLib['powerCycle'], 'power-cycle'),
  new IconDefinition(iconLib['powerOff'], 'power-off'),
  new IconDefinition(iconLib['powerOn'], 'power-on'),
  new IconDefinition(iconLib['powerPlug'], 'power-plug'),
  new IconDefinition(iconLib['powerPlugOff'], 'power-plug-off'),
  new IconDefinition(iconLib['powerSettings'], 'power-settings'),
  new IconDefinition(iconLib['powerSleep'], 'power-sleep'),
  new IconDefinition(iconLib['powerSocket'], 'power-socket'),
  new IconDefinition(iconLib['powerSocketAu'], 'power-socket-au'),
  new IconDefinition(iconLib['powerSocketEu'], 'power-socket-eu'),
  new IconDefinition(iconLib['powerSocketUk'], 'power-socket-uk'),
  new IconDefinition(iconLib['powerSocketUs'], 'power-socket-us'),
  new IconDefinition(iconLib['powerStandby'], 'power-standby'),
  new IconDefinition(iconLib['powershell'], 'powershell'),
  new IconDefinition(iconLib['prescription'], 'prescription'),
  new IconDefinition(iconLib['presentation'], 'presentation'),
  new IconDefinition(iconLib['presentationPlay'], 'presentation-play'),
  new IconDefinition(iconLib['printer'], 'printer'),
  new IconDefinition(iconLib['printer3D'], 'printer-3d'),
  new IconDefinition(iconLib['printer3DNozzle'], 'printer-3d-nozzle'),
  new IconDefinition(iconLib['printer3DNozzleOutline'], 'printer-3d-nozzle-outline'),
  new IconDefinition(iconLib['printerAlert'], 'printer-alert'),
  new IconDefinition(iconLib['printerOff'], 'printer-off'),
  new IconDefinition(iconLib['printerSettings'], 'printer-settings'),
  new IconDefinition(iconLib['printerWireless'], 'printer-wireless'),
  new IconDefinition(iconLib['priorityHigh'], 'priority-high'),
  new IconDefinition(iconLib['priorityLow'], 'priority-low'),
  new IconDefinition(iconLib['professionalHexagon'], 'professional-hexagon'),
  new IconDefinition(iconLib['progressAlert'], 'progress-alert'),
  new IconDefinition(iconLib['progressCheck'], 'progress-check'),
  new IconDefinition(iconLib['progressClock'], 'progress-clock'),
  new IconDefinition(iconLib['progressDownload'], 'progress-download'),
  new IconDefinition(iconLib['progressUpload'], 'progress-upload'),
  new IconDefinition(iconLib['progressWrench'], 'progress-wrench'),
  new IconDefinition(iconLib['projector'], 'projector'),
  new IconDefinition(iconLib['projectorScreen'], 'projector-screen'),
  new IconDefinition(iconLib['publish'], 'publish'),
  new IconDefinition(iconLib['pulse'], 'pulse'),
  new IconDefinition(iconLib['pumpkin'], 'pumpkin'),
  new IconDefinition(iconLib['purse'], 'purse'),
  new IconDefinition(iconLib['purseOutline'], 'purse-outline'),
  new IconDefinition(iconLib['puzzle'], 'puzzle'),
  new IconDefinition(iconLib['puzzleOutline'], 'puzzle-outline'),
  new IconDefinition(iconLib['qi'], 'qi'),
  new IconDefinition(iconLib['qqchat'], 'qqchat'),
  new IconDefinition(iconLib['qrcode'], 'qrcode'),
  new IconDefinition(iconLib['qrcodeEdit'], 'qrcode-edit'),
  new IconDefinition(iconLib['qrcodeScan'], 'qrcode-scan'),
  new IconDefinition(iconLib['quadcopter'], 'quadcopter'),
  new IconDefinition(iconLib['qualityHigh'], 'quality-high'),
  new IconDefinition(iconLib['qualityLow'], 'quality-low'),
  new IconDefinition(iconLib['qualityMedium'], 'quality-medium'),
  new IconDefinition(iconLib['quicktime'], 'quicktime'),
  new IconDefinition(iconLib['quora'], 'quora'),
  new IconDefinition(iconLib['rabbit'], 'rabbit'),
  new IconDefinition(iconLib['racingHelmet'], 'racing-helmet'),
  new IconDefinition(iconLib['racquetball'], 'racquetball'),
  new IconDefinition(iconLib['radar'], 'radar'),
  new IconDefinition(iconLib['radiator'], 'radiator'),
  new IconDefinition(iconLib['radiatorDisabled'], 'radiator-disabled'),
  new IconDefinition(iconLib['radiatorOff'], 'radiator-off'),
  new IconDefinition(iconLib['radio'], 'radio'),
  new IconDefinition(iconLib['radioAm'], 'radio-am'),
  new IconDefinition(iconLib['radioFm'], 'radio-fm'),
  new IconDefinition(iconLib['radioHandheld'], 'radio-handheld'),
  new IconDefinition(iconLib['radioTower'], 'radio-tower'),
  new IconDefinition(iconLib['radioactive'], 'radioactive'),
  new IconDefinition(iconLib['radioactiveOff'], 'radioactive-off'),
  new IconDefinition(iconLib['radioboxBlank'], 'radiobox-blank'),
  new IconDefinition(iconLib['radioboxMarked'], 'radiobox-marked'),
  new IconDefinition(iconLib['radius'], 'radius'),
  new IconDefinition(iconLib['radiusOutline'], 'radius-outline'),
  new IconDefinition(iconLib['railroadLight'], 'railroad-light'),
  new IconDefinition(iconLib['raspberryPi'], 'raspberry-pi'),
  new IconDefinition(iconLib['rayEnd'], 'ray-end'),
  new IconDefinition(iconLib['rayEndArrow'], 'ray-end-arrow'),
  new IconDefinition(iconLib['rayStart'], 'ray-start'),
  new IconDefinition(iconLib['rayStartArrow'], 'ray-start-arrow'),
  new IconDefinition(iconLib['rayStartEnd'], 'ray-start-end'),
  new IconDefinition(iconLib['rayVertex'], 'ray-vertex'),
  new IconDefinition(iconLib['react'], 'react'),
  new IconDefinition(iconLib['read'], 'read'),
  new IconDefinition(iconLib['receipt'], 'receipt'),
  new IconDefinition(iconLib['record'], 'record'),
  new IconDefinition(iconLib['recordCircle'], 'record-circle'),
  new IconDefinition(iconLib['recordCircleOutline'], 'record-circle-outline'),
  new IconDefinition(iconLib['recordPlayer'], 'record-player'),
  new IconDefinition(iconLib['recordRec'], 'record-rec'),
  new IconDefinition(iconLib['rectangle'], 'rectangle'),
  new IconDefinition(iconLib['rectangleOutline'], 'rectangle-outline'),
  new IconDefinition(iconLib['recycle'], 'recycle'),
  new IconDefinition(iconLib['reddit'], 'reddit'),
  new IconDefinition(iconLib['redo'], 'redo'),
  new IconDefinition(iconLib['redoVariant'], 'redo-variant'),
  new IconDefinition(iconLib['reflectHorizontal'], 'reflect-horizontal'),
  new IconDefinition(iconLib['reflectVertical'], 'reflect-vertical'),
  new IconDefinition(iconLib['refresh'], 'refresh'),
  new IconDefinition(iconLib['regex'], 'regex'),
  new IconDefinition(iconLib['registeredTrademark'], 'registered-trademark'),
  new IconDefinition(iconLib['relativeScale'], 'relative-scale'),
  new IconDefinition(iconLib['reload'], 'reload'),
  new IconDefinition(iconLib['reminder'], 'reminder'),
  new IconDefinition(iconLib['remote'], 'remote'),
  new IconDefinition(iconLib['remoteDesktop'], 'remote-desktop'),
  new IconDefinition(iconLib['remoteOff'], 'remote-off'),
  new IconDefinition(iconLib['remoteTv'], 'remote-tv'),
  new IconDefinition(iconLib['remoteTvOff'], 'remote-tv-off'),
  new IconDefinition(iconLib['renameBox'], 'rename-box'),
  new IconDefinition(iconLib['reorderHorizontal'], 'reorder-horizontal'),
  new IconDefinition(iconLib['reorderVertical'], 'reorder-vertical'),
  new IconDefinition(iconLib['repeat'], 'repeat'),
  new IconDefinition(iconLib['repeatOff'], 'repeat-off'),
  new IconDefinition(iconLib['repeatOnce'], 'repeat-once'),
  new IconDefinition(iconLib['replay'], 'replay'),
  new IconDefinition(iconLib['reply'], 'reply'),
  new IconDefinition(iconLib['replyAll'], 'reply-all'),
  new IconDefinition(iconLib['replyAllOutline'], 'reply-all-outline'),
  new IconDefinition(iconLib['replyOutline'], 'reply-outline'),
  new IconDefinition(iconLib['reproduction'], 'reproduction'),
  new IconDefinition(iconLib['resistor'], 'resistor'),
  new IconDefinition(iconLib['resistorNodes'], 'resistor-nodes'),
  new IconDefinition(iconLib['resize'], 'resize'),
  new IconDefinition(iconLib['resizeBottomRight'], 'resize-bottom-right'),
  new IconDefinition(iconLib['responsive'], 'responsive'),
  new IconDefinition(iconLib['restart'], 'restart'),
  new IconDefinition(iconLib['restartOff'], 'restart-off'),
  new IconDefinition(iconLib['restore'], 'restore'),
  new IconDefinition(iconLib['restoreClock'], 'restore-clock'),
  new IconDefinition(iconLib['rewind'], 'rewind'),
  new IconDefinition(iconLib['rewind10'], 'rewind-10'),
  new IconDefinition(iconLib['rewind30'], 'rewind-30'),
  new IconDefinition(iconLib['rewindOutline'], 'rewind-outline'),
  new IconDefinition(iconLib['rhombus'], 'rhombus'),
  new IconDefinition(iconLib['rhombusMedium'], 'rhombus-medium'),
  new IconDefinition(iconLib['rhombusOutline'], 'rhombus-outline'),
  new IconDefinition(iconLib['rhombusSplit'], 'rhombus-split'),
  new IconDefinition(iconLib['ribbon'], 'ribbon'),
  new IconDefinition(iconLib['rice'], 'rice'),
  new IconDefinition(iconLib['ring'], 'ring'),
  new IconDefinition(iconLib['rivet'], 'rivet'),
  new IconDefinition(iconLib['road'], 'road'),
  new IconDefinition(iconLib['roadVariant'], 'road-variant'),
  new IconDefinition(iconLib['robot'], 'robot'),
  new IconDefinition(iconLib['robotIndustrial'], 'robot-industrial'),
  new IconDefinition(iconLib['robotVacuum'], 'robot-vacuum'),
  new IconDefinition(iconLib['robotVacuumVariant'], 'robot-vacuum-variant'),
  new IconDefinition(iconLib['rocket'], 'rocket'),
  new IconDefinition(iconLib['rollerSkate'], 'roller-skate'),
  new IconDefinition(iconLib['rollerblade'], 'rollerblade'),
  new IconDefinition(iconLib['rollupjs'], 'rollupjs'),
  new IconDefinition(iconLib['roomService'], 'room-service'),
  new IconDefinition(iconLib['roomServiceOutline'], 'room-service-outline'),
  new IconDefinition(iconLib['rotate3D'], 'rotate-3d'),
  new IconDefinition(iconLib['rotate3DVariant'], 'rotate-3d-variant'),
  new IconDefinition(iconLib['rotateLeft'], 'rotate-left'),
  new IconDefinition(iconLib['rotateLeftVariant'], 'rotate-left-variant'),
  new IconDefinition(iconLib['rotateOrbit'], 'rotate-orbit'),
  new IconDefinition(iconLib['rotateRight'], 'rotate-right'),
  new IconDefinition(iconLib['rotateRightVariant'], 'rotate-right-variant'),
  new IconDefinition(iconLib['roundedCorner'], 'rounded-corner'),
  new IconDefinition(iconLib['routerWireless'], 'router-wireless'),
  new IconDefinition(iconLib['routerWirelessSettings'], 'router-wireless-settings'),
  new IconDefinition(iconLib['routes'], 'routes'),
  new IconDefinition(iconLib['rowing'], 'rowing'),
  new IconDefinition(iconLib['rss'], 'rss'),
  new IconDefinition(iconLib['rssBox'], 'rss-box'),
  new IconDefinition(iconLib['rssOff'], 'rss-off'),
  new IconDefinition(iconLib['ruby'], 'ruby'),
  new IconDefinition(iconLib['rugby'], 'rugby'),
  new IconDefinition(iconLib['ruler'], 'ruler'),
  new IconDefinition(iconLib['rulerSquare'], 'ruler-square'),
  new IconDefinition(iconLib['run'], 'run'),
  new IconDefinition(iconLib['runFast'], 'run-fast'),
  new IconDefinition(iconLib['sack'], 'sack'),
  new IconDefinition(iconLib['sackPercent'], 'sack-percent'),
  new IconDefinition(iconLib['safe'], 'safe'),
  new IconDefinition(iconLib['safetyGoggles'], 'safety-goggles'),
  new IconDefinition(iconLib['sailing'], 'sailing'),
  new IconDefinition(iconLib['sale'], 'sale'),
  new IconDefinition(iconLib['salesforce'], 'salesforce'),
  new IconDefinition(iconLib['sass'], 'sass'),
  new IconDefinition(iconLib['satellite'], 'satellite'),
  new IconDefinition(iconLib['satelliteUplink'], 'satellite-uplink'),
  new IconDefinition(iconLib['satelliteVariant'], 'satellite-variant'),
  new IconDefinition(iconLib['sausage'], 'sausage'),
  new IconDefinition(iconLib['sawBlade'], 'saw-blade'),
  new IconDefinition(iconLib['saxophone'], 'saxophone'),
  new IconDefinition(iconLib['scale'], 'scale'),
  new IconDefinition(iconLib['scaleBalance'], 'scale-balance'),
  new IconDefinition(iconLib['scaleBathroom'], 'scale-bathroom'),
  new IconDefinition(iconLib['scanner'], 'scanner'),
  new IconDefinition(iconLib['scannerOff'], 'scanner-off'),
  new IconDefinition(iconLib['scatterPlot'], 'scatter-plot'),
  new IconDefinition(iconLib['scatterPlotOutline'], 'scatter-plot-outline'),
  new IconDefinition(iconLib['school'], 'school'),
  new IconDefinition(iconLib['scissorsCutting'], 'scissors-cutting'),
  new IconDefinition(iconLib['screenRotation'], 'screen-rotation'),
  new IconDefinition(iconLib['screenRotationLock'], 'screen-rotation-lock'),
  new IconDefinition(iconLib['screwFlatTop'], 'screw-flat-top'),
  new IconDefinition(iconLib['screwLag'], 'screw-lag'),
  new IconDefinition(iconLib['screwMachineFlatTop'], 'screw-machine-flat-top'),
  new IconDefinition(iconLib['screwMachineRoundTop'], 'screw-machine-round-top'),
  new IconDefinition(iconLib['screwRoundTop'], 'screw-round-top'),
  new IconDefinition(iconLib['screwdriver'], 'screwdriver'),
  new IconDefinition(iconLib['script'], 'script'),
  new IconDefinition(iconLib['scriptOutline'], 'script-outline'),
  new IconDefinition(iconLib['scriptText'], 'script-text'),
  new IconDefinition(iconLib['scriptTextOutline'], 'script-text-outline'),
  new IconDefinition(iconLib['sd'], 'sd'),
  new IconDefinition(iconLib['seal'], 'seal'),
  new IconDefinition(iconLib['searchWeb'], 'search-web'),
  new IconDefinition(iconLib['seat'], 'seat'),
  new IconDefinition(iconLib['seatFlat'], 'seat-flat'),
  new IconDefinition(iconLib['seatFlatAngled'], 'seat-flat-angled'),
  new IconDefinition(iconLib['seatIndividualSuite'], 'seat-individual-suite'),
  new IconDefinition(iconLib['seatLegroomExtra'], 'seat-legroom-extra'),
  new IconDefinition(iconLib['seatLegroomNormal'], 'seat-legroom-normal'),
  new IconDefinition(iconLib['seatLegroomReduced'], 'seat-legroom-reduced'),
  new IconDefinition(iconLib['seatOutline'], 'seat-outline'),
  new IconDefinition(iconLib['seatReclineExtra'], 'seat-recline-extra'),
  new IconDefinition(iconLib['seatReclineNormal'], 'seat-recline-normal'),
  new IconDefinition(iconLib['seatbelt'], 'seatbelt'),
  new IconDefinition(iconLib['security'], 'security'),
  new IconDefinition(iconLib['securityNetwork'], 'security-network'),
  new IconDefinition(iconLib['seed'], 'seed'),
  new IconDefinition(iconLib['seedOutline'], 'seed-outline'),
  new IconDefinition(iconLib['segment'], 'segment'),
  new IconDefinition(iconLib['select'], 'select'),
  new IconDefinition(iconLib['selectAll'], 'select-all'),
  new IconDefinition(iconLib['selectColor'], 'select-color'),
  new IconDefinition(iconLib['selectCompare'], 'select-compare'),
  new IconDefinition(iconLib['selectDrag'], 'select-drag'),
  new IconDefinition(iconLib['selectInverse'], 'select-inverse'),
  new IconDefinition(iconLib['selectOff'], 'select-off'),
  new IconDefinition(iconLib['selection'], 'selection'),
  new IconDefinition(iconLib['selectionDrag'], 'selection-drag'),
  new IconDefinition(iconLib['selectionEllipse'], 'selection-ellipse'),
  new IconDefinition(iconLib['selectionEllipseArrowInside'], 'selection-ellipse-arrow-inside'),
  new IconDefinition(iconLib['selectionOff'], 'selection-off'),
  new IconDefinition(iconLib['send'], 'send'),
  new IconDefinition(iconLib['sendCircle'], 'send-circle'),
  new IconDefinition(iconLib['sendCircleOutline'], 'send-circle-outline'),
  new IconDefinition(iconLib['sendLock'], 'send-lock'),
  new IconDefinition(iconLib['serialPort'], 'serial-port'),
  new IconDefinition(iconLib['server'], 'server'),
  new IconDefinition(iconLib['serverMinus'], 'server-minus'),
  new IconDefinition(iconLib['serverNetwork'], 'server-network'),
  new IconDefinition(iconLib['serverNetworkOff'], 'server-network-off'),
  new IconDefinition(iconLib['serverOff'], 'server-off'),
  new IconDefinition(iconLib['serverPlus'], 'server-plus'),
  new IconDefinition(iconLib['serverRemove'], 'server-remove'),
  new IconDefinition(iconLib['serverSecurity'], 'server-security'),
  new IconDefinition(iconLib['setAll'], 'set-all'),
  new IconDefinition(iconLib['setCenter'], 'set-center'),
  new IconDefinition(iconLib['setCenterRight'], 'set-center-right'),
  new IconDefinition(iconLib['setLeft'], 'set-left'),
  new IconDefinition(iconLib['setLeftCenter'], 'set-left-center'),
  new IconDefinition(iconLib['setLeftRight'], 'set-left-right'),
  new IconDefinition(iconLib['setNone'], 'set-none'),
  new IconDefinition(iconLib['setRight'], 'set-right'),
  new IconDefinition(iconLib['setTopBox'], 'set-top-box'),
  new IconDefinition(iconLib['settings'], 'settings'),
  new IconDefinition(iconLib['settingsBox'], 'settings-box'),
  new IconDefinition(iconLib['settingsHelper'], 'settings-helper'),
  new IconDefinition(iconLib['settingsOutline'], 'settings-outline'),
  new IconDefinition(iconLib['shape'], 'shape'),
  new IconDefinition(iconLib['shapeCirclePlus'], 'shape-circle-plus'),
  new IconDefinition(iconLib['shapeOutline'], 'shape-outline'),
  new IconDefinition(iconLib['shapePlus'], 'shape-plus'),
  new IconDefinition(iconLib['shapePolygonPlus'], 'shape-polygon-plus'),
  new IconDefinition(iconLib['shapeRectanglePlus'], 'shape-rectangle-plus'),
  new IconDefinition(iconLib['shapeSquarePlus'], 'shape-square-plus'),
  new IconDefinition(iconLib['share'], 'share'),
  new IconDefinition(iconLib['shareOff'], 'share-off'),
  new IconDefinition(iconLib['shareOffOutline'], 'share-off-outline'),
  new IconDefinition(iconLib['shareOutline'], 'share-outline'),
  new IconDefinition(iconLib['shareVariant'], 'share-variant'),
  new IconDefinition(iconLib['sheep'], 'sheep'),
  new IconDefinition(iconLib['shield'], 'shield'),
  new IconDefinition(iconLib['shieldAccount'], 'shield-account'),
  new IconDefinition(iconLib['shieldAccountOutline'], 'shield-account-outline'),
  new IconDefinition(iconLib['shieldAirplane'], 'shield-airplane'),
  new IconDefinition(iconLib['shieldAirplaneOutline'], 'shield-airplane-outline'),
  new IconDefinition(iconLib['shieldAlert'], 'shield-alert'),
  new IconDefinition(iconLib['shieldAlertOutline'], 'shield-alert-outline'),
  new IconDefinition(iconLib['shieldCheck'], 'shield-check'),
  new IconDefinition(iconLib['shieldCheckOutline'], 'shield-check-outline'),
  new IconDefinition(iconLib['shieldCross'], 'shield-cross'),
  new IconDefinition(iconLib['shieldCrossOutline'], 'shield-cross-outline'),
  new IconDefinition(iconLib['shieldHalfFull'], 'shield-half-full'),
  new IconDefinition(iconLib['shieldHome'], 'shield-home'),
  new IconDefinition(iconLib['shieldHomeOutline'], 'shield-home-outline'),
  new IconDefinition(iconLib['shieldKey'], 'shield-key'),
  new IconDefinition(iconLib['shieldKeyOutline'], 'shield-key-outline'),
  new IconDefinition(iconLib['shieldLinkVariant'], 'shield-link-variant'),
  new IconDefinition(iconLib['shieldLinkVariantOutline'], 'shield-link-variant-outline'),
  new IconDefinition(iconLib['shieldLock'], 'shield-lock'),
  new IconDefinition(iconLib['shieldLockOutline'], 'shield-lock-outline'),
  new IconDefinition(iconLib['shieldOff'], 'shield-off'),
  new IconDefinition(iconLib['shieldOffOutline'], 'shield-off-outline'),
  new IconDefinition(iconLib['shieldOutline'], 'shield-outline'),
  new IconDefinition(iconLib['shieldPlus'], 'shield-plus'),
  new IconDefinition(iconLib['shieldPlusOutline'], 'shield-plus-outline'),
  new IconDefinition(iconLib['shieldRemove'], 'shield-remove'),
  new IconDefinition(iconLib['shieldRemoveOutline'], 'shield-remove-outline'),
  new IconDefinition(iconLib['shieldSearch'], 'shield-search'),
  new IconDefinition(iconLib['shipWheel'], 'ship-wheel'),
  new IconDefinition(iconLib['shoeFormal'], 'shoe-formal'),
  new IconDefinition(iconLib['shoeHeel'], 'shoe-heel'),
  new IconDefinition(iconLib['shoePrint'], 'shoe-print'),
  new IconDefinition(iconLib['shopify'], 'shopify'),
  new IconDefinition(iconLib['shopping'], 'shopping'),
  new IconDefinition(iconLib['shoppingMusic'], 'shopping-music'),
  new IconDefinition(iconLib['shovel'], 'shovel'),
  new IconDefinition(iconLib['shovelOff'], 'shovel-off'),
  new IconDefinition(iconLib['shower'], 'shower'),
  new IconDefinition(iconLib['showerHead'], 'shower-head'),
  new IconDefinition(iconLib['shredder'], 'shredder'),
  new IconDefinition(iconLib['shuffle'], 'shuffle'),
  new IconDefinition(iconLib['shuffleDisabled'], 'shuffle-disabled'),
  new IconDefinition(iconLib['shuffleVariant'], 'shuffle-variant'),
  new IconDefinition(iconLib['sigma'], 'sigma'),
  new IconDefinition(iconLib['sigmaLower'], 'sigma-lower'),
  new IconDefinition(iconLib['signCaution'], 'sign-caution'),
  new IconDefinition(iconLib['signDirection'], 'sign-direction'),
  new IconDefinition(iconLib['signText'], 'sign-text'),
  new IconDefinition(iconLib['signal'], 'signal'),
  new IconDefinition(iconLib['signal2G'], 'signal-2g'),
  new IconDefinition(iconLib['signal3G'], 'signal-3g'),
  new IconDefinition(iconLib['signal4G'], 'signal-4g'),
  new IconDefinition(iconLib['signal5G'], 'signal-5g'),
  new IconDefinition(iconLib['signalCellular1'], 'signal-cellular-1'),
  new IconDefinition(iconLib['signalCellular2'], 'signal-cellular-2'),
  new IconDefinition(iconLib['signalCellular3'], 'signal-cellular-3'),
  new IconDefinition(iconLib['signalCellularOutline'], 'signal-cellular-outline'),
  new IconDefinition(iconLib['signalDistanceVariant'], 'signal-distance-variant'),
  new IconDefinition(iconLib['signalHspa'], 'signal-hspa'),
  new IconDefinition(iconLib['signalHspaPlus'], 'signal-hspa-plus'),
  new IconDefinition(iconLib['signalOff'], 'signal-off'),
  new IconDefinition(iconLib['signalVariant'], 'signal-variant'),
  new IconDefinition(iconLib['signature'], 'signature'),
  new IconDefinition(iconLib['signatureFreehand'], 'signature-freehand'),
  new IconDefinition(iconLib['signatureImage'], 'signature-image'),
  new IconDefinition(iconLib['signatureText'], 'signature-text'),
  new IconDefinition(iconLib['silo'], 'silo'),
  new IconDefinition(iconLib['silverware'], 'silverware'),
  new IconDefinition(iconLib['silverwareFork'], 'silverware-fork'),
  new IconDefinition(iconLib['silverwareForkKnife'], 'silverware-fork-knife'),
  new IconDefinition(iconLib['silverwareSpoon'], 'silverware-spoon'),
  new IconDefinition(iconLib['silverwareVariant'], 'silverware-variant'),
  new IconDefinition(iconLib['sim'], 'sim'),
  new IconDefinition(iconLib['simAlert'], 'sim-alert'),
  new IconDefinition(iconLib['simOff'], 'sim-off'),
  new IconDefinition(iconLib['sinaWeibo'], 'sina-weibo'),
  new IconDefinition(iconLib['sitemap'], 'sitemap'),
  new IconDefinition(iconLib['skate'], 'skate'),
  new IconDefinition(iconLib['skewLess'], 'skew-less'),
  new IconDefinition(iconLib['skewMore'], 'skew-more'),
  new IconDefinition(iconLib['skipBackward'], 'skip-backward'),
  new IconDefinition(iconLib['skipBackwardOutline'], 'skip-backward-outline'),
  new IconDefinition(iconLib['skipForward'], 'skip-forward'),
  new IconDefinition(iconLib['skipForwardOutline'], 'skip-forward-outline'),
  new IconDefinition(iconLib['skipNext'], 'skip-next'),
  new IconDefinition(iconLib['skipNextCircle'], 'skip-next-circle'),
  new IconDefinition(iconLib['skipNextCircleOutline'], 'skip-next-circle-outline'),
  new IconDefinition(iconLib['skipNextOutline'], 'skip-next-outline'),
  new IconDefinition(iconLib['skipPrevious'], 'skip-previous'),
  new IconDefinition(iconLib['skipPreviousCircle'], 'skip-previous-circle'),
  new IconDefinition(iconLib['skipPreviousCircleOutline'], 'skip-previous-circle-outline'),
  new IconDefinition(iconLib['skipPreviousOutline'], 'skip-previous-outline'),
  new IconDefinition(iconLib['skull'], 'skull'),
  new IconDefinition(iconLib['skullCrossbones'], 'skull-crossbones'),
  new IconDefinition(iconLib['skullCrossbonesOutline'], 'skull-crossbones-outline'),
  new IconDefinition(iconLib['skullOutline'], 'skull-outline'),
  new IconDefinition(iconLib['skype'], 'skype'),
  new IconDefinition(iconLib['skypeBusiness'], 'skype-business'),
  new IconDefinition(iconLib['slack'], 'slack'),
  new IconDefinition(iconLib['slackware'], 'slackware'),
  new IconDefinition(iconLib['sleep'], 'sleep'),
  new IconDefinition(iconLib['sleepOff'], 'sleep-off'),
  new IconDefinition(iconLib['slopeDownhill'], 'slope-downhill'),
  new IconDefinition(iconLib['slopeUphill'], 'slope-uphill'),
  new IconDefinition(iconLib['smog'], 'smog'),
  new IconDefinition(iconLib['smokeDetector'], 'smoke-detector'),
  new IconDefinition(iconLib['smoking'], 'smoking'),
  new IconDefinition(iconLib['smokingOff'], 'smoking-off'),
  new IconDefinition(iconLib['snapchat'], 'snapchat'),
  new IconDefinition(iconLib['snowflake'], 'snowflake'),
  new IconDefinition(iconLib['snowflakeAlert'], 'snowflake-alert'),
  new IconDefinition(iconLib['snowflakeVariant'], 'snowflake-variant'),
  new IconDefinition(iconLib['snowman'], 'snowman'),
  new IconDefinition(iconLib['soccer'], 'soccer'),
  new IconDefinition(iconLib['soccerField'], 'soccer-field'),
  new IconDefinition(iconLib['sofa'], 'sofa'),
  new IconDefinition(iconLib['solarPanel'], 'solar-panel'),
  new IconDefinition(iconLib['solarPanelLarge'], 'solar-panel-large'),
  new IconDefinition(iconLib['solarPower'], 'solar-power'),
  new IconDefinition(iconLib['solid'], 'solid'),
  new IconDefinition(iconLib['sort'], 'sort'),
  new IconDefinition(iconLib['sortAlphabetical'], 'sort-alphabetical'),
  new IconDefinition(iconLib['sortAscending'], 'sort-ascending'),
  new IconDefinition(iconLib['sortDescending'], 'sort-descending'),
  new IconDefinition(iconLib['sortNumeric'], 'sort-numeric'),
  new IconDefinition(iconLib['sortVariant'], 'sort-variant'),
  new IconDefinition(iconLib['sortVariantLock'], 'sort-variant-lock'),
  new IconDefinition(iconLib['sortVariantLockOpen'], 'sort-variant-lock-open'),
  new IconDefinition(iconLib['soundcloud'], 'soundcloud'),
  new IconDefinition(iconLib['sourceBranch'], 'source-branch'),
  new IconDefinition(iconLib['sourceCommit'], 'source-commit'),
  new IconDefinition(iconLib['sourceCommitEnd'], 'source-commit-end'),
  new IconDefinition(iconLib['sourceCommitEndLocal'], 'source-commit-end-local'),
  new IconDefinition(iconLib['sourceCommitLocal'], 'source-commit-local'),
  new IconDefinition(iconLib['sourceCommitNextLocal'], 'source-commit-next-local'),
  new IconDefinition(iconLib['sourceCommitStart'], 'source-commit-start'),
  new IconDefinition(iconLib['sourceCommitStartNextLocal'], 'source-commit-start-next-local'),
  new IconDefinition(iconLib['sourceFork'], 'source-fork'),
  new IconDefinition(iconLib['sourceMerge'], 'source-merge'),
  new IconDefinition(iconLib['sourcePull'], 'source-pull'),
  new IconDefinition(iconLib['sourceRepository'], 'source-repository'),
  new IconDefinition(iconLib['sourceRepositoryMultiple'], 'source-repository-multiple'),
  new IconDefinition(iconLib['soySauce'], 'soy-sauce'),
  new IconDefinition(iconLib['spa'], 'spa'),
  new IconDefinition(iconLib['spaOutline'], 'spa-outline'),
  new IconDefinition(iconLib['spaceInvaders'], 'space-invaders'),
  new IconDefinition(iconLib['spade'], 'spade'),
  new IconDefinition(iconLib['speaker'], 'speaker'),
  new IconDefinition(iconLib['speakerBluetooth'], 'speaker-bluetooth'),
  new IconDefinition(iconLib['speakerMultiple'], 'speaker-multiple'),
  new IconDefinition(iconLib['speakerOff'], 'speaker-off'),
  new IconDefinition(iconLib['speakerWireless'], 'speaker-wireless'),
  new IconDefinition(iconLib['speedometer'], 'speedometer'),
  new IconDefinition(iconLib['spellcheck'], 'spellcheck'),
  new IconDefinition(iconLib['spiderWeb'], 'spider-web'),
  new IconDefinition(iconLib['spotify'], 'spotify'),
  new IconDefinition(iconLib['spotlight'], 'spotlight'),
  new IconDefinition(iconLib['spotlightBeam'], 'spotlight-beam'),
  new IconDefinition(iconLib['spray'], 'spray'),
  new IconDefinition(iconLib['sprayBottle'], 'spray-bottle'),
  new IconDefinition(iconLib['sprout'], 'sprout'),
  new IconDefinition(iconLib['sproutOutline'], 'sprout-outline'),
  new IconDefinition(iconLib['square'], 'square'),
  new IconDefinition(iconLib['squareEditOutline'], 'square-edit-outline'),
  new IconDefinition(iconLib['squareInc'], 'square-inc'),
  new IconDefinition(iconLib['squareIncCash'], 'square-inc-cash'),
  new IconDefinition(iconLib['squareMedium'], 'square-medium'),
  new IconDefinition(iconLib['squareMediumOutline'], 'square-medium-outline'),
  new IconDefinition(iconLib['squareOutline'], 'square-outline'),
  new IconDefinition(iconLib['squareRoot'], 'square-root'),
  new IconDefinition(iconLib['squareRootBox'], 'square-root-box'),
  new IconDefinition(iconLib['squareSmall'], 'square-small'),
  new IconDefinition(iconLib['squeegee'], 'squeegee'),
  new IconDefinition(iconLib['ssh'], 'ssh'),
  new IconDefinition(iconLib['stackExchange'], 'stack-exchange'),
  new IconDefinition(iconLib['stackOverflow'], 'stack-overflow'),
  new IconDefinition(iconLib['stadium'], 'stadium'),
  new IconDefinition(iconLib['stairs'], 'stairs'),
  new IconDefinition(iconLib['stamper'], 'stamper'),
  new IconDefinition(iconLib['standardDefinition'], 'standard-definition'),
  new IconDefinition(iconLib['star'], 'star'),
  new IconDefinition(iconLib['starBox'], 'star-box'),
  new IconDefinition(iconLib['starBoxOutline'], 'star-box-outline'),
  new IconDefinition(iconLib['starCircle'], 'star-circle'),
  new IconDefinition(iconLib['starCircleOutline'], 'star-circle-outline'),
  new IconDefinition(iconLib['starFace'], 'star-face'),
  new IconDefinition(iconLib['starFourPoints'], 'star-four-points'),
  new IconDefinition(iconLib['starFourPointsOutline'], 'star-four-points-outline'),
  new IconDefinition(iconLib['starHalf'], 'star-half'),
  new IconDefinition(iconLib['starOff'], 'star-off'),
  new IconDefinition(iconLib['starOutline'], 'star-outline'),
  new IconDefinition(iconLib['starThreePoints'], 'star-three-points'),
  new IconDefinition(iconLib['starThreePointsOutline'], 'star-three-points-outline'),
  new IconDefinition(iconLib['steam'], 'steam'),
  new IconDefinition(iconLib['steamBox'], 'steam-box'),
  new IconDefinition(iconLib['steering'], 'steering'),
  new IconDefinition(iconLib['steeringOff'], 'steering-off'),
  new IconDefinition(iconLib['stepBackward'], 'step-backward'),
  new IconDefinition(iconLib['stepBackward2'], 'step-backward-2'),
  new IconDefinition(iconLib['stepForward'], 'step-forward'),
  new IconDefinition(iconLib['stepForward2'], 'step-forward-2'),
  new IconDefinition(iconLib['stethoscope'], 'stethoscope'),
  new IconDefinition(iconLib['sticker'], 'sticker'),
  new IconDefinition(iconLib['stickerEmoji'], 'sticker-emoji'),
  new IconDefinition(iconLib['stocking'], 'stocking'),
  new IconDefinition(iconLib['stop'], 'stop'),
  new IconDefinition(iconLib['stopCircle'], 'stop-circle'),
  new IconDefinition(iconLib['stopCircleOutline'], 'stop-circle-outline'),
  new IconDefinition(iconLib['store'], 'store'),
  new IconDefinition(iconLib['store24Hour'], 'store-24-hour'),
  new IconDefinition(iconLib['stove'], 'stove'),
  new IconDefinition(iconLib['strava'], 'strava'),
  new IconDefinition(iconLib['stretchToPage'], 'stretch-to-page'),
  new IconDefinition(iconLib['stretchToPageOutline'], 'stretch-to-page-outline'),
  new IconDefinition(iconLib['subdirectoryArrowLeft'], 'subdirectory-arrow-left'),
  new IconDefinition(iconLib['subdirectoryArrowRight'], 'subdirectory-arrow-right'),
  new IconDefinition(iconLib['subtitles'], 'subtitles'),
  new IconDefinition(iconLib['subtitlesOutline'], 'subtitles-outline'),
  new IconDefinition(iconLib['subway'], 'subway'),
  new IconDefinition(iconLib['subwayAlertVariant'], 'subway-alert-variant'),
  new IconDefinition(iconLib['subwayVariant'], 'subway-variant'),
  new IconDefinition(iconLib['summit'], 'summit'),
  new IconDefinition(iconLib['sunglasses'], 'sunglasses'),
  new IconDefinition(iconLib['surroundSound'], 'surround-sound'),
  new IconDefinition(iconLib['surroundSound20'], 'surround-sound-2-0'),
  new IconDefinition(iconLib['surroundSound31'], 'surround-sound-3-1'),
  new IconDefinition(iconLib['surroundSound51'], 'surround-sound-5-1'),
  new IconDefinition(iconLib['surroundSound71'], 'surround-sound-7-1'),
  new IconDefinition(iconLib['svg'], 'svg'),
  new IconDefinition(iconLib['swapHorizontal'], 'swap-horizontal'),
  new IconDefinition(iconLib['swapHorizontalBold'], 'swap-horizontal-bold'),
  new IconDefinition(iconLib['swapHorizontalVariant'], 'swap-horizontal-variant'),
  new IconDefinition(iconLib['swapVertical'], 'swap-vertical'),
  new IconDefinition(iconLib['swapVerticalBold'], 'swap-vertical-bold'),
  new IconDefinition(iconLib['swapVerticalVariant'], 'swap-vertical-variant'),
  new IconDefinition(iconLib['swim'], 'swim'),
  new IconDefinition(iconLib['switchIcon'], 'switch'),
  new IconDefinition(iconLib['sword'], 'sword'),
  new IconDefinition(iconLib['swordCross'], 'sword-cross'),
  new IconDefinition(iconLib['symfony'], 'symfony'),
  new IconDefinition(iconLib['syncIcon'], 'sync'),
  new IconDefinition(iconLib['syncAlert'], 'sync-alert'),
  new IconDefinition(iconLib['syncOff'], 'sync-off'),
  new IconDefinition(iconLib['tab'], 'tab'),
  new IconDefinition(iconLib['tabMinus'], 'tab-minus'),
  new IconDefinition(iconLib['tabPlus'], 'tab-plus'),
  new IconDefinition(iconLib['tabRemove'], 'tab-remove'),
  new IconDefinition(iconLib['tabUnselected'], 'tab-unselected'),
  new IconDefinition(iconLib['table'], 'table'),
  new IconDefinition(iconLib['tableBorder'], 'table-border'),
  new IconDefinition(iconLib['tableColumn'], 'table-column'),
  new IconDefinition(iconLib['tableColumnPlusAfter'], 'table-column-plus-after'),
  new IconDefinition(iconLib['tableColumnPlusBefore'], 'table-column-plus-before'),
  new IconDefinition(iconLib['tableColumnRemove'], 'table-column-remove'),
  new IconDefinition(iconLib['tableColumnWidth'], 'table-column-width'),
  new IconDefinition(iconLib['tableEdit'], 'table-edit'),
  new IconDefinition(iconLib['tableLarge'], 'table-large'),
  new IconDefinition(iconLib['tableMergeCells'], 'table-merge-cells'),
  new IconDefinition(iconLib['tableOfContents'], 'table-of-contents'),
  new IconDefinition(iconLib['tablePlus'], 'table-plus'),
  new IconDefinition(iconLib['tableRemove'], 'table-remove'),
  new IconDefinition(iconLib['tableRow'], 'table-row'),
  new IconDefinition(iconLib['tableRowHeight'], 'table-row-height'),
  new IconDefinition(iconLib['tableRowPlusAfter'], 'table-row-plus-after'),
  new IconDefinition(iconLib['tableRowPlusBefore'], 'table-row-plus-before'),
  new IconDefinition(iconLib['tableRowRemove'], 'table-row-remove'),
  new IconDefinition(iconLib['tableSearch'], 'table-search'),
  new IconDefinition(iconLib['tableSettings'], 'table-settings'),
  new IconDefinition(iconLib['tableTennis'], 'table-tennis'),
  new IconDefinition(iconLib['tablet'], 'tablet'),
  new IconDefinition(iconLib['tabletAndroid'], 'tablet-android'),
  new IconDefinition(iconLib['tabletCellphone'], 'tablet-cellphone'),
  new IconDefinition(iconLib['tabletDashboard'], 'tablet-dashboard'),
  new IconDefinition(iconLib['tabletIpad'], 'tablet-ipad'),
  new IconDefinition(iconLib['taco'], 'taco'),
  new IconDefinition(iconLib['tag'], 'tag'),
  new IconDefinition(iconLib['tagFaces'], 'tag-faces'),
  new IconDefinition(iconLib['tagHeart'], 'tag-heart'),
  new IconDefinition(iconLib['tagHeartOutline'], 'tag-heart-outline'),
  new IconDefinition(iconLib['tagMinus'], 'tag-minus'),
  new IconDefinition(iconLib['tagMultiple'], 'tag-multiple'),
  new IconDefinition(iconLib['tagOutline'], 'tag-outline'),
  new IconDefinition(iconLib['tagPlus'], 'tag-plus'),
  new IconDefinition(iconLib['tagRemove'], 'tag-remove'),
  new IconDefinition(iconLib['tagTextOutline'], 'tag-text-outline'),
  new IconDefinition(iconLib['tank'], 'tank'),
  new IconDefinition(iconLib['tapeMeasure'], 'tape-measure'),
  new IconDefinition(iconLib['target'], 'target'),
  new IconDefinition(iconLib['targetAccount'], 'target-account'),
  new IconDefinition(iconLib['targetVariant'], 'target-variant'),
  new IconDefinition(iconLib['taxi'], 'taxi'),
  new IconDefinition(iconLib['tea'], 'tea'),
  new IconDefinition(iconLib['teaOutline'], 'tea-outline'),
  new IconDefinition(iconLib['teach'], 'teach'),
  new IconDefinition(iconLib['teamviewer'], 'teamviewer'),
  new IconDefinition(iconLib['telegram'], 'telegram'),
  new IconDefinition(iconLib['telescope'], 'telescope'),
  new IconDefinition(iconLib['television'], 'television'),
  new IconDefinition(iconLib['televisionBox'], 'television-box'),
  new IconDefinition(iconLib['televisionClassic'], 'television-classic'),
  new IconDefinition(iconLib['televisionClassicOff'], 'television-classic-off'),
  new IconDefinition(iconLib['televisionGuide'], 'television-guide'),
  new IconDefinition(iconLib['televisionOff'], 'television-off'),
  new IconDefinition(iconLib['televisionPlay'], 'television-play'),
  new IconDefinition(iconLib['temperatureCelsius'], 'temperature-celsius'),
  new IconDefinition(iconLib['temperatureFahrenheit'], 'temperature-fahrenheit'),
  new IconDefinition(iconLib['temperatureKelvin'], 'temperature-kelvin'),
  new IconDefinition(iconLib['tennis'], 'tennis'),
  new IconDefinition(iconLib['tennisBall'], 'tennis-ball'),
  new IconDefinition(iconLib['tent'], 'tent'),
  new IconDefinition(iconLib['terrain'], 'terrain'),
  new IconDefinition(iconLib['testTube'], 'test-tube'),
  new IconDefinition(iconLib['testTubeEmpty'], 'test-tube-empty'),
  new IconDefinition(iconLib['testTubeOff'], 'test-tube-off'),
  new IconDefinition(iconLib['text'], 'text'),
  new IconDefinition(iconLib['textShadow'], 'text-shadow'),
  new IconDefinition(iconLib['textShort'], 'text-short'),
  new IconDefinition(iconLib['textSubject'], 'text-subject'),
  new IconDefinition(iconLib['textToSpeech'], 'text-to-speech'),
  new IconDefinition(iconLib['textToSpeechOff'], 'text-to-speech-off'),
  new IconDefinition(iconLib['textbox'], 'textbox'),
  new IconDefinition(iconLib['textboxPassword'], 'textbox-password'),
  new IconDefinition(iconLib['texture'], 'texture'),
  new IconDefinition(iconLib['theater'], 'theater'),
  new IconDefinition(iconLib['themeLightDark'], 'theme-light-dark'),
  new IconDefinition(iconLib['thermometer'], 'thermometer'),
  new IconDefinition(iconLib['thermometerAlert'], 'thermometer-alert'),
  new IconDefinition(iconLib['thermometerChevronDown'], 'thermometer-chevron-down'),
  new IconDefinition(iconLib['thermometerChevronUp'], 'thermometer-chevron-up'),
  new IconDefinition(iconLib['thermometerLines'], 'thermometer-lines'),
  new IconDefinition(iconLib['thermometerMinus'], 'thermometer-minus'),
  new IconDefinition(iconLib['thermometerPlus'], 'thermometer-plus'),
  new IconDefinition(iconLib['thermostat'], 'thermostat'),
  new IconDefinition(iconLib['thermostatBox'], 'thermostat-box'),
  new IconDefinition(iconLib['thoughtBubble'], 'thought-bubble'),
  new IconDefinition(iconLib['thoughtBubbleOutline'], 'thought-bubble-outline'),
  new IconDefinition(iconLib['thumbDown'], 'thumb-down'),
  new IconDefinition(iconLib['thumbDownOutline'], 'thumb-down-outline'),
  new IconDefinition(iconLib['thumbUp'], 'thumb-up'),
  new IconDefinition(iconLib['thumbUpOutline'], 'thumb-up-outline'),
  new IconDefinition(iconLib['thumbsUpDown'], 'thumbs-up-down'),
  new IconDefinition(iconLib['ticket'], 'ticket'),
  new IconDefinition(iconLib['ticketAccount'], 'ticket-account'),
  new IconDefinition(iconLib['ticketConfirmation'], 'ticket-confirmation'),
  new IconDefinition(iconLib['ticketOutline'], 'ticket-outline'),
  new IconDefinition(iconLib['ticketPercent'], 'ticket-percent'),
  new IconDefinition(iconLib['tie'], 'tie'),
  new IconDefinition(iconLib['tilde'], 'tilde'),
  new IconDefinition(iconLib['timelapse'], 'timelapse'),
  new IconDefinition(iconLib['timeline'], 'timeline'),
  new IconDefinition(iconLib['timelineOutline'], 'timeline-outline'),
  new IconDefinition(iconLib['timelineText'], 'timeline-text'),
  new IconDefinition(iconLib['timelineTextOutline'], 'timeline-text-outline'),
  new IconDefinition(iconLib['timer'], 'timer'),
  new IconDefinition(iconLib['timer10'], 'timer-10'),
  new IconDefinition(iconLib['timer3'], 'timer-3'),
  new IconDefinition(iconLib['timerOff'], 'timer-off'),
  new IconDefinition(iconLib['timerSand'], 'timer-sand'),
  new IconDefinition(iconLib['timerSandEmpty'], 'timer-sand-empty'),
  new IconDefinition(iconLib['timerSandFull'], 'timer-sand-full'),
  new IconDefinition(iconLib['timetable'], 'timetable'),
  new IconDefinition(iconLib['toasterOven'], 'toaster-oven'),
  new IconDefinition(iconLib['toggleSwitch'], 'toggle-switch'),
  new IconDefinition(iconLib['toggleSwitchOff'], 'toggle-switch-off'),
  new IconDefinition(iconLib['toggleSwitchOffOutline'], 'toggle-switch-off-outline'),
  new IconDefinition(iconLib['toggleSwitchOutline'], 'toggle-switch-outline'),
  new IconDefinition(iconLib['toilet'], 'toilet'),
  new IconDefinition(iconLib['toolbox'], 'toolbox'),
  new IconDefinition(iconLib['toolboxOutline'], 'toolbox-outline'),
  new IconDefinition(iconLib['tooltip'], 'tooltip'),
  new IconDefinition(iconLib['tooltipAccount'], 'tooltip-account'),
  new IconDefinition(iconLib['tooltipEdit'], 'tooltip-edit'),
  new IconDefinition(iconLib['tooltipImage'], 'tooltip-image'),
  new IconDefinition(iconLib['tooltipImageOutline'], 'tooltip-image-outline'),
  new IconDefinition(iconLib['tooltipOutline'], 'tooltip-outline'),
  new IconDefinition(iconLib['tooltipPlus'], 'tooltip-plus'),
  new IconDefinition(iconLib['tooltipPlusOutline'], 'tooltip-plus-outline'),
  new IconDefinition(iconLib['tooltipText'], 'tooltip-text'),
  new IconDefinition(iconLib['tooltipTextOutline'], 'tooltip-text-outline'),
  new IconDefinition(iconLib['tooth'], 'tooth'),
  new IconDefinition(iconLib['toothOutline'], 'tooth-outline'),
  new IconDefinition(iconLib['tor'], 'tor'),
  new IconDefinition(iconLib['tortoise'], 'tortoise'),
  new IconDefinition(iconLib['tournament'], 'tournament'),
  new IconDefinition(iconLib['towerBeach'], 'tower-beach'),
  new IconDefinition(iconLib['towerFire'], 'tower-fire'),
  new IconDefinition(iconLib['towing'], 'towing'),
  new IconDefinition(iconLib['trackLight'], 'track-light'),
  new IconDefinition(iconLib['trackpad'], 'trackpad'),
  new IconDefinition(iconLib['trackpadLock'], 'trackpad-lock'),
  new IconDefinition(iconLib['tractor'], 'tractor'),
  new IconDefinition(iconLib['trademark'], 'trademark'),
  new IconDefinition(iconLib['trafficLight'], 'traffic-light'),
  new IconDefinition(iconLib['train'], 'train'),
  new IconDefinition(iconLib['trainCar'], 'train-car'),
  new IconDefinition(iconLib['trainVariant'], 'train-variant'),
  new IconDefinition(iconLib['tram'], 'tram'),
  new IconDefinition(iconLib['transcribe'], 'transcribe'),
  new IconDefinition(iconLib['transcribeClose'], 'transcribe-close'),
  new IconDefinition(iconLib['transferDown'], 'transfer-down'),
  new IconDefinition(iconLib['transferLeft'], 'transfer-left'),
  new IconDefinition(iconLib['transferRight'], 'transfer-right'),
  new IconDefinition(iconLib['transferUp'], 'transfer-up'),
  new IconDefinition(iconLib['transitConnection'], 'transit-connection'),
  new IconDefinition(iconLib['transitConnectionVariant'], 'transit-connection-variant'),
  new IconDefinition(iconLib['transitTransfer'], 'transit-transfer'),
  new IconDefinition(iconLib['transition'], 'transition'),
  new IconDefinition(iconLib['transitionMasked'], 'transition-masked'),
  new IconDefinition(iconLib['translate'], 'translate'),
  new IconDefinition(iconLib['translateOff'], 'translate-off'),
  new IconDefinition(iconLib['transmissionTower'], 'transmission-tower'),
  new IconDefinition(iconLib['trashCan'], 'trash-can'),
  new IconDefinition(iconLib['trashCanOutline'], 'trash-can-outline'),
  new IconDefinition(iconLib['treasureChest'], 'treasure-chest'),
  new IconDefinition(iconLib['tree'], 'tree'),
  new IconDefinition(iconLib['treeOutline'], 'tree-outline'),
  new IconDefinition(iconLib['trello'], 'trello'),
  new IconDefinition(iconLib['trendingDown'], 'trending-down'),
  new IconDefinition(iconLib['trendingNeutral'], 'trending-neutral'),
  new IconDefinition(iconLib['trendingUp'], 'trending-up'),
  new IconDefinition(iconLib['triangle'], 'triangle'),
  new IconDefinition(iconLib['triangleOutline'], 'triangle-outline'),
  new IconDefinition(iconLib['triforce'], 'triforce'),
  new IconDefinition(iconLib['trophy'], 'trophy'),
  new IconDefinition(iconLib['trophyAward'], 'trophy-award'),
  new IconDefinition(iconLib['trophyBroken'], 'trophy-broken'),
  new IconDefinition(iconLib['trophyOutline'], 'trophy-outline'),
  new IconDefinition(iconLib['trophyVariant'], 'trophy-variant'),
  new IconDefinition(iconLib['trophyVariantOutline'], 'trophy-variant-outline'),
  new IconDefinition(iconLib['truck'], 'truck'),
  new IconDefinition(iconLib['truckCheck'], 'truck-check'),
  new IconDefinition(iconLib['truckDelivery'], 'truck-delivery'),
  new IconDefinition(iconLib['truckFast'], 'truck-fast'),
  new IconDefinition(iconLib['truckTrailer'], 'truck-trailer'),
  new IconDefinition(iconLib['tshirtCrew'], 'tshirt-crew'),
  new IconDefinition(iconLib['tshirtCrewOutline'], 'tshirt-crew-outline'),
  new IconDefinition(iconLib['tshirtV'], 'tshirt-v'),
  new IconDefinition(iconLib['tshirtVOutline'], 'tshirt-v-outline'),
  new IconDefinition(iconLib['tumbleDryer'], 'tumble-dryer'),
  new IconDefinition(iconLib['tumblr'], 'tumblr'),
  new IconDefinition(iconLib['tumblrBox'], 'tumblr-box'),
  new IconDefinition(iconLib['tumblrReblog'], 'tumblr-reblog'),
  new IconDefinition(iconLib['tune'], 'tune'),
  new IconDefinition(iconLib['tuneVertical'], 'tune-vertical'),
  new IconDefinition(iconLib['turnstile'], 'turnstile'),
  new IconDefinition(iconLib['turnstileOutline'], 'turnstile-outline'),
  new IconDefinition(iconLib['turtle'], 'turtle'),
  new IconDefinition(iconLib['twitch'], 'twitch'),
  new IconDefinition(iconLib['twitter'], 'twitter'),
  new IconDefinition(iconLib['twitterBox'], 'twitter-box'),
  new IconDefinition(iconLib['twitterCircle'], 'twitter-circle'),
  new IconDefinition(iconLib['twitterRetweet'], 'twitter-retweet'),
  new IconDefinition(iconLib['twoFactorAuthentication'], 'two-factor-authentication'),
  new IconDefinition(iconLib['typewriter'], 'typewriter'),
  new IconDefinition(iconLib['uber'], 'uber'),
  new IconDefinition(iconLib['ubisoft'], 'ubisoft'),
  new IconDefinition(iconLib['ubuntu'], 'ubuntu'),
  new IconDefinition(iconLib['ultraHighDefinition'], 'ultra-high-definition'),
  new IconDefinition(iconLib['umbraco'], 'umbraco'),
  new IconDefinition(iconLib['umbrella'], 'umbrella'),
  new IconDefinition(iconLib['umbrellaClosed'], 'umbrella-closed'),
  new IconDefinition(iconLib['umbrellaOutline'], 'umbrella-outline'),
  new IconDefinition(iconLib['undo'], 'undo'),
  new IconDefinition(iconLib['undoVariant'], 'undo-variant'),
  new IconDefinition(iconLib['unfoldLessHorizontal'], 'unfold-less-horizontal'),
  new IconDefinition(iconLib['unfoldLessVertical'], 'unfold-less-vertical'),
  new IconDefinition(iconLib['unfoldMoreHorizontal'], 'unfold-more-horizontal'),
  new IconDefinition(iconLib['unfoldMoreVertical'], 'unfold-more-vertical'),
  new IconDefinition(iconLib['ungroup'], 'ungroup'),
  new IconDefinition(iconLib['unicode'], 'unicode'),
  new IconDefinition(iconLib['unity'], 'unity'),
  new IconDefinition(iconLib['unreal'], 'unreal'),
  new IconDefinition(iconLib['untappd'], 'untappd'),
  new IconDefinition(iconLib['update'], 'update'),
  new IconDefinition(iconLib['upload'], 'upload'),
  new IconDefinition(iconLib['uploadMultiple'], 'upload-multiple'),
  new IconDefinition(iconLib['uploadNetwork'], 'upload-network'),
  new IconDefinition(iconLib['uploadNetworkOutline'], 'upload-network-outline'),
  new IconDefinition(iconLib['uploadOutline'], 'upload-outline'),
  new IconDefinition(iconLib['usb'], 'usb'),
  new IconDefinition(iconLib['vanPassenger'], 'van-passenger'),
  new IconDefinition(iconLib['vanUtility'], 'van-utility'),
  new IconDefinition(iconLib['vanish'], 'vanish'),
  new IconDefinition(iconLib['variable'], 'variable'),
  new IconDefinition(iconLib['vectorArrangeAbove'], 'vector-arrange-above'),
  new IconDefinition(iconLib['vectorArrangeBelow'], 'vector-arrange-below'),
  new IconDefinition(iconLib['vectorBezier'], 'vector-bezier'),
  new IconDefinition(iconLib['vectorCircle'], 'vector-circle'),
  new IconDefinition(iconLib['vectorCircleVariant'], 'vector-circle-variant'),
  new IconDefinition(iconLib['vectorCombine'], 'vector-combine'),
  new IconDefinition(iconLib['vectorCurve'], 'vector-curve'),
  new IconDefinition(iconLib['vectorDifference'], 'vector-difference'),
  new IconDefinition(iconLib['vectorDifferenceAb'], 'vector-difference-ab'),
  new IconDefinition(iconLib['vectorDifferenceBa'], 'vector-difference-ba'),
  new IconDefinition(iconLib['vectorEllipse'], 'vector-ellipse'),
  new IconDefinition(iconLib['vectorIntersection'], 'vector-intersection'),
  new IconDefinition(iconLib['vectorLine'], 'vector-line'),
  new IconDefinition(iconLib['vectorPoint'], 'vector-point'),
  new IconDefinition(iconLib['vectorPolygon'], 'vector-polygon'),
  new IconDefinition(iconLib['vectorPolyline'], 'vector-polyline'),
  new IconDefinition(iconLib['vectorRadius'], 'vector-radius'),
  new IconDefinition(iconLib['vectorRectangle'], 'vector-rectangle'),
  new IconDefinition(iconLib['vectorSelection'], 'vector-selection'),
  new IconDefinition(iconLib['vectorSquare'], 'vector-square'),
  new IconDefinition(iconLib['vectorTriangle'], 'vector-triangle'),
  new IconDefinition(iconLib['vectorUnion'], 'vector-union'),
  new IconDefinition(iconLib['venmo'], 'venmo'),
  new IconDefinition(iconLib['vhs'], 'vhs'),
  new IconDefinition(iconLib['vibrate'], 'vibrate'),
  new IconDefinition(iconLib['vibrateOff'], 'vibrate-off'),
  new IconDefinition(iconLib['video'], 'video'),
  new IconDefinition(iconLib['video3D'], 'video-3d'),
  new IconDefinition(iconLib['video3DVariant'], 'video-3d-variant'),
  new IconDefinition(iconLib['video4KBox'], 'video-4k-box'),
  new IconDefinition(iconLib['videoAccount'], 'video-account'),
  new IconDefinition(iconLib['videoImage'], 'video-image'),
  new IconDefinition(iconLib['videoInputAntenna'], 'video-input-antenna'),
  new IconDefinition(iconLib['videoInputComponent'], 'video-input-component'),
  new IconDefinition(iconLib['videoInputHdmi'], 'video-input-hdmi'),
  new IconDefinition(iconLib['videoInputSvideo'], 'video-input-svideo'),
  new IconDefinition(iconLib['videoMinus'], 'video-minus'),
  new IconDefinition(iconLib['videoOff'], 'video-off'),
  new IconDefinition(iconLib['videoOffOutline'], 'video-off-outline'),
  new IconDefinition(iconLib['videoOutline'], 'video-outline'),
  new IconDefinition(iconLib['videoPlus'], 'video-plus'),
  new IconDefinition(iconLib['videoStabilization'], 'video-stabilization'),
  new IconDefinition(iconLib['videoSwitch'], 'video-switch'),
  new IconDefinition(iconLib['videoVintage'], 'video-vintage'),
  new IconDefinition(iconLib['videoWireless'], 'video-wireless'),
  new IconDefinition(iconLib['videoWirelessOutline'], 'video-wireless-outline'),
  new IconDefinition(iconLib['viewAgenda'], 'view-agenda'),
  new IconDefinition(iconLib['viewArray'], 'view-array'),
  new IconDefinition(iconLib['viewCarousel'], 'view-carousel'),
  new IconDefinition(iconLib['viewColumn'], 'view-column'),
  new IconDefinition(iconLib['viewComfy'], 'view-comfy'),
  new IconDefinition(iconLib['viewCompact'], 'view-compact'),
  new IconDefinition(iconLib['viewCompactOutline'], 'view-compact-outline'),
  new IconDefinition(iconLib['viewDashboard'], 'view-dashboard'),
  new IconDefinition(iconLib['viewDashboardOutline'], 'view-dashboard-outline'),
  new IconDefinition(iconLib['viewDashboardVariant'], 'view-dashboard-variant'),
  new IconDefinition(iconLib['viewDay'], 'view-day'),
  new IconDefinition(iconLib['viewGrid'], 'view-grid'),
  new IconDefinition(iconLib['viewHeadline'], 'view-headline'),
  new IconDefinition(iconLib['viewList'], 'view-list'),
  new IconDefinition(iconLib['viewModule'], 'view-module'),
  new IconDefinition(iconLib['viewParallel'], 'view-parallel'),
  new IconDefinition(iconLib['viewQuilt'], 'view-quilt'),
  new IconDefinition(iconLib['viewSequential'], 'view-sequential'),
  new IconDefinition(iconLib['viewSplitHorizontal'], 'view-split-horizontal'),
  new IconDefinition(iconLib['viewSplitVertical'], 'view-split-vertical'),
  new IconDefinition(iconLib['viewStream'], 'view-stream'),
  new IconDefinition(iconLib['viewWeek'], 'view-week'),
  new IconDefinition(iconLib['vimeo'], 'vimeo'),
  new IconDefinition(iconLib['violin'], 'violin'),
  new IconDefinition(iconLib['virtualReality'], 'virtual-reality'),
  new IconDefinition(iconLib['visualStudio'], 'visual-studio'),
  new IconDefinition(iconLib['visualStudioCode'], 'visual-studio-code'),
  new IconDefinition(iconLib['vk'], 'vk'),
  new IconDefinition(iconLib['vkBox'], 'vk-box'),
  new IconDefinition(iconLib['vkCircle'], 'vk-circle'),
  new IconDefinition(iconLib['vlc'], 'vlc'),
  new IconDefinition(iconLib['voice'], 'voice'),
  new IconDefinition(iconLib['voiceOff'], 'voice-off'),
  new IconDefinition(iconLib['voicemail'], 'voicemail'),
  new IconDefinition(iconLib['volleyball'], 'volleyball'),
  new IconDefinition(iconLib['volumeHigh'], 'volume-high'),
  new IconDefinition(iconLib['volumeLow'], 'volume-low'),
  new IconDefinition(iconLib['volumeMedium'], 'volume-medium'),
  new IconDefinition(iconLib['volumeMinus'], 'volume-minus'),
  new IconDefinition(iconLib['volumeMute'], 'volume-mute'),
  new IconDefinition(iconLib['volumeOff'], 'volume-off'),
  new IconDefinition(iconLib['volumePlus'], 'volume-plus'),
  new IconDefinition(iconLib['volumeVariantOff'], 'volume-variant-off'),
  new IconDefinition(iconLib['vote'], 'vote'),
  new IconDefinition(iconLib['voteOutline'], 'vote-outline'),
  new IconDefinition(iconLib['vpn'], 'vpn'),
  new IconDefinition(iconLib['vuejs'], 'vuejs'),
  new IconDefinition(iconLib['vuetify'], 'vuetify'),
  new IconDefinition(iconLib['walk'], 'walk'),
  new IconDefinition(iconLib['wall'], 'wall'),
  new IconDefinition(iconLib['wallSconce'], 'wall-sconce'),
  new IconDefinition(iconLib['wallSconceFlat'], 'wall-sconce-flat'),
  new IconDefinition(iconLib['wallSconceVariant'], 'wall-sconce-variant'),
  new IconDefinition(iconLib['wallet'], 'wallet'),
  new IconDefinition(iconLib['walletGiftcard'], 'wallet-giftcard'),
  new IconDefinition(iconLib['walletMembership'], 'wallet-membership'),
  new IconDefinition(iconLib['walletOutline'], 'wallet-outline'),
  new IconDefinition(iconLib['walletTravel'], 'wallet-travel'),
  new IconDefinition(iconLib['wallpaper'], 'wallpaper'),
  new IconDefinition(iconLib['wan'], 'wan'),
  new IconDefinition(iconLib['washingMachine'], 'washing-machine'),
  new IconDefinition(iconLib['watch'], 'watch'),
  new IconDefinition(iconLib['watchExport'], 'watch-export'),
  new IconDefinition(iconLib['watchExportVariant'], 'watch-export-variant'),
  new IconDefinition(iconLib['watchImport'], 'watch-import'),
  new IconDefinition(iconLib['watchImportVariant'], 'watch-import-variant'),
  new IconDefinition(iconLib['watchVariant'], 'watch-variant'),
  new IconDefinition(iconLib['watchVibrate'], 'watch-vibrate'),
  new IconDefinition(iconLib['watchVibrateOff'], 'watch-vibrate-off'),
  new IconDefinition(iconLib['water'], 'water'),
  new IconDefinition(iconLib['waterOff'], 'water-off'),
  new IconDefinition(iconLib['waterOutline'], 'water-outline'),
  new IconDefinition(iconLib['waterPercent'], 'water-percent'),
  new IconDefinition(iconLib['waterPump'], 'water-pump'),
  new IconDefinition(iconLib['watermark'], 'watermark'),
  new IconDefinition(iconLib['wave'], 'wave'),
  new IconDefinition(iconLib['waves'], 'waves'),
  new IconDefinition(iconLib['waze'], 'waze'),
  new IconDefinition(iconLib['weatherCloudy'], 'weather-cloudy'),
  new IconDefinition(iconLib['weatherCloudyAlert'], 'weather-cloudy-alert'),
  new IconDefinition(iconLib['weatherCloudyArrowRight'], 'weather-cloudy-arrow-right'),
  new IconDefinition(iconLib['weatherFog'], 'weather-fog'),
  new IconDefinition(iconLib['weatherHail'], 'weather-hail'),
  new IconDefinition(iconLib['weatherHazy'], 'weather-hazy'),
  new IconDefinition(iconLib['weatherHurricane'], 'weather-hurricane'),
  new IconDefinition(iconLib['weatherLightning'], 'weather-lightning'),
  new IconDefinition(iconLib['weatherLightningRainy'], 'weather-lightning-rainy'),
  new IconDefinition(iconLib['weatherNight'], 'weather-night'),
  new IconDefinition(iconLib['weatherNightPartlyCloudy'], 'weather-night-partly-cloudy'),
  new IconDefinition(iconLib['weatherPartlyCloudy'], 'weather-partly-cloudy'),
  new IconDefinition(iconLib['weatherPartlyLightning'], 'weather-partly-lightning'),
  new IconDefinition(iconLib['weatherPartlyRainy'], 'weather-partly-rainy'),
  new IconDefinition(iconLib['weatherPartlySnowy'], 'weather-partly-snowy'),
  new IconDefinition(iconLib['weatherPartlySnowyRainy'], 'weather-partly-snowy-rainy'),
  new IconDefinition(iconLib['weatherPouring'], 'weather-pouring'),
  new IconDefinition(iconLib['weatherRainy'], 'weather-rainy'),
  new IconDefinition(iconLib['weatherSnowy'], 'weather-snowy'),
  new IconDefinition(iconLib['weatherSnowyHeavy'], 'weather-snowy-heavy'),
  new IconDefinition(iconLib['weatherSnowyRainy'], 'weather-snowy-rainy'),
  new IconDefinition(iconLib['weatherSunny'], 'weather-sunny'),
  new IconDefinition(iconLib['weatherSunnyAlert'], 'weather-sunny-alert'),
  new IconDefinition(iconLib['weatherSunset'], 'weather-sunset'),
  new IconDefinition(iconLib['weatherSunsetDown'], 'weather-sunset-down'),
  new IconDefinition(iconLib['weatherSunsetUp'], 'weather-sunset-up'),
  new IconDefinition(iconLib['weatherTornado'], 'weather-tornado'),
  new IconDefinition(iconLib['weatherWindy'], 'weather-windy'),
  new IconDefinition(iconLib['weatherWindyVariant'], 'weather-windy-variant'),
  new IconDefinition(iconLib['web'], 'web'),
  new IconDefinition(iconLib['webcam'], 'webcam'),
  new IconDefinition(iconLib['webhook'], 'webhook'),
  new IconDefinition(iconLib['webpack'], 'webpack'),
  new IconDefinition(iconLib['wechat'], 'wechat'),
  new IconDefinition(iconLib['weight'], 'weight'),
  new IconDefinition(iconLib['weightGram'], 'weight-gram'),
  new IconDefinition(iconLib['weightKilogram'], 'weight-kilogram'),
  new IconDefinition(iconLib['weightPound'], 'weight-pound'),
  new IconDefinition(iconLib['whatsapp'], 'whatsapp'),
  new IconDefinition(iconLib['wheelchairAccessibility'], 'wheelchair-accessibility'),
  new IconDefinition(iconLib['whistle'], 'whistle'),
  new IconDefinition(iconLib['whiteBalanceAuto'], 'white-balance-auto'),
  new IconDefinition(iconLib['whiteBalanceIncandescent'], 'white-balance-incandescent'),
  new IconDefinition(iconLib['whiteBalanceIridescent'], 'white-balance-iridescent'),
  new IconDefinition(iconLib['whiteBalanceSunny'], 'white-balance-sunny'),
  new IconDefinition(iconLib['widgets'], 'widgets'),
  new IconDefinition(iconLib['wifi'], 'wifi'),
  new IconDefinition(iconLib['wifiOff'], 'wifi-off'),
  new IconDefinition(iconLib['wifiStar'], 'wifi-star'),
  new IconDefinition(iconLib['wifiStrength1'], 'wifi-strength-1'),
  new IconDefinition(iconLib['wifiStrength1Alert'], 'wifi-strength-1-alert'),
  new IconDefinition(iconLib['wifiStrength1Lock'], 'wifi-strength-1-lock'),
  new IconDefinition(iconLib['wifiStrength2'], 'wifi-strength-2'),
  new IconDefinition(iconLib['wifiStrength2Alert'], 'wifi-strength-2-alert'),
  new IconDefinition(iconLib['wifiStrength2Lock'], 'wifi-strength-2-lock'),
  new IconDefinition(iconLib['wifiStrength3'], 'wifi-strength-3'),
  new IconDefinition(iconLib['wifiStrength3Alert'], 'wifi-strength-3-alert'),
  new IconDefinition(iconLib['wifiStrength3Lock'], 'wifi-strength-3-lock'),
  new IconDefinition(iconLib['wifiStrength4'], 'wifi-strength-4'),
  new IconDefinition(iconLib['wifiStrength4Alert'], 'wifi-strength-4-alert'),
  new IconDefinition(iconLib['wifiStrength4Lock'], 'wifi-strength-4-lock'),
  new IconDefinition(iconLib['wifiStrengthAlertOutline'], 'wifi-strength-alert-outline'),
  new IconDefinition(iconLib['wifiStrengthLockOutline'], 'wifi-strength-lock-outline'),
  new IconDefinition(iconLib['wifiStrengthOff'], 'wifi-strength-off'),
  new IconDefinition(iconLib['wifiStrengthOffOutline'], 'wifi-strength-off-outline'),
  new IconDefinition(iconLib['wifiStrengthOutline'], 'wifi-strength-outline'),
  new IconDefinition(iconLib['wii'], 'wii'),
  new IconDefinition(iconLib['wiiu'], 'wiiu'),
  new IconDefinition(iconLib['wikipedia'], 'wikipedia'),
  new IconDefinition(iconLib['windTurbine'], 'wind-turbine'),
  new IconDefinition(iconLib['windowClose'], 'window-close'),
  new IconDefinition(iconLib['windowClosed'], 'window-closed'),
  new IconDefinition(iconLib['windowMaximize'], 'window-maximize'),
  new IconDefinition(iconLib['windowMinimize'], 'window-minimize'),
  new IconDefinition(iconLib['windowOpen'], 'window-open'),
  new IconDefinition(iconLib['windowRestore'], 'window-restore'),
  new IconDefinition(iconLib['windows'], 'windows'),
  new IconDefinition(iconLib['windowsClassic'], 'windows-classic'),
  new IconDefinition(iconLib['wiper'], 'wiper'),
  new IconDefinition(iconLib['wiperWash'], 'wiper-wash'),
  new IconDefinition(iconLib['wordpress'], 'wordpress'),
  new IconDefinition(iconLib['worker'], 'worker'),
  new IconDefinition(iconLib['wrap'], 'wrap'),
  new IconDefinition(iconLib['wrapDisabled'], 'wrap-disabled'),
  new IconDefinition(iconLib['wrench'], 'wrench'),
  new IconDefinition(iconLib['wrenchOutline'], 'wrench-outline'),
  new IconDefinition(iconLib['wunderlist'], 'wunderlist'),
  new IconDefinition(iconLib['xamarin'], 'xamarin'),
  new IconDefinition(iconLib['xamarinOutline'], 'xamarin-outline'),
  new IconDefinition(iconLib['xaml'], 'xaml'),
  new IconDefinition(iconLib['xbox'], 'xbox'),
  new IconDefinition(iconLib['xboxController'], 'xbox-controller'),
  new IconDefinition(iconLib['xboxControllerBatteryAlert'], 'xbox-controller-battery-alert'),
  new IconDefinition(iconLib['xboxControllerBatteryCharging'], 'xbox-controller-battery-charging'),
  new IconDefinition(iconLib['xboxControllerBatteryEmpty'], 'xbox-controller-battery-empty'),
  new IconDefinition(iconLib['xboxControllerBatteryFull'], 'xbox-controller-battery-full'),
  new IconDefinition(iconLib['xboxControllerBatteryLow'], 'xbox-controller-battery-low'),
  new IconDefinition(iconLib['xboxControllerBatteryMedium'], 'xbox-controller-battery-medium'),
  new IconDefinition(iconLib['xboxControllerBatteryUnknown'], 'xbox-controller-battery-unknown'),
  new IconDefinition(iconLib['xboxControllerMenu'], 'xbox-controller-menu'),
  new IconDefinition(iconLib['xboxControllerOff'], 'xbox-controller-off'),
  new IconDefinition(iconLib['xboxControllerView'], 'xbox-controller-view'),
  new IconDefinition(iconLib['xda'], 'xda'),
  new IconDefinition(iconLib['xing'], 'xing'),
  new IconDefinition(iconLib['xingBox'], 'xing-box'),
  new IconDefinition(iconLib['xingCircle'], 'xing-circle'),
  new IconDefinition(iconLib['xml'], 'xml'),
  new IconDefinition(iconLib['xmpp'], 'xmpp'),
  new IconDefinition(iconLib['yahoo'], 'yahoo'),
  new IconDefinition(iconLib['yammer'], 'yammer'),
  new IconDefinition(iconLib['yeast'], 'yeast'),
  new IconDefinition(iconLib['yelp'], 'yelp'),
  new IconDefinition(iconLib['yinYang'], 'yin-yang'),
  new IconDefinition(iconLib['youtube'], 'youtube'),
  new IconDefinition(iconLib['youtubeCreatorStudio'], 'youtube-creator-studio'),
  new IconDefinition(iconLib['youtubeGaming'], 'youtube-gaming'),
  new IconDefinition(iconLib['youtubeSubscription'], 'youtube-subscription'),
  new IconDefinition(iconLib['youtubeTv'], 'youtube-tv'),
  new IconDefinition(iconLib['zWave'], 'z-wave'),
  new IconDefinition(iconLib['zend'], 'zend'),
  new IconDefinition(iconLib['zigbee'], 'zigbee'),
  new IconDefinition(iconLib['zipBox'], 'zip-box'),
  new IconDefinition(iconLib['zipDisk'], 'zip-disk'),
  new IconDefinition(iconLib['zodiacAquarius'], 'zodiac-aquarius'),
  new IconDefinition(iconLib['zodiacAries'], 'zodiac-aries'),
  new IconDefinition(iconLib['zodiacCancer'], 'zodiac-cancer'),
  new IconDefinition(iconLib['zodiacCapricorn'], 'zodiac-capricorn'),
  new IconDefinition(iconLib['zodiacGemini'], 'zodiac-gemini'),
  new IconDefinition(iconLib['zodiacLeo'], 'zodiac-leo'),
  new IconDefinition(iconLib['zodiacLibra'], 'zodiac-libra'),
  new IconDefinition(iconLib['zodiacPisces'], 'zodiac-pisces'),
  new IconDefinition(iconLib['zodiacSagittarius'], 'zodiac-sagittarius'),
  new IconDefinition(iconLib['zodiacScorpio'], 'zodiac-scorpio'),
  new IconDefinition(iconLib['zodiacTaurus'], 'zodiac-taurus'),
  new IconDefinition(iconLib['zodiacVirgo'], 'zodiac-virgo'),
];
